Module: FactPulse
- Defined in:
- lib/factpulse/version.rb,
lib/factpulse.rb,
lib/factpulse/api_error.rb,
lib/factpulse/api_client.rb,
lib/factpulse/models/rate.rb,
lib/factpulse/models/payee.rb,
lib/factpulse/models/rate1.rb,
lib/factpulse/api/parse_api.rb,
lib/factpulse/configuration.rb,
lib/factpulse/models/amount.rb,
lib/factpulse/api/health_api.rb,
lib/factpulse/api_model_base.rb,
lib/factpulse/helpers/client.rb,
lib/factpulse/models/amount1.rb,
lib/factpulse/models/amount2.rb,
lib/factpulse/models/contact.rb,
lib/factpulse/helpers/helpers.rb,
lib/factpulse/models/currency.rb,
lib/factpulse/models/doc_type.rb,
lib/factpulse/models/quantity.rb,
lib/factpulse/models/supplier.rb,
lib/factpulse/models/vat_line.rb,
lib/factpulse/models/vat_rate.rb,
lib/factpulse/models/api_error.rb,
lib/factpulse/models/file_info.rb,
lib/factpulse/models/flow_type.rb,
lib/factpulse/models/recipient.rb,
lib/factpulse/models/scheme_id.rb,
lib/factpulse/models/taxamount.rb,
lib/factpulse/api/downloads_api.rb,
lib/factpulse/models/afnor_flow.rb,
lib/factpulse/models/amount_due.rb,
lib/factpulse/models/files_info.rb,
lib/factpulse/models/percentage.rb,
lib/factpulse/models/taxamount1.rb,
lib/factpulse/models/taxamount2.rb,
lib/factpulse/models/vat_amount.rb,
lib/factpulse/api/afnorpdppa_api.rb,
lib/factpulse/api/chorus_pro_api.rb,
lib/factpulse/api/references_api.rb,
lib/factpulse/api/validation_api.rb,
lib/factpulse/helpers/exceptions.rb,
lib/factpulse/models/afnor_error.rb,
lib/factpulse/models/api_profile.rb,
lib/factpulse/models/base_amount.rb,
lib/factpulse/models/destination.rb,
lib/factpulse/models/error_level.rb,
lib/factpulse/models/flow_syntax.rb,
lib/factpulse/models/manual_rate.rb,
lib/factpulse/api/async_tasks_api.rb,
lib/factpulse/models/afnor_result.rb,
lib/factpulse/models/buyercountry.rb,
lib/factpulse/models/country_code.rb,
lib/factpulse/models/error_source.rb,
lib/factpulse/models/field_status.rb,
lib/factpulse/models/flow_profile.rb,
lib/factpulse/models/flow_summary.rb,
lib/factpulse/models/invoice_line.rb,
lib/factpulse/models/invoice_note.rb,
lib/factpulse/models/payment_card.rb,
lib/factpulse/models/vat_category.rb,
lib/factpulse/models/afnor_webhook.rb,
lib/factpulse/models/celery_status.rb,
lib/factpulse/models/client_detail.rb,
lib/factpulse/models/currency_code.rb,
lib/factpulse/models/invoice_input.rb,
lib/factpulse/models/line_sub_type.rb,
lib/factpulse/models/missing_field.rb,
lib/factpulse/models/output_format.rb,
lib/factpulse/models/payment_means.rb,
lib/factpulse/models/report_issuer.rb,
lib/factpulse/models/report_period.rb,
lib/factpulse/models/report_sender.rb,
lib/factpulse/models/secret_status.rb,
lib/factpulse/models/sellercountry.rb,
lib/factpulse/models/task_response.rb,
lib/factpulse/models/taxableamount.rb,
lib/factpulse/models/client_summary.rb,
lib/factpulse/models/delivery_party.rb,
lib/factpulse/models/encaisseamount.rb,
lib/factpulse/models/flow_direction.rb,
lib/factpulse/models/invoice_format.rb,
lib/factpulse/models/invoice_status.rb,
lib/factpulse/models/invoice_totals.rb,
lib/factpulse/models/location_inner.rb,
lib/factpulse/models/postal_address.rb,
lib/factpulse/models/signature_info.rb,
lib/factpulse/models/structure_info.rb,
lib/factpulse/models/taxable_amount.rb,
lib/factpulse/models/unit_net_price.rb,
lib/factpulse/models/afnor_algorithm.rb,
lib/factpulse/models/afnor_flow_info.rb,
lib/factpulse/models/afnor_flow_type.rb,
lib/factpulse/models/encaisseamount1.rb,
lib/factpulse/models/extraction_info.rb,
lib/factpulse/models/lifecycle_event.rb,
lib/factpulse/models/line_net_amount.rb,
lib/factpulse/models/manual_vat_rate.rb,
lib/factpulse/models/pdp_credentials.rb,
lib/factpulse/models/processing_rule.rb,
lib/factpulse/models/recipient_input.rb,
lib/factpulse/models/refusee_request.rb,
lib/factpulse/models/rounding_amount.rb,
lib/factpulse/models/submission_mode.rb,
lib/factpulse/models/unit_of_measure.rb,
lib/factpulse/models/validation_info.rb,
lib/factpulse/models/vatex_code_info.rb,
lib/factpulse/models/action_code_info.rb,
lib/factpulse/models/allowance_charge.rb,
lib/factpulse/models/factur_x_invoice.rb,
lib/factpulse/models/factur_xpdf_info.rb,
lib/factpulse/models/gross_unit_price.rb,
lib/factpulse/models/incoming_invoice.rb,
lib/factpulse/models/issuer_role_code.rb,
lib/factpulse/models/operation_nature.rb,
lib/factpulse/models/reason_code_info.rb,
lib/factpulse/models/status_code_info.rb,
lib/factpulse/models/total_net_amount.rb,
lib/factpulse/models/total_vat_amount.rb,
lib/factpulse/models/validation_error.rb,
lib/factpulse/models/afnor_credentials.rb,
lib/factpulse/models/afnor_destination.rb,
lib/factpulse/models/afnor_entity_type.rb,
lib/factpulse/models/afnor_flow_syntax.rb,
lib/factpulse/models/afnor_reason_code.rb,
lib/factpulse/models/afnor_siren_field.rb,
lib/factpulse/models/afnor_siret_field.rb,
lib/factpulse/models/async_task_status.rb,
lib/factpulse/models/chorus_pro_result.rb,
lib/factpulse/models/encaissee_request.rb,
lib/factpulse/models/incoming_supplier.rb,
lib/factpulse/models/invoice_lifecycle.rb,
lib/factpulse/models/invoice_type_code.rb,
lib/factpulse/models/line_total_amount.rb,
lib/factpulse/models/structure_service.rb,
lib/factpulse/models/submit_net_amount.rb,
lib/factpulse/models/submit_vat_amount.rb,
lib/factpulse/models/task_error_result.rb,
lib/factpulse/models/tax_due_date_type.rb,
lib/factpulse/api/client_management_api.rb,
lib/factpulse/models/afnor_address_read.rb,
lib/factpulse/models/afnor_error_detail.rb,
lib/factpulse/models/afnor_flow_profile.rb,
lib/factpulse/models/afnor_search_siren.rb,
lib/factpulse/models/afnor_search_siret.rb,
lib/factpulse/models/document_type_info.rb,
lib/factpulse/models/electronic_address.rb,
lib/factpulse/models/invoice_references.rb,
lib/factpulse/models/lifecycle_response.rb,
lib/factpulse/models/processing_options.rb,
lib/factpulse/models/signature_info_api.rb,
lib/factpulse/models/tax_representative.rb,
lib/factpulse/models/taxexclusiveamount.rb,
lib/factpulse/models/total_gross_amount.rb,
lib/factpulse/api/flux10_e_reporting_api.rb,
lib/factpulse/api/invoice_generation_api.rb,
lib/factpulse/models/additional_document.rb,
lib/factpulse/models/afnor_facility_type.rb,
lib/factpulse/models/afnor_sorting_order.rb,
lib/factpulse/models/bounding_box_schema.rb,
lib/factpulse/models/charge_total_amount.rb,
lib/factpulse/models/create_cdar_request.rb,
lib/factpulse/models/get_invoice_request.rb,
lib/factpulse/models/invoicing_framework.rb,
lib/factpulse/models/pdp_config_response.rb,
lib/factpulse/models/search_flow_request.rb,
lib/factpulse/models/submit_cdar_request.rb,
lib/factpulse/models/submit_flow_request.rb,
lib/factpulse/models/submit_gross_amount.rb,
lib/factpulse/models/tax_breakdown_input.rb,
lib/factpulse/models/taxexclusiveamount1.rb,
lib/factpulse/models/vat_accounting_code.rb,
lib/factpulse/models/vat_point_date_code.rb,
lib/factpulse/api/factur_x_conversion_api.rb,
lib/factpulse/api/factur_x_validation_api.rb,
lib/factpulse/models/afnor_core_flow_info.rb,
lib/factpulse/models/afnor_flow_direction.rb,
lib/factpulse/models/afnor_flow_extension.rb,
lib/factpulse/models/afnor_full_flow_info.rb,
lib/factpulse/models/afnor_webhook_params.rb,
lib/factpulse/models/client_list_response.rb,
lib/factpulse/models/get_invoice_response.rb,
lib/factpulse/models/key_rotation_request.rb,
lib/factpulse/models/price_basis_quantity.rb,
lib/factpulse/models/search_flow_response.rb,
lib/factpulse/models/signature_parameters.rb,
lib/factpulse/models/structure_parameters.rb,
lib/factpulse/models/submit_cdar_response.rb,
lib/factpulse/models/submit_flow_response.rb,
lib/factpulse/models/transaction_category.rb,
lib/factpulse/models/vatex_codes_response.rb,
lib/factpulse/api/electronic_signature_api.rb,
lib/factpulse/models/acknowledgment_status.rb,
lib/factpulse/models/action_codes_response.rb,
lib/factpulse/models/afnor_acknowledgement.rb,
lib/factpulse/models/afnor_callback_header.rb,
lib/factpulse/models/afnor_flow_ack_status.rb,
lib/factpulse/models/afnor_processing_rule.rb,
lib/factpulse/models/afnor_strict_operator.rb,
lib/factpulse/models/allowance_reason_code.rb,
lib/factpulse/models/client_create_request.rb,
lib/factpulse/models/client_update_request.rb,
lib/factpulse/models/e_reporting_flow_type.rb,
lib/factpulse/models/enriched_invoice_info.rb,
lib/factpulse/models/get_structure_request.rb,
lib/factpulse/models/http_validation_error.rb,
lib/factpulse/models/invoice_payment_input.rb,
lib/factpulse/models/key_rotation_response.rb,
lib/factpulse/models/mandatory_note_schema.rb,
lib/factpulse/models/reason_codes_response.rb,
lib/factpulse/models/signature_task_status.rb,
lib/factpulse/models/status_codes_response.rb,
lib/factpulse/models/validate_cdar_request.rb,
lib/factpulse/models/verified_field_schema.rb,
lib/factpulse/models/afnor_reason_code_enum.rb,
lib/factpulse/models/afnor_webhook_id_param.rb,
lib/factpulse/models/afnor_webhook_metadata.rb,
lib/factpulse/models/allowance_total_amount.rb,
lib/factpulse/models/chorus_pro_credentials.rb,
lib/factpulse/models/chorus_pro_destination.rb,
lib/factpulse/models/conversion_task_status.rb,
lib/factpulse/models/convert_resume_request.rb,
lib/factpulse/models/generate_cdar_response.rb,
lib/factpulse/models/generation_task_status.rb,
lib/factpulse/models/get_structure_response.rb,
lib/factpulse/models/page_dimensions_schema.rb,
lib/factpulse/models/payment_amount_by_rate.rb,
lib/factpulse/models/price_allowance_amount.rb,
lib/factpulse/models/product_characteristic.rb,
lib/factpulse/models/product_classification.rb,
lib/factpulse/models/submit_cdarxml_request.rb,
lib/factpulse/models/submit_invoice_request.rb,
lib/factpulse/models/transmission_type_code.rb,
lib/factpulse/models/validate_cdar_response.rb,
lib/factpulse/models/validation_task_status.rb,
lib/factpulse/models/afnor_contains_operator.rb,
lib/factpulse/models/conversion_error_result.rb,
lib/factpulse/models/global_allowance_amount.rb,
lib/factpulse/models/parse_factur_x_response.rb,
lib/factpulse/models/simplified_invoice_data.rb,
lib/factpulse/models/submit_invoice_response.rb,
lib/factpulse/models/validation_error_detail.rb,
lib/factpulse/api/afnorpdppa_flow_service_api.rb,
lib/factpulse/models/afnor_callback_signature.rb,
lib/factpulse/models/afnor_routing_code_field.rb,
lib/factpulse/models/afnor_search_flow_params.rb,
lib/factpulse/models/afnor_siren_instructions.rb,
lib/factpulse/models/afnor_siret_instructions.rb,
lib/factpulse/models/aggregated_payment_input.rb,
lib/factpulse/models/client_activate_response.rb,
lib/factpulse/models/convert_success_response.rb,
lib/factpulse/models/invoice_type_code_output.rb,
lib/factpulse/models/invoicing_framework_code.rb,
lib/factpulse/models/search_services_response.rb,
lib/factpulse/models/search_structure_request.rb,
lib/factpulse/models/signature_success_result.rb,
lib/factpulse/models/simplified_cdar_response.rb,
lib/factpulse/models/supplementary_attachment.rb,
lib/factpulse/models/afnor_callback_parameters.rb,
lib/factpulse/models/afnor_flow_info_extension.rb,
lib/factpulse/models/afnor_routing_code_search.rb,
lib/factpulse/models/afnor_search_flow_content.rb,
lib/factpulse/models/afnor_search_flow_filters.rb,
lib/factpulse/models/certificate_info_response.rb,
lib/factpulse/models/generation_success_result.rb,
lib/factpulse/models/get_chorus_pro_id_request.rb,
lib/factpulse/models/invoice_totals_prepayment.rb,
lib/factpulse/models/pdf_validation_result_api.rb,
lib/factpulse/models/pdp_config_update_request.rb,
lib/factpulse/models/search_structure_response.rb,
lib/factpulse/models/validation_error_response.rb,
lib/factpulse/models/afnor_basic_authentication.rb,
lib/factpulse/models/afnor_directory_line_field.rb,
lib/factpulse/models/afnor_search_siren_filters.rb,
lib/factpulse/models/afnor_search_siret_filters.rb,
lib/factpulse/models/conversion_extraction_info.rb,
lib/factpulse/models/create_e_reporting_request.rb,
lib/factpulse/models/get_chorus_pro_id_response.rb,
lib/factpulse/models/submit_e_reporting_request.rb,
lib/factpulse/models/afnor_directory_line_status.rb,
lib/factpulse/models/afnor_health_check_response.rb,
lib/factpulse/models/afnor_search_directory_line.rb,
lib/factpulse/models/afnor_webhook_patch_payload.rb,
lib/factpulse/models/afnoro_auth2_authentication.rb,
lib/factpulse/models/schematron_validation_error.rb,
lib/factpulse/models/submit_e_reporting_response.rb,
lib/factpulse/models/validation_success_response.rb,
lib/factpulse/api/factur_xpdfxml_verification_api.rb,
lib/factpulse/models/afnor_acknowledgement_detail.rb,
lib/factpulse/models/aggregated_transaction_input.rb,
lib/factpulse/models/allowance_charge_reason_code.rb,
lib/factpulse/models/e_reporting_validation_error.rb,
lib/factpulse/models/generate_certificate_request.rb,
lib/factpulse/models/signature_task_status_result.rb,
lib/factpulse/models/validate_e_reporting_request.rb,
lib/factpulse/api/afnorpdppa_directory_service_api.rb,
lib/factpulse/api/flux6_invoice_lifecycle_cdar_api.rb,
lib/factpulse/models/afnor_callback_authentication.rb,
lib/factpulse/models/afnor_recipient_platform_type.rb,
lib/factpulse/models/conversion_task_status_result.rb,
lib/factpulse/models/generate_certificate_response.rb,
lib/factpulse/models/generate_e_reporting_response.rb,
lib/factpulse/models/generation_task_status_result.rb,
lib/factpulse/models/invoice_line_allowance_amount.rb,
lib/factpulse/models/validate_e_reporting_response.rb,
lib/factpulse/models/validation_task_status_result.rb,
lib/factpulse/models/verification_success_response.rb,
lib/factpulse/models/afnor_facility_payload_history.rb,
lib/factpulse/models/afnor_full_flow_info_extension.rb,
lib/factpulse/models/conversion_success_task_result.rb,
lib/factpulse/models/validation_success_task_result.rb,
lib/factpulse/models/verification_typed_task_status.rb,
lib/factpulse/models/webhook_secret_delete_response.rb,
lib/factpulse/models/webhook_secret_status_response.rb,
lib/factpulse/models/afnor_facility_payload_included.rb,
lib/factpulse/models/afnor_search_siret_filters_name.rb,
lib/factpulse/models/conversion_pending_input_result.rb,
lib/factpulse/models/submit_complete_invoice_request.rb,
lib/factpulse/models/afnor_legal_unit_payload_history.rb,
lib/factpulse/models/afnor_search_siren_filters_siren.rb,
lib/factpulse/models/afnor_search_siren_sorting_inner.rb,
lib/factpulse/models/afnor_search_siret_filters_siret.rb,
lib/factpulse/models/afnor_search_siret_sorting_inner.rb,
lib/factpulse/models/create_aggregated_report_request.rb,
lib/factpulse/models/submit_aggregated_report_request.rb,
lib/factpulse/models/submit_complete_invoice_response.rb,
lib/factpulse/models/verification_success_task_result.rb,
lib/factpulse/models/webhook_secret_generate_response.rb,
lib/factpulse/models/afnor_contains_or_strict_operator.rb,
lib/factpulse/models/afnor_legal_unit_payload_included.rb,
lib/factpulse/models/afnor_routing_code_search_filters.rb,
lib/factpulse/models/convert_validation_failed_response.rb,
lib/factpulse/models/afnor_search_directory_line_filters.rb,
lib/factpulse/models/afnor_search_siret_filters_locality.rb,
lib/factpulse/models/afnor_siren_search_post200_response.rb,
lib/factpulse/models/afnor_siret_search_post200_response.rb,
lib/factpulse/models/afnor_strict_or_start_with_operator.rb,
lib/factpulse/models/conversion_validation_failed_result.rb,
lib/factpulse/models/generate_aggregated_report_response.rb,
lib/factpulse/models/afnor_facility_administrative_status.rb,
lib/factpulse/models/verification_typed_task_status_result.rb,
lib/factpulse/models/afnor_legal_unit_administrative_status.rb,
lib/factpulse/models/afnor_search_siren_filters_entity_type.rb,
lib/factpulse/models/afnor_search_siret_filters_postal_code.rb,
lib/factpulse/models/afnor_routing_code_search_sorting_inner.rb,
lib/factpulse/models/afnor_routing_code_administrative_status.rb,
lib/factpulse/models/afnor_search_siren_filters_business_name.rb,
lib/factpulse/models/afnor_search_siret_filters_address_lines.rb,
lib/factpulse/models/afnor_search_siret_filters_facility_type.rb,
lib/factpulse/models/afnor_search_directory_line_sorting_inner.rb,
lib/factpulse/models/afnor_routing_code_search_post200_response.rb,
lib/factpulse/models/afnor_directory_line_search_post200_response.rb,
lib/factpulse/models/afnor_search_siret_filters_country_subdivision.rb,
lib/factpulse/models/afnor_search_siren_filters_administrative_status.rb,
lib/factpulse/models/afnor_search_siret_filters_administrative_status.rb,
lib/factpulse/models/afnor_routing_code_search_filters_routing_code_name.rb,
lib/factpulse/models/afnor_routing_code_search_filters_routing_identifier.rb,
lib/factpulse/models/afnor_search_directory_line_filters_addressing_suffix.rb,
lib/factpulse/models/afnor_facility_payload_history_ule_b2g_additional_data.rb,
lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb,
lib/factpulse/models/afnor_routing_code_search_filters_administrative_status.rb,
lib/factpulse/models/afnor_search_directory_line_filters_addressing_identifier.rb,
lib/factpulse/models/afnor_directory_line_payload_legal_unit_facility_routing_code.rb,
lib/factpulse/models/facture_electronique_rest_api_schemas_ereporting_invoice_type_code.rb,
lib/factpulse/models/afnor_directory_line_payload_status_legal_unit_facility_routing_code.rb,
lib/factpulse/models/facture_electronique_rest_api_schemas_cdar_validation_error_response.rb,
lib/factpulse/models/facture_electronique_rest_api_schemas_processing_chorus_pro_credentials.rb,
lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb
Overview
#FactPulse REST API
REST API for electronic invoicing in France: Factur-X (CII), UBL 2.1, AFNOR PDP/PA, electronic signatures. ## 🎯 Main Features ### 📄 Invoice Generation - Formats: CII XML, UBL 2.1 XML, or Factur-X PDF/A-3 - Profiles (CII/PDF): MINIMUM, BASIC, EN16931, EXTENDED - UBL: Always EN16931 compliant - Standards: EN 16931 (EU directive 2014/55), ISO 19005-3 (PDF/A-3), CII (UN/CEFACT), UBL 2.1 (OASIS) - Simplified Format: Generation from SIRET + auto-enrichment (Chorus Pro API + Business Search) ### ✅ Factur-X - Validation - XML Validation: Schematron (45 to 210+ rules depending on profile) - PDF Validation: PDF/A-3, Factur-X XMP metadata - VeraPDF: Strict PDF/A validation (146+ ISO 19005-3 rules) ### ✍️ Electronic Signature - Standards: PAdES-B-B, PAdES-B-T (RFC 3161 timestamping), PAdES-B-LT (long-term archival) - eIDAS Levels: SES (self-signed), AdES (commercial CA), QES (QTSP) - Validation: Cryptographic integrity and certificate verification ### 📋 Flux 6 - Invoice Lifecycle (CDAR) - CDAR Messages: Acknowledgements, invoice statuses - PPF Statuses: REFUSED (210), PAID (212) ### 📊 Flux 10 - E-Reporting - Tax Declarations: International B2B, B2C - Flow Types: 10.1 (B2B transactions), 10.2 (B2B payments), 10.3 (B2C transactions), 10.4 (B2C payments) ### 📡 AFNOR PDP/PA (XP Z12-013) - Flow Service: Submit and search flows to PDPs - Directory Service: Company search (SIREN/SIRET) - Multi-client: Support for multiple PDP configs per user ### 🏛️ Chorus Pro - Public Sector Invoicing: Complete API for Chorus Pro ### ⏳ Async Tasks - Celery: Asynchronous generation, validation and signing - Polling: Status tracking via /tasks/{task_id}/status - Webhooks: Automatic notifications when tasks complete ## 🔒 Authentication All requests require a JWT token in the Authorization header: Authorization: Bearer YOUR_JWT_TOKEN ### How to obtain a JWT token? #### 🔑 Method 1: /api/token/ API (Recommended) URL: https://factpulse.fr/api/token/ This method is recommended for integration in your applications and CI/CD workflows. Prerequisites: Having set a password on your account For users registered via email/password: - You already have a password, use it directly For users registered via OAuth (Google/GitHub): - You must first set a password at: https://factpulse.fr/accounts/password/set/ - Once the password is created, you can use the API Request example: bash curl -X POST https://factpulse.fr/api/token/ \\ -H \"Content-Type: application/json\" \\ -d '{ \"username\": \"[email protected]\", \"password\": \"your_password\" }' Optional client_uid parameter: To select credentials for a specific client (PA/PDP, Chorus Pro, signing certificates), add client_uid: bash curl -X POST https://factpulse.fr/api/token/ \\ -H \"Content-Type: application/json\" \\ -d '{ \"username\": \"[email protected]\", \"password\": \"your_password\", \"client_uid\": \"550e8400-e29b-41d4-a716-446655440000\" }' The client_uid will be included in the JWT and allow the API to automatically use: - AFNOR/PDP credentials configured for this client - Chorus Pro credentials configured for this client - Electronic signature certificates configured for this client Response: json { \"access\": \"eyJ0eXAiOiJKV1QiLCJhbGc...\", // Access token (validity: 30 min) \"refresh\": \"eyJ0eXAiOiJKV1QiLCJhbGc...\" // Refresh token (validity: 7 days) } Advantages: - ✅ Full automation (CI/CD, scripts) - ✅ Programmatic token management - ✅ Refresh token support for automatic access renewal - ✅ Easy integration in any language/tool #### 🖥️ Method 2: Dashboard Generation (Alternative) URL: https://factpulse.fr/api/dashboard/ This method is suitable for quick tests or occasional use via the graphical interface. How it works: - Log in to the dashboard - Use the "Generate Test Token" or "Generate Production Token" buttons - Works for all users (OAuth and email/password), without requiring a password Token types: - Test Token: 24h validity, 1000 calls/day quota (free) - Production Token: 7 days validity, quota based on your plan Advantages: - ✅ Quick for API testing - ✅ No password required - ✅ Simple visual interface Disadvantages: - ❌ Requires manual action - ❌ No refresh token - ❌ Less suited for automation ### 📚 Full Documentation For more information on authentication and API usage: https://factpulse.fr/documentation-api/
The version of the OpenAPI document: 1.0.0 Contact: [email protected] Generated by: https://openapi-generator.tech Generator version: 7.21.0-SNAPSHOT
Defined Under Namespace
Modules: AFNORCallbackAuthentication, AFNORReasonCode, AllowanceTotalAmount, Amount, Amount1, Amount2, AmountDue, BaseAmount, Buyercountry, ChargeTotalAmount, ConversionTaskStatusResult, Currency, Destination, Encaisseamount, Encaisseamount1, GenerationTaskStatusResult, GlobalAllowanceAmount, GrossUnitPrice, Helpers, InvoiceLineAllowanceAmount, InvoiceTotalsPrepayment, LineNetAmount, LineTotalAmount, LocationInner, ManualRate, ManualVatRate, Percentage, PriceAllowanceAmount, PriceBasisQuantity, Quantity, Rate, Rate1, RoundingAmount, Sellercountry, SignatureTaskStatusResult, SubmitGrossAmount, SubmitNetAmount, SubmitVatAmount, TaxableAmount, Taxableamount, Taxamount, Taxamount1, Taxamount2, Taxexclusiveamount, Taxexclusiveamount1, TotalGrossAmount, TotalNetAmount, TotalVATAmount, UnitNetPrice, VATAmount, ValidationTaskStatusResult, VatRate, VerificationTypedTaskStatusResult Classes: AFNORAcknowledgement, AFNORAcknowledgementDetail, AFNORAddressRead, AFNORAlgorithm, AFNORBasicAuthentication, AFNORCallbackHeader, AFNORCallbackParameters, AFNORCallbackSignature, AFNORContainsOperator, AFNORContainsOrStrictOperator, AFNORCoreFlowInfo, AFNORCredentials, AFNORDestination, AFNORDirectoryLineField, AFNORDirectoryLinePayloadHistoryLegalUnitFacilityRoutingCodeRoutingCode, AFNORDirectoryLinePayloadLegalUnitFacilityRoutingCode, AFNORDirectoryLinePayloadStatusLegalUnitFacilityRoutingCode, AFNORDirectoryLineSearchPost200Response, AFNORDirectoryLineStatus, AFNOREntityType, AFNORError, AFNORErrorDetail, AFNORFacilityAdministrativeStatus, AFNORFacilityPayloadHistory, AFNORFacilityPayloadHistoryUleB2gAdditionalData, AFNORFacilityPayloadIncluded, AFNORFacilityType, AFNORFlow, AFNORFlowAckStatus, AFNORFlowDirection, AFNORFlowExtension, AFNORFlowInfo, AFNORFlowInfoExtension, AFNORFlowProfile, AFNORFlowSyntax, AFNORFlowType, AFNORFullFlowInfo, AFNORFullFlowInfoExtension, AFNORHealthCheckResponse, AFNORLegalUnitAdministrativeStatus, AFNORLegalUnitPayloadHistory, AFNORLegalUnitPayloadIncluded, AFNOROAuth2Authentication, AFNORPDPPAApi, AFNORPDPPADirectoryServiceApi, AFNORPDPPAFlowServiceApi, AFNORProcessingRule, AFNORReasonCodeEnum, AFNORRecipientPlatformType, AFNORResult, AFNORRoutingCodeAdministrativeStatus, AFNORRoutingCodeField, AFNORRoutingCodePayloadHistoryLegalUnitFacility, AFNORRoutingCodeSearch, AFNORRoutingCodeSearchFilters, AFNORRoutingCodeSearchFiltersAdministrativeStatus, AFNORRoutingCodeSearchFiltersRoutingCodeName, AFNORRoutingCodeSearchFiltersRoutingIdentifier, AFNORRoutingCodeSearchPost200Response, AFNORRoutingCodeSearchSortingInner, AFNORSearchDirectoryLine, AFNORSearchDirectoryLineFilters, AFNORSearchDirectoryLineFiltersAddressingIdentifier, AFNORSearchDirectoryLineFiltersAddressingSuffix, AFNORSearchDirectoryLineSortingInner, AFNORSearchFlowContent, AFNORSearchFlowFilters, AFNORSearchFlowParams, AFNORSearchSiren, AFNORSearchSirenFilters, AFNORSearchSirenFiltersAdministrativeStatus, AFNORSearchSirenFiltersBusinessName, AFNORSearchSirenFiltersEntityType, AFNORSearchSirenFiltersSiren, AFNORSearchSirenSortingInner, AFNORSearchSiret, AFNORSearchSiretFilters, AFNORSearchSiretFiltersAddressLines, AFNORSearchSiretFiltersAdministrativeStatus, AFNORSearchSiretFiltersCountrySubdivision, AFNORSearchSiretFiltersFacilityType, AFNORSearchSiretFiltersLocality, AFNORSearchSiretFiltersName, AFNORSearchSiretFiltersPostalCode, AFNORSearchSiretFiltersSiret, AFNORSearchSiretSortingInner, AFNORSirenField, AFNORSirenInstructions, AFNORSirenSearchPost200Response, AFNORSiretField, AFNORSiretInstructions, AFNORSiretSearchPost200Response, AFNORSortingOrder, AFNORStrictOperator, AFNORStrictOrStartWithOperator, AFNORWebhook, AFNORWebhookIdParam, AFNORWebhookMetadata, AFNORWebhookParams, AFNORWebhookPatchPayload, APIError, APIProfile, AcknowledgmentStatus, ActionCodeInfo, ActionCodesResponse, AdditionalDocument, AggregatedPaymentInput, AggregatedTransactionInput, AllowanceCharge, AllowanceChargeReasonCode, AllowanceReasonCode, ApiClient, ApiError, ApiModelBase, AsyncTaskStatus, AsyncTasksApi, AuthError, BoundingBoxSchema, CeleryStatus, CertificateInfoResponse, ChorusProApi, ChorusProCredentials, ChorusProDestination, ChorusProResult, Client, ClientActivateResponse, ClientCreateRequest, ClientDetail, ClientListResponse, ClientManagementApi, ClientSummary, ClientUpdateRequest, Configuration, Contact, ConversionErrorResult, ConversionExtractionInfo, ConversionPendingInputResult, ConversionSuccessTaskResult, ConversionTaskStatus, ConversionValidationFailedResult, ConvertResumeRequest, ConvertSuccessResponse, ConvertValidationFailedResponse, CountryCode, CreateAggregatedReportRequest, CreateCDARRequest, CreateEReportingRequest, CurrencyCode, DeliveryParty, DocType, DocumentTypeInfo, DownloadsApi, EReportingFlowType, EReportingValidationError, ElectronicAddress, ElectronicSignatureApi, EncaisseeRequest, EnrichedInvoiceInfo, Error, ErrorLevel, ErrorSource, ExtractionInfo, FacturXConversionApi, FacturXInvoice, FacturXPDFInfo, FacturXPDFXMLVerificationApi, FacturXValidationApi, FactureElectroniqueRestApiSchemasCdarValidationErrorResponse, FactureElectroniqueRestApiSchemasEreportingInvoiceTypeCode, FactureElectroniqueRestApiSchemasProcessingChorusProCredentials, FieldStatus, FileInfo, FilesInfo, FlowDirection, FlowProfile, FlowSummary, FlowSyntax, FlowType, Flux10EReportingApi, Flux6InvoiceLifecycleCDARApi, GenerateAggregatedReportResponse, GenerateCDARResponse, GenerateCertificateRequest, GenerateCertificateResponse, GenerateEReportingResponse, GenerationSuccessResult, GenerationTaskStatus, GetChorusProIdRequest, GetChorusProIdResponse, GetInvoiceRequest, GetInvoiceResponse, GetStructureRequest, GetStructureResponse, HTTPValidationError, HealthApi, IncomingInvoice, IncomingSupplier, InvoiceFormat, InvoiceGenerationApi, InvoiceInput, InvoiceLifecycle, InvoiceLine, InvoiceNote, InvoicePaymentInput, InvoiceReferences, InvoiceStatus, InvoiceTotals, InvoiceTypeCode, InvoiceTypeCodeOutput, InvoicingFramework, InvoicingFrameworkCode, IssuerRoleCode, KeyRotationRequest, KeyRotationResponse, LifecycleEvent, LifecycleResponse, LineSubType, MandatoryNoteSchema, MissingField, OperationNature, OutputFormat, PDFValidationResultAPI, PDPConfigResponse, PDPConfigUpdateRequest, PDPCredentials, PageDimensionsSchema, ParseApi, ParseFacturXResponse, Payee, PaymentAmountByRate, PaymentCard, PaymentMeans, PollingTimeout, PostalAddress, ProcessingOptions, ProcessingRule, ProductCharacteristic, ProductClassification, ReasonCodeInfo, ReasonCodesResponse, Recipient, RecipientInput, ReferencesApi, RefuseeRequest, ReportIssuer, ReportPeriod, ReportSender, SchematronValidationError, SchemeID, SearchFlowRequest, SearchFlowResponse, SearchServicesResponse, SearchStructureRequest, SearchStructureResponse, SecretStatus, SignatureInfo, SignatureInfoAPI, SignatureParameters, SignatureSuccessResult, SignatureTaskStatus, SimplifiedCDARResponse, SimplifiedInvoiceData, StatusCodeInfo, StatusCodesResponse, StructureInfo, StructureParameters, StructureService, SubmissionMode, SubmitAggregatedReportRequest, SubmitCDARRequest, SubmitCDARResponse, SubmitCDARXMLRequest, SubmitCompleteInvoiceRequest, SubmitCompleteInvoiceResponse, SubmitEReportingRequest, SubmitEReportingResponse, SubmitFlowRequest, SubmitFlowResponse, SubmitInvoiceRequest, SubmitInvoiceResponse, SupplementaryAttachment, Supplier, TaskErrorResult, TaskResponse, TaxBreakdownInput, TaxDueDateType, TaxRepresentative, TransactionCategory, TransmissionTypeCode, UnitOfMeasure, VATAccountingCode, VATCategory, VATEXCodeInfo, VATEXCodesResponse, VATLine, VATPointDateCode, ValidateCDARRequest, ValidateCDARResponse, ValidateEReportingRequest, ValidateEReportingResponse, ValidationApi, ValidationError, ValidationErrorDetail, ValidationErrorResponse, ValidationInfo, ValidationSuccessResponse, ValidationSuccessTaskResult, ValidationTaskStatus, VerificationSuccessResponse, VerificationSuccessTaskResult, VerificationTypedTaskStatus, VerifiedFieldSchema, WebhookSecretDeleteResponse, WebhookSecretGenerateResponse, WebhookSecretStatusResponse
Constant Summary collapse
- VERSION =
'4.3.0'
Class Method Summary collapse
-
.configure ⇒ Object
Customize default settings for the SDK using block.
Class Method Details
.configure ⇒ Object
Customize default settings for the SDK using block. FactPulse.configure do |config| config.username = "xxx" config.password = "xxx" end If no block given, return the default Configuration object.
391 392 393 394 395 396 397 |
# File 'lib/factpulse.rb', line 391 def configure if block_given? yield(Configuration.default) else Configuration.default end end |