Class: FactPulse::AFNORAddressEdit
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::AFNORAddressEdit
- Defined in:
- lib/factpulse/models/afnor_address_edit.rb
Overview
Wrapper for postal addresses without country name.
Instance Attribute Summary collapse
-
#code_pays ⇒ Object
Corresponds to the country of the recipient structure.
-
#country_subdivision ⇒ Object
Subdivision of the country.
-
#ligne_adresse1 ⇒ Object
Corresponds to the address of the recipient structure having defined the directory line(s).
-
#ligne_adresse2 ⇒ Object
Corresponds to the address of the recipient structure having defined the directory line(s).
-
#ligne_adresse3 ⇒ Object
Corresponds to the address of the recipient structure having defined the directory line(s).
-
#locality ⇒ Object
Municipality of the recipient structure having defined the directory line(s).
-
#postal_code ⇒ Object
Service postal code.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AFNORAddressEdit
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AFNORAddressEdit
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORAddressEdit` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORAddressEdit`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ligne_adresse1') self.ligne_adresse1 = attributes[:'ligne_adresse1'] end if attributes.key?(:'ligne_adresse2') self.ligne_adresse2 = attributes[:'ligne_adresse2'] end if attributes.key?(:'ligne_adresse3') self.ligne_adresse3 = attributes[:'ligne_adresse3'] end if attributes.key?(:'postal_code') self.postal_code = attributes[:'postal_code'] end if attributes.key?(:'country_subdivision') self.country_subdivision = attributes[:'country_subdivision'] end if attributes.key?(:'locality') self.locality = attributes[:'locality'] end if attributes.key?(:'code_pays') self.code_pays = attributes[:'code_pays'] end end |
Instance Attribute Details
#code_pays ⇒ Object
Corresponds to the country of the recipient structure.
38 39 40 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 38 def code_pays @code_pays end |
#country_subdivision ⇒ Object
Subdivision of the country
32 33 34 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 32 def country_subdivision @country_subdivision end |
#ligne_adresse1 ⇒ Object
Corresponds to the address of the recipient structure having defined the directory line(s).
20 21 22 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 20 def ligne_adresse1 @ligne_adresse1 end |
#ligne_adresse2 ⇒ Object
Corresponds to the address of the recipient structure having defined the directory line(s).
23 24 25 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 23 def ligne_adresse2 @ligne_adresse2 end |
#ligne_adresse3 ⇒ Object
Corresponds to the address of the recipient structure having defined the directory line(s).
26 27 28 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 26 def ligne_adresse3 @ligne_adresse3 end |
#locality ⇒ Object
Municipality of the recipient structure having defined the directory line(s).
35 36 37 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 35 def locality @locality end |
#postal_code ⇒ Object
Service postal code
29 30 31 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 29 def postal_code @postal_code end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 41 def self.attribute_map { :'ligne_adresse1' => :'ligneAdresse1', :'ligne_adresse2' => :'ligneAdresse2', :'ligne_adresse3' => :'ligneAdresse3', :'postal_code' => :'postalCode', :'country_subdivision' => :'countrySubdivision', :'locality' => :'locality', :'code_pays' => :'codePays' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 315 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 64 def self.openapi_types { :'ligne_adresse1' => :'String', :'ligne_adresse2' => :'String', :'ligne_adresse3' => :'String', :'postal_code' => :'String', :'country_subdivision' => :'String', :'locality' => :'String', :'code_pays' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 288 def ==(o) return true if self.equal?(o) self.class == o.class && ligne_adresse1 == o.ligne_adresse1 && ligne_adresse2 == o.ligne_adresse2 && ligne_adresse3 == o.ligne_adresse3 && postal_code == o.postal_code && country_subdivision == o.country_subdivision && locality == o.locality && code_pays == o.code_pays end |
#eql?(o) ⇒ Boolean
302 303 304 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 302 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
308 309 310 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 308 def hash [ligne_adresse1, ligne_adresse2, ligne_adresse3, postal_code, country_subdivision, locality, code_pays].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 129 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@ligne_adresse1.nil? && @ligne_adresse1.to_s.length > 255 invalid_properties.push('invalid value for "ligne_adresse1", the character length must be smaller than or equal to 255.') end if !@ligne_adresse2.nil? && @ligne_adresse2.to_s.length > 255 invalid_properties.push('invalid value for "ligne_adresse2", the character length must be smaller than or equal to 255.') end if !@ligne_adresse3.nil? && @ligne_adresse3.to_s.length > 255 invalid_properties.push('invalid value for "ligne_adresse3", the character length must be smaller than or equal to 255.') end if !@postal_code.nil? && @postal_code.to_s.length > 5 invalid_properties.push('invalid value for "postal_code", the character length must be smaller than or equal to 5.') end pattern = Regexp.new(/[0-9]*/) if !@postal_code.nil? && @postal_code !~ pattern invalid_properties.push("invalid value for \"postal_code\", must conform to the pattern #{pattern}.") end if !@country_subdivision.nil? && @country_subdivision.to_s.length > 255 invalid_properties.push('invalid value for "country_subdivision", the character length must be smaller than or equal to 255.') end if !@locality.nil? && @locality.to_s.length > 100 invalid_properties.push('invalid value for "locality", the character length must be smaller than or equal to 100.') end if !@code_pays.nil? && @code_pays.to_s.length > 2 invalid_properties.push('invalid value for "code_pays", the character length must be smaller than or equal to 2.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 337 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/factpulse/models/afnor_address_edit.rb', line 170 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@ligne_adresse1.nil? && @ligne_adresse1.to_s.length > 255 return false if !@ligne_adresse2.nil? && @ligne_adresse2.to_s.length > 255 return false if !@ligne_adresse3.nil? && @ligne_adresse3.to_s.length > 255 return false if !@postal_code.nil? && @postal_code.to_s.length > 5 return false if !@postal_code.nil? && @postal_code !~ Regexp.new(/[0-9]*/) return false if !@country_subdivision.nil? && @country_subdivision.to_s.length > 255 return false if !@locality.nil? && @locality.to_s.length > 100 return false if !@code_pays.nil? && @code_pays.to_s.length > 2 true end |