Class: FactPulse::AFNORAddressRead

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/afnor_address_read.rb

Overview

Wrapper for postal addresses

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AFNORAddressRead

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/factpulse/models/afnor_address_read.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORAddressRead` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORAddressRead`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'address_line1')
    self.address_line1 = attributes[:'address_line1']
  end

  if attributes.key?(:'address_line2')
    self.address_line2 = attributes[:'address_line2']
  end

  if attributes.key?(:'address_line3')
    self.address_line3 = attributes[:'address_line3']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'country_subdivision')
    self.country_subdivision = attributes[:'country_subdivision']
  end

  if attributes.key?(:'locality')
    self.locality = attributes[:'locality']
  end

  if attributes.key?(:'country_code')
    self.country_code = attributes[:'country_code']
  end

  if attributes.key?(:'country_name')
    self.country_name = attributes[:'country_name']
  end
end

Instance Attribute Details

#address_line1Object

Corresponds to the address of the recipient structure having defined the directory line(s).



20
21
22
# File 'lib/factpulse/models/afnor_address_read.rb', line 20

def address_line1
  @address_line1
end

#address_line2Object

Corresponds to the address of the recipient structure having defined the directory line(s).



23
24
25
# File 'lib/factpulse/models/afnor_address_read.rb', line 23

def address_line2
  @address_line2
end

#address_line3Object

Corresponds to the address of the recipient structure having defined the directory line(s).



26
27
28
# File 'lib/factpulse/models/afnor_address_read.rb', line 26

def address_line3
  @address_line3
end

#country_codeObject

Corresponds to the country of the recipient structure.



38
39
40
# File 'lib/factpulse/models/afnor_address_read.rb', line 38

def country_code
  @country_code
end

#country_nameObject

Corresponds to the country of the recipient structure having defined the directory line(s).



41
42
43
# File 'lib/factpulse/models/afnor_address_read.rb', line 41

def country_name
  @country_name
end

#country_subdivisionObject

Subdivision of the country



32
33
34
# File 'lib/factpulse/models/afnor_address_read.rb', line 32

def country_subdivision
  @country_subdivision
end

#localityObject

Municipality of the recipient structure having defined the directory line(s).



35
36
37
# File 'lib/factpulse/models/afnor_address_read.rb', line 35

def locality
  @locality
end

#postal_codeObject

Service postal code



29
30
31
# File 'lib/factpulse/models/afnor_address_read.rb', line 29

def postal_code
  @postal_code
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/factpulse/models/afnor_address_read.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/factpulse/models/afnor_address_read.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/factpulse/models/afnor_address_read.rb', line 44

def self.attribute_map
  {
    :'address_line1' => :'addressLine1',
    :'address_line2' => :'addressLine2',
    :'address_line3' => :'addressLine3',
    :'postal_code' => :'postalCode',
    :'country_subdivision' => :'countrySubdivision',
    :'locality' => :'locality',
    :'country_code' => :'countryCode',
    :'country_name' => :'countryName'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/factpulse/models/afnor_address_read.rb', line 344

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/factpulse/models/afnor_address_read.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/factpulse/models/afnor_address_read.rb', line 68

def self.openapi_types
  {
    :'address_line1' => :'String',
    :'address_line2' => :'String',
    :'address_line3' => :'String',
    :'postal_code' => :'String',
    :'country_subdivision' => :'String',
    :'locality' => :'String',
    :'country_code' => :'String',
    :'country_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/factpulse/models/afnor_address_read.rb', line 316

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      address_line1 == o.address_line1 &&
      address_line2 == o.address_line2 &&
      address_line3 == o.address_line3 &&
      postal_code == o.postal_code &&
      country_subdivision == o.country_subdivision &&
      locality == o.locality &&
      country_code == o.country_code &&
      country_name == o.country_name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


331
332
333
# File 'lib/factpulse/models/afnor_address_read.rb', line 331

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



337
338
339
# File 'lib/factpulse/models/afnor_address_read.rb', line 337

def hash
  [address_line1, address_line2, address_line3, postal_code, country_subdivision, locality, country_code, country_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/factpulse/models/afnor_address_read.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@address_line1.nil? && @address_line1.to_s.length > 255
    invalid_properties.push('invalid value for "address_line1", the character length must be smaller than or equal to 255.')
  end

  if !@address_line2.nil? && @address_line2.to_s.length > 255
    invalid_properties.push('invalid value for "address_line2", the character length must be smaller than or equal to 255.')
  end

  if !@address_line3.nil? && @address_line3.to_s.length > 255
    invalid_properties.push('invalid value for "address_line3", the character length must be smaller than or equal to 255.')
  end

  if !@postal_code.nil? && @postal_code.to_s.length > 5
    invalid_properties.push('invalid value for "postal_code", the character length must be smaller than or equal to 5.')
  end

  pattern = Regexp.new(/[0-9]*/)
  if !@postal_code.nil? && @postal_code !~ pattern
    invalid_properties.push("invalid value for \"postal_code\", must conform to the pattern #{pattern}.")
  end

  if !@country_subdivision.nil? && @country_subdivision.to_s.length > 255
    invalid_properties.push('invalid value for "country_subdivision", the character length must be smaller than or equal to 255.')
  end

  if !@locality.nil? && @locality.to_s.length > 100
    invalid_properties.push('invalid value for "locality", the character length must be smaller than or equal to 100.')
  end

  if !@country_code.nil? && @country_code.to_s.length > 2
    invalid_properties.push('invalid value for "country_code", the character length must be smaller than or equal to 2.')
  end

  if !@country_name.nil? && @country_name.to_s.length > 100
    invalid_properties.push('invalid value for "country_name", the character length must be smaller than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/factpulse/models/afnor_address_read.rb', line 366

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/factpulse/models/afnor_address_read.rb', line 183

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@address_line1.nil? && @address_line1.to_s.length > 255
  return false if !@address_line2.nil? && @address_line2.to_s.length > 255
  return false if !@address_line3.nil? && @address_line3.to_s.length > 255
  return false if !@postal_code.nil? && @postal_code.to_s.length > 5
  return false if !@postal_code.nil? && @postal_code !~ Regexp.new(/[0-9]*/)
  return false if !@country_subdivision.nil? && @country_subdivision.to_s.length > 255
  return false if !@locality.nil? && @locality.to_s.length > 100
  return false if !@country_code.nil? && @country_code.to_s.length > 2
  return false if !@country_name.nil? && @country_name.to_s.length > 100
  true
end