Class: FactPulse::AFNORCoreFlowInfo
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::AFNORCoreFlowInfo
- Defined in:
- lib/factpulse/models/afnor_core_flow_info.rb
Overview
Core schema to build FlowInfo, FullFlowInfo, Flow schemas
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#flow_profile ⇒ Object
Returns the value of attribute flow_profile.
-
#flow_syntax ⇒ Object
Returns the value of attribute flow_syntax.
-
#name ⇒ Object
Name of the file.
-
#processing_rule ⇒ Object
Returns the value of attribute processing_rule.
-
#tracking_id ⇒ Object
The tracking id is an external identifier and is used to track the flow by the sender.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AFNORCoreFlowInfo
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AFNORCoreFlowInfo
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORCoreFlowInfo` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORCoreFlowInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tracking_id') self.tracking_id = attributes[:'tracking_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'processing_rule') self.processing_rule = attributes[:'processing_rule'] end if attributes.key?(:'flow_syntax') self.flow_syntax = attributes[:'flow_syntax'] else self.flow_syntax = nil end if attributes.key?(:'flow_profile') self.flow_profile = attributes[:'flow_profile'] end end |
Instance Attribute Details
#flow_profile ⇒ Object
Returns the value of attribute flow_profile.
29 30 31 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 29 def flow_profile @flow_profile end |
#flow_syntax ⇒ Object
Returns the value of attribute flow_syntax.
27 28 29 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 27 def flow_syntax @flow_syntax end |
#name ⇒ Object
Name of the file
23 24 25 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 23 def name @name end |
#processing_rule ⇒ Object
Returns the value of attribute processing_rule.
25 26 27 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 25 def processing_rule @processing_rule end |
#tracking_id ⇒ Object
The tracking id is an external identifier and is used to track the flow by the sender
20 21 22 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 20 def tracking_id @tracking_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
65 66 67 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 65 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 70 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 54 def self.attribute_map { :'tracking_id' => :'trackingId', :'name' => :'name', :'processing_rule' => :'processingRule', :'flow_syntax' => :'flowSyntax', :'flow_profile' => :'flowProfile' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 232 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 75 def self.openapi_types { :'tracking_id' => :'String', :'name' => :'String', :'processing_rule' => :'AFNORProcessingRule', :'flow_syntax' => :'AFNORFlowSyntax', :'flow_profile' => :'AFNORFlowProfile' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
207 208 209 210 211 212 213 214 215 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 207 def ==(o) return true if self.equal?(o) self.class == o.class && tracking_id == o.tracking_id && name == o.name && processing_rule == o.processing_rule && flow_syntax == o.flow_syntax && flow_profile == o.flow_profile end |
#eql?(o) ⇒ Boolean
219 220 221 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 219 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
225 226 227 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 225 def hash [tracking_id, name, processing_rule, flow_syntax, flow_profile].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 134 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@tracking_id.nil? && @tracking_id.to_s.length > 36 invalid_properties.push('invalid value for "tracking_id", the character length must be smaller than or equal to 36.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 255 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.') end if @flow_syntax.nil? invalid_properties.push('invalid value for "flow_syntax", flow_syntax cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 254 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
158 159 160 161 162 163 164 165 |
# File 'lib/factpulse/models/afnor_core_flow_info.rb', line 158 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@tracking_id.nil? && @tracking_id.to_s.length > 36 return false if @name.nil? return false if @name.to_s.length > 255 return false if @flow_syntax.nil? true end |