Class: FactPulse::AFNORCreateDirectoryLineBodyAddressingInformation

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AFNORCreateDirectoryLineBodyAddressingInformation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORCreateDirectoryLineBodyAddressingInformation` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORCreateDirectoryLineBodyAddressingInformation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'siren')
    self.siren = attributes[:'siren']
  else
    self.siren = nil
  end

  if attributes.key?(:'siret')
    self.siret = attributes[:'siret']
  end

  if attributes.key?(:'routing_identifier')
    self.routing_identifier = attributes[:'routing_identifier']
  end

  if attributes.key?(:'addressing_suffix')
    self.addressing_suffix = attributes[:'addressing_suffix']
  end
end

Instance Attribute Details

#addressing_suffix ⇒ Object

suffix of the directory line which defines an address mesh not attached to a facility



28
29
30
# File 'lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb', line 28

def addressing_suffix
  @addressing_suffix
end

#routing_identifier ⇒ Object

Routing identifier od a routing code.



25
26
27
# File 'lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb', line 25

def routing_identifier
  @routing_identifier
end

#siren ⇒ Object

SIREN number



19
20
21
# File 'lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb', line 19

def siren
  @siren
end

#siret ⇒ Object

SIRET Number



22
23
24
# File 'lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb', line 22

def siret
  @siret
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



41
42
43
# File 'lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb', line 31

def self.attribute_map
  {
    :'siren' => :'siren',
    :'siret' => :'siret',
    :'routing_identifier' => :'routingIdentifier',
    :'addressing_suffix' => :'addressingSuffix'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb', line 256

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



61
62
63
64
# File 'lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb', line 51

def self.openapi_types
  {
    :'siren' => :'String',
    :'siret' => :'String',
    :'routing_identifier' => :'String',
    :'addressing_suffix' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



232
233
234
235
236
237
238
239
# File 'lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb', line 232

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      siren == o.siren &&
      siret == o.siret &&
      routing_identifier == o.routing_identifier &&
      addressing_suffix == o.addressing_suffix
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


243
244
245
# File 'lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb', line 243

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



249
250
251
# File 'lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb', line 249

def hash
  [siren, siret, routing_identifier, addressing_suffix].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb', line 103

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @siren.nil?
    invalid_properties.push('invalid value for "siren", siren cannot be nil.')
  end

  if @siren.to_s.length > 9
    invalid_properties.push('invalid value for "siren", the character length must be smaller than or equal to 9.')
  end

  pattern = Regexp.new(/^([0-9]{9})$/)
  if @siren !~ pattern
    invalid_properties.push("invalid value for \"siren\", must conform to the pattern #{pattern}.")
  end

  if !@siret.nil? && @siret.to_s.length > 14
    invalid_properties.push('invalid value for "siret", the character length must be smaller than or equal to 14.')
  end

  pattern = Regexp.new(/^([0-9]{14})$/)
  if !@siret.nil? && @siret !~ pattern
    invalid_properties.push("invalid value for \"siret\", must conform to the pattern #{pattern}.")
  end

  if !@routing_identifier.nil? && @routing_identifier.to_s.length > 100
    invalid_properties.push('invalid value for "routing_identifier", the character length must be smaller than or equal to 100.')
  end

  pattern = Regexp.new(/^(?!\s+$)[\-_\/a-zA-Z0-9]{1,100}$/)
  if !@routing_identifier.nil? && @routing_identifier !~ pattern
    invalid_properties.push("invalid value for \"routing_identifier\", must conform to the pattern #{pattern}.")
  end

  if !@addressing_suffix.nil? && @addressing_suffix.to_s.length > 100
    invalid_properties.push('invalid value for "addressing_suffix", the character length must be smaller than or equal to 100.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb', line 278

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/factpulse/models/afnor_create_directory_line_body_addressing_information.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @siren.nil?
  return false if @siren.to_s.length > 9
  return false if @siren !~ Regexp.new(/^([0-9]{9})$/)
  return false if !@siret.nil? && @siret.to_s.length > 14
  return false if !@siret.nil? && @siret !~ Regexp.new(/^([0-9]{14})$/)
  return false if !@routing_identifier.nil? && @routing_identifier.to_s.length > 100
  return false if !@routing_identifier.nil? && @routing_identifier !~ Regexp.new(/^(?!\s+$)[\-_\/a-zA-Z0-9]{1,100}$/)
  return false if !@addressing_suffix.nil? && @addressing_suffix.to_s.length > 100
  true
end