Class: FactPulse::AFNORDirectoryLinePayloadHistoryLegalUnitFacilityRoutingCode
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::AFNORDirectoryLinePayloadHistoryLegalUnitFacilityRoutingCode
- Defined in:
- lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb
Instance Attribute Summary collapse
-
#addressing_identifier ⇒ Object
Addressing identifier of the directory line.
-
#addressing_suffix ⇒ Object
suffix of the directory line which defines an address mesh not attached to a facility.
-
#facility ⇒ Object
Returns the value of attribute facility.
-
#legal_unit ⇒ Object
Returns the value of attribute legal_unit.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#routing_code ⇒ Object
Returns the value of attribute routing_code.
-
#siren ⇒ Object
SIREN number.
-
#siret ⇒ Object
SIRET Number.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AFNORDirectoryLinePayloadHistoryLegalUnitFacilityRoutingCode
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AFNORDirectoryLinePayloadHistoryLegalUnitFacilityRoutingCode
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORDirectoryLinePayloadHistoryLegalUnitFacilityRoutingCode` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORDirectoryLinePayloadHistoryLegalUnitFacilityRoutingCode`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'addressing_identifier') self.addressing_identifier = attributes[:'addressing_identifier'] end if attributes.key?(:'siren') self.siren = attributes[:'siren'] end if attributes.key?(:'siret') self.siret = attributes[:'siret'] end if attributes.key?(:'addressing_suffix') self.addressing_suffix = attributes[:'addressing_suffix'] end if attributes.key?(:'routing_code') self.routing_code = attributes[:'routing_code'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'legal_unit') self.legal_unit = attributes[:'legal_unit'] end if attributes.key?(:'facility') self.facility = attributes[:'facility'] end end |
Instance Attribute Details
#addressing_identifier ⇒ Object
Addressing identifier of the directory line.
19 20 21 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 19 def addressing_identifier @addressing_identifier end |
#addressing_suffix ⇒ Object
suffix of the directory line which defines an address mesh not attached to a facility
28 29 30 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 28 def addressing_suffix @addressing_suffix end |
#facility ⇒ Object
Returns the value of attribute facility.
36 37 38 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 36 def facility @facility end |
#legal_unit ⇒ Object
Returns the value of attribute legal_unit.
34 35 36 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 34 def legal_unit @legal_unit end |
#platform ⇒ Object
Returns the value of attribute platform.
32 33 34 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 32 def platform @platform end |
#routing_code ⇒ Object
Returns the value of attribute routing_code.
30 31 32 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 30 def routing_code @routing_code end |
#siren ⇒ Object
SIREN number
22 23 24 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 22 def siren @siren end |
#siret ⇒ Object
SIRET Number
25 26 27 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 25 def siret @siret end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 39 def self.attribute_map { :'addressing_identifier' => :'addressingIdentifier', :'siren' => :'siren', :'siret' => :'siret', :'addressing_suffix' => :'addressingSuffix', :'routing_code' => :'routingCode', :'platform' => :'platform', :'legal_unit' => :'legalUnit', :'facility' => :'facility' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 274 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 63 def self.openapi_types { :'addressing_identifier' => :'String', :'siren' => :'String', :'siret' => :'String', :'addressing_suffix' => :'String', :'routing_code' => :'AFNORDirectoryLinePayloadHistoryLegalUnitFacilityRoutingCodeRoutingCode', :'platform' => :'AFNORDirectoryLinePayloadHistoryLegalUnitFacilityRoutingCodePlatform', :'legal_unit' => :'AFNORLegalUnitPayloadIncludedNoSiren', :'facility' => :'AFNORFacilityPayloadIncluded' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 246 def ==(o) return true if self.equal?(o) self.class == o.class && addressing_identifier == o.addressing_identifier && siren == o.siren && siret == o.siret && addressing_suffix == o.addressing_suffix && routing_code == o.routing_code && platform == o.platform && legal_unit == o.legal_unit && facility == o.facility end |
#eql?(o) ⇒ Boolean
261 262 263 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 261 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
267 268 269 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 267 def hash [addressing_identifier, siren, siret, addressing_suffix, routing_code, platform, legal_unit, facility].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 133 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@addressing_identifier.nil? && @addressing_identifier.to_s.length > 125 invalid_properties.push('invalid value for "addressing_identifier", the character length must be smaller than or equal to 125.') end if !@siren.nil? && @siren.to_s.length > 9 invalid_properties.push('invalid value for "siren", the character length must be smaller than or equal to 9.') end pattern = Regexp.new(/^([0-9]{9})$/) if !@siren.nil? && @siren !~ pattern invalid_properties.push("invalid value for \"siren\", must conform to the pattern #{pattern}.") end if !@siret.nil? && @siret.to_s.length > 14 invalid_properties.push('invalid value for "siret", the character length must be smaller than or equal to 14.') end pattern = Regexp.new(/^([0-9]{14})$/) if !@siret.nil? && @siret !~ pattern invalid_properties.push("invalid value for \"siret\", must conform to the pattern #{pattern}.") end if !@addressing_suffix.nil? && @addressing_suffix.to_s.length > 100 invalid_properties.push('invalid value for "addressing_suffix", the character length must be smaller than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 296 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
167 168 169 170 171 172 173 174 175 176 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code.rb', line 167 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@addressing_identifier.nil? && @addressing_identifier.to_s.length > 125 return false if !@siren.nil? && @siren.to_s.length > 9 return false if !@siren.nil? && @siren !~ Regexp.new(/^([0-9]{9})$/) return false if !@siret.nil? && @siret.to_s.length > 14 return false if !@siret.nil? && @siret !~ Regexp.new(/^([0-9]{14})$/) return false if !@addressing_suffix.nil? && @addressing_suffix.to_s.length > 100 true end |