Class: FactPulse::AFNORDirectoryLinePayloadHistoryLegalUnitFacilityRoutingCodeRoutingCode
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::AFNORDirectoryLinePayloadHistoryLegalUnitFacilityRoutingCodeRoutingCode
- Defined in:
- lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#administrative_status ⇒ Object
Returns the value of attribute administrative_status.
-
#manages_legal_commitment ⇒ Object
Indicates whether the public structure requires a legal commitment number.
-
#routing_code_name ⇒ Object
Name of the directory line routing code.
-
#routing_identifier ⇒ Object
Routing identifier od a routing code.
-
#routing_identifier_type ⇒ Object
Routing Identifier type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AFNORDirectoryLinePayloadHistoryLegalUnitFacilityRoutingCodeRoutingCode
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AFNORDirectoryLinePayloadHistoryLegalUnitFacilityRoutingCodeRoutingCode
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORDirectoryLinePayloadHistoryLegalUnitFacilityRoutingCodeRoutingCode` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORDirectoryLinePayloadHistoryLegalUnitFacilityRoutingCodeRoutingCode`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'routing_identifier') self.routing_identifier = attributes[:'routing_identifier'] end if attributes.key?(:'routing_identifier_type') self.routing_identifier_type = attributes[:'routing_identifier_type'] end if attributes.key?(:'routing_code_name') self.routing_code_name = attributes[:'routing_code_name'] end if attributes.key?(:'manages_legal_commitment') self.manages_legal_commitment = attributes[:'manages_legal_commitment'] end if attributes.key?(:'administrative_status') self.administrative_status = attributes[:'administrative_status'] end if attributes.key?(:'address') self.address = attributes[:'address'] end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
32 33 34 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 32 def address @address end |
#administrative_status ⇒ Object
Returns the value of attribute administrative_status.
30 31 32 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 30 def administrative_status @administrative_status end |
#manages_legal_commitment ⇒ Object
Indicates whether the public structure requires a legal commitment number. This attribute is only returned if the directory line is defined for a public structure at the SIREN / SIRET or SIREN / SIRET / Routing code level.
28 29 30 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 28 def manages_legal_commitment @manages_legal_commitment end |
#routing_code_name ⇒ Object
Name of the directory line routing code. This attribute is only returned if the directory line is defined at the SIREN / SIRET / Routing code mesh.
25 26 27 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 25 def routing_code_name @routing_code_name end |
#routing_identifier ⇒ Object
Routing identifier od a routing code.
19 20 21 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 19 def routing_identifier @routing_identifier end |
#routing_identifier_type ⇒ Object
Routing Identifier type.
22 23 24 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 22 def routing_identifier_type @routing_identifier_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 57 def self.attribute_map { :'routing_identifier' => :'routingIdentifier', :'routing_identifier_type' => :'routingIdentifierType', :'routing_code_name' => :'routingCodeName', :'manages_legal_commitment' => :'managesLegalCommitment', :'administrative_status' => :'administrativeStatus', :'address' => :'address' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 270 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 79 def self.openapi_types { :'routing_identifier' => :'String', :'routing_identifier_type' => :'String', :'routing_code_name' => :'String', :'manages_legal_commitment' => :'Boolean', :'administrative_status' => :'AFNORRoutingCodeAdministrativeStatus', :'address' => :'AFNORAddressRead' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
244 245 246 247 248 249 250 251 252 253 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 244 def ==(o) return true if self.equal?(o) self.class == o.class && routing_identifier == o.routing_identifier && routing_identifier_type == o.routing_identifier_type && routing_code_name == o.routing_code_name && manages_legal_commitment == o.manages_legal_commitment && administrative_status == o.administrative_status && address == o.address end |
#eql?(o) ⇒ Boolean
257 258 259 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 257 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
263 264 265 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 263 def hash [routing_identifier, routing_identifier_type, routing_code_name, manages_legal_commitment, administrative_status, address].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 139 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@routing_identifier.nil? && @routing_identifier.to_s.length > 100 invalid_properties.push('invalid value for "routing_identifier", the character length must be smaller than or equal to 100.') end pattern = Regexp.new(/^(?!\s+$)[\-_\/a-zA-Z0-9]{1,100}$/) if !@routing_identifier.nil? && @routing_identifier !~ pattern invalid_properties.push("invalid value for \"routing_identifier\", must conform to the pattern #{pattern}.") end if !@routing_identifier_type.nil? && @routing_identifier_type.to_s.length > 4 invalid_properties.push('invalid value for "routing_identifier_type", the character length must be smaller than or equal to 4.') end pattern = Regexp.new(/^(?!\s*$).+/) if !@routing_identifier_type.nil? && @routing_identifier_type !~ pattern invalid_properties.push("invalid value for \"routing_identifier_type\", must conform to the pattern #{pattern}.") end if !@routing_code_name.nil? && @routing_code_name.to_s.length > 100 invalid_properties.push('invalid value for "routing_code_name", the character length must be smaller than or equal to 100.') end pattern = Regexp.new(/^(?!\s*$).+/) if !@routing_code_name.nil? && @routing_code_name !~ pattern invalid_properties.push("invalid value for \"routing_code_name\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 292 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
174 175 176 177 178 179 180 181 182 183 |
# File 'lib/factpulse/models/afnor_directory_line_payload_history_legal_unit_facility_routing_code_routing_code.rb', line 174 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@routing_identifier.nil? && @routing_identifier.to_s.length > 100 return false if !@routing_identifier.nil? && @routing_identifier !~ Regexp.new(/^(?!\s+$)[\-_\/a-zA-Z0-9]{1,100}$/) return false if !@routing_identifier_type.nil? && @routing_identifier_type.to_s.length > 4 return false if !@routing_identifier_type.nil? && @routing_identifier_type !~ Regexp.new(/^(?!\s*$).+/) return false if !@routing_code_name.nil? && @routing_code_name.to_s.length > 100 return false if !@routing_code_name.nil? && @routing_code_name !~ Regexp.new(/^(?!\s*$).+/) true end |