Class: FactPulse::AFNORFlow

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/afnor_flow.rb

Overview

The properties of a Flow resource

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AFNORFlow

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/factpulse/models/afnor_flow.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORFlow` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORFlow`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'submitted_at')
    self. = attributes[:'submitted_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'flow_id')
    self.flow_id = attributes[:'flow_id']
  end

  if attributes.key?(:'tracking_id')
    self.tracking_id = attributes[:'tracking_id']
  end

  if attributes.key?(:'flow_type')
    self.flow_type = attributes[:'flow_type']
  end

  if attributes.key?(:'processing_rule')
    self.processing_rule = attributes[:'processing_rule']
  end

  if attributes.key?(:'processing_rule_source')
    self.processing_rule_source = attributes[:'processing_rule_source']
  end

  if attributes.key?(:'flow_direction')
    self.flow_direction = attributes[:'flow_direction']
  end

  if attributes.key?(:'flow_syntax')
    self.flow_syntax = attributes[:'flow_syntax']
  end

  if attributes.key?(:'flow_profile')
    self.flow_profile = attributes[:'flow_profile']
  end

  if attributes.key?(:'acknowledgement')
    self.acknowledgement = attributes[:'acknowledgement']
  end
end

Instance Attribute Details

#acknowledgement ⇒ Object

Returns the value of attribute acknowledgement.



44
45
46
# File 'lib/factpulse/models/afnor_flow.rb', line 44

def acknowledgement
  @acknowledgement
end

#flow_direction ⇒ Object

Returns the value of attribute flow_direction.



38
39
40
# File 'lib/factpulse/models/afnor_flow.rb', line 38

def flow_direction
  @flow_direction
end

#flow_id ⇒ Object

Unique identifier supporting UUID but not only, for flexibility purpose



26
27
28
# File 'lib/factpulse/models/afnor_flow.rb', line 26

def flow_id
  @flow_id
end

#flow_profile ⇒ Object

Returns the value of attribute flow_profile.



42
43
44
# File 'lib/factpulse/models/afnor_flow.rb', line 42

def flow_profile
  @flow_profile
end

#flow_syntax ⇒ Object

Returns the value of attribute flow_syntax.



40
41
42
# File 'lib/factpulse/models/afnor_flow.rb', line 40

def flow_syntax
  @flow_syntax
end

#flow_type ⇒ Object

Returns the value of attribute flow_type.



31
32
33
# File 'lib/factpulse/models/afnor_flow.rb', line 31

def flow_type
  @flow_type
end

#processing_rule ⇒ Object

Returns the value of attribute processing_rule.



33
34
35
# File 'lib/factpulse/models/afnor_flow.rb', line 33

def processing_rule
  @processing_rule
end

#processing_rule_source ⇒ Object

Says whether the processing rule has been computed or the processing rule was an input parameter



36
37
38
# File 'lib/factpulse/models/afnor_flow.rb', line 36

def processing_rule_source
  @processing_rule_source
end

#submitted_at ⇒ Object

The flow submission date and time (the date and time when the flow was created on the system)



20
21
22
# File 'lib/factpulse/models/afnor_flow.rb', line 20

def 
  @submitted_at
end

#tracking_id ⇒ Object

Unique identifier supporting UUID but not only, for flexibility purpose



29
30
31
# File 'lib/factpulse/models/afnor_flow.rb', line 29

def tracking_id
  @tracking_id
end

#updated_at ⇒ Object

The last update date and time of the flow. When the flow is submitted updatedAt is equal to submittedAt. When the flow acknowledgment status is changed updatedAt date and time is updated.



23
24
25
# File 'lib/factpulse/models/afnor_flow.rb', line 23

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



86
87
88
# File 'lib/factpulse/models/afnor_flow.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/factpulse/models/afnor_flow.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/factpulse/models/afnor_flow.rb', line 69

def self.attribute_map
  {
    :'submitted_at' => :'submittedAt',
    :'updated_at' => :'updatedAt',
    :'flow_id' => :'flowId',
    :'tracking_id' => :'trackingId',
    :'flow_type' => :'flowType',
    :'processing_rule' => :'processingRule',
    :'processing_rule_source' => :'processingRuleSource',
    :'flow_direction' => :'flowDirection',
    :'flow_syntax' => :'flowSyntax',
    :'flow_profile' => :'flowProfile',
    :'acknowledgement' => :'acknowledgement'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/factpulse/models/afnor_flow.rb', line 277

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



113
114
115
116
# File 'lib/factpulse/models/afnor_flow.rb', line 113

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/factpulse/models/afnor_flow.rb', line 96

def self.openapi_types
  {
    :'submitted_at' => :'Time',
    :'updated_at' => :'Time',
    :'flow_id' => :'String',
    :'tracking_id' => :'String',
    :'flow_type' => :'AFNORFlowType',
    :'processing_rule' => :'AFNORProcessingRule',
    :'processing_rule_source' => :'String',
    :'flow_direction' => :'AFNORFlowDirection',
    :'flow_syntax' => :'AFNORFlowSyntax',
    :'flow_profile' => :'AFNORFlowProfile',
    :'acknowledgement' => :'AFNORAcknowledgement'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/factpulse/models/afnor_flow.rb', line 246

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      updated_at == o.updated_at &&
      flow_id == o.flow_id &&
      tracking_id == o.tracking_id &&
      flow_type == o.flow_type &&
      processing_rule == o.processing_rule &&
      processing_rule_source == o.processing_rule_source &&
      flow_direction == o.flow_direction &&
      flow_syntax == o.flow_syntax &&
      flow_profile == o.flow_profile &&
      acknowledgement == o.acknowledgement
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


264
265
266
# File 'lib/factpulse/models/afnor_flow.rb', line 264

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



270
271
272
# File 'lib/factpulse/models/afnor_flow.rb', line 270

def hash
  [, updated_at, flow_id, tracking_id, flow_type, processing_rule, processing_rule_source, flow_direction, flow_syntax, flow_profile, acknowledgement].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/factpulse/models/afnor_flow.rb', line 181

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@flow_id.nil? && @flow_id.to_s.length > 36
    invalid_properties.push('invalid value for "flow_id", the character length must be smaller than or equal to 36.')
  end

  if !@tracking_id.nil? && @tracking_id.to_s.length > 36
    invalid_properties.push('invalid value for "tracking_id", the character length must be smaller than or equal to 36.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/factpulse/models/afnor_flow.rb', line 299

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



197
198
199
200
201
202
203
204
# File 'lib/factpulse/models/afnor_flow.rb', line 197

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@flow_id.nil? && @flow_id.to_s.length > 36
  return false if !@tracking_id.nil? && @tracking_id.to_s.length > 36
  processing_rule_source_validator = EnumAttributeValidator.new('String', ["Input", "Computed"])
  return false unless processing_rule_source_validator.valid?(@processing_rule_source)
  true
end