Class: FactPulse::AFNORFlowExtension

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/afnor_flow_extension.rb

Overview

Extension schema to build Flow schema

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AFNORFlowExtension

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORFlowExtension` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORFlowExtension`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'flow_type')
    self.flow_type = attributes[:'flow_type']
  else
    self.flow_type = nil
  end

  if attributes.key?(:'processing_rule_source')
    self.processing_rule_source = attributes[:'processing_rule_source']
  else
    self.processing_rule_source = nil
  end

  if attributes.key?(:'flow_direction')
    self.flow_direction = attributes[:'flow_direction']
  else
    self.flow_direction = nil
  end

  if attributes.key?(:'acknowledgement')
    self.acknowledgement = attributes[:'acknowledgement']
  else
    self.acknowledgement = nil
  end
end

Instance Attribute Details

#acknowledgementObject

Returns the value of attribute acknowledgement.



29
30
31
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 29

def acknowledgement
  @acknowledgement
end

#flow_directionObject

Returns the value of attribute flow_direction.



27
28
29
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 27

def flow_direction
  @flow_direction
end

#flow_typeObject

Returns the value of attribute flow_type.



22
23
24
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 22

def flow_type
  @flow_type
end

#processing_rule_sourceObject

Says whether the processing rule has been computed or the processing rule was an input parameter



25
26
27
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 25

def processing_rule_source
  @processing_rule_source
end

#updated_atObject

The last update date and time of the flow. When the flow is submitted updatedAt is equal to submittedAt. When the flow acknowledgment status is changed updatedAt date and time is updated.



20
21
22
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 20

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 54

def self.attribute_map
  {
    :'updated_at' => :'updatedAt',
    :'flow_type' => :'flowType',
    :'processing_rule_source' => :'processingRuleSource',
    :'flow_direction' => :'flowDirection',
    :'acknowledgement' => :'acknowledgement'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 257

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 75

def self.openapi_types
  {
    :'updated_at' => :'Time',
    :'flow_type' => :'AFNORFlowType',
    :'processing_rule_source' => :'String',
    :'flow_direction' => :'AFNORFlowDirection',
    :'acknowledgement' => :'AFNORAcknowledgement'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



232
233
234
235
236
237
238
239
240
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 232

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      updated_at == o.updated_at &&
      flow_type == o.flow_type &&
      processing_rule_source == o.processing_rule_source &&
      flow_direction == o.flow_direction &&
      acknowledgement == o.acknowledgement
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


244
245
246
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 244

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



250
251
252
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 250

def hash
  [updated_at, flow_type, processing_rule_source, flow_direction, acknowledgement].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @flow_type.nil?
    invalid_properties.push('invalid value for "flow_type", flow_type cannot be nil.')
  end

  if @processing_rule_source.nil?
    invalid_properties.push('invalid value for "processing_rule_source", processing_rule_source cannot be nil.')
  end

  if @flow_direction.nil?
    invalid_properties.push('invalid value for "flow_direction", flow_direction cannot be nil.')
  end

  if @acknowledgement.nil?
    invalid_properties.push('invalid value for "acknowledgement", acknowledgement cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 279

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



168
169
170
171
172
173
174
175
176
177
178
# File 'lib/factpulse/models/afnor_flow_extension.rb', line 168

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @updated_at.nil?
  return false if @flow_type.nil?
  return false if @processing_rule_source.nil?
  processing_rule_source_validator = EnumAttributeValidator.new('String', ["Input", "Computed"])
  return false unless processing_rule_source_validator.valid?(@processing_rule_source)
  return false if @flow_direction.nil?
  return false if @acknowledgement.nil?
  true
end