Class: FactPulse::AFNORFlowInfo
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::AFNORFlowInfo
- Defined in:
- lib/factpulse/models/afnor_flow_info.rb
Overview
Signaling of the flow: - The tracking id is an external identifier and is used to track the flow by the sender - The sha256 is the fingerprint of the attached file: - if provided in the request: it should be checked once received - if not provided in the request: it should be computed and returned in the response
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#flow_profile ⇒ Object
Returns the value of attribute flow_profile.
-
#flow_syntax ⇒ Object
Returns the value of attribute flow_syntax.
-
#name ⇒ Object
Name of the file.
-
#processing_rule ⇒ Object
Returns the value of attribute processing_rule.
-
#sha256 ⇒ Object
Returns the value of attribute sha256.
-
#tracking_id ⇒ Object
Unique identifier supporting UUID but not only, for flexibility purpose.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AFNORFlowInfo
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AFNORFlowInfo
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORFlowInfo` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORFlowInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tracking_id') self.tracking_id = attributes[:'tracking_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'processing_rule') self.processing_rule = attributes[:'processing_rule'] end if attributes.key?(:'flow_syntax') self.flow_syntax = attributes[:'flow_syntax'] else self.flow_syntax = nil end if attributes.key?(:'flow_profile') self.flow_profile = attributes[:'flow_profile'] end if attributes.key?(:'sha256') self.sha256 = attributes[:'sha256'] end end |
Instance Attribute Details
#flow_profile ⇒ Object
Returns the value of attribute flow_profile.
29 30 31 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 29 def flow_profile @flow_profile end |
#flow_syntax ⇒ Object
Returns the value of attribute flow_syntax.
27 28 29 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 27 def flow_syntax @flow_syntax end |
#name ⇒ Object
Name of the file
23 24 25 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 23 def name @name end |
#processing_rule ⇒ Object
Returns the value of attribute processing_rule.
25 26 27 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 25 def processing_rule @processing_rule end |
#sha256 ⇒ Object
Returns the value of attribute sha256.
31 32 33 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 31 def sha256 @sha256 end |
#tracking_id ⇒ Object
Unique identifier supporting UUID but not only, for flexibility purpose
20 21 22 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 20 def tracking_id @tracking_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 56 def self.attribute_map { :'tracking_id' => :'trackingId', :'name' => :'name', :'processing_rule' => :'processingRule', :'flow_syntax' => :'flowSyntax', :'flow_profile' => :'flowProfile', :'sha256' => :'sha256' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 255 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
90 91 92 93 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 90 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 78 def self.openapi_types { :'tracking_id' => :'String', :'name' => :'String', :'processing_rule' => :'AFNORProcessingRule', :'flow_syntax' => :'AFNORFlowSyntax', :'flow_profile' => :'AFNORFlowProfile', :'sha256' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
229 230 231 232 233 234 235 236 237 238 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 229 def ==(o) return true if self.equal?(o) self.class == o.class && tracking_id == o.tracking_id && name == o.name && processing_rule == o.processing_rule && flow_syntax == o.flow_syntax && flow_profile == o.flow_profile && sha256 == o.sha256 end |
#eql?(o) ⇒ Boolean
242 243 244 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 242 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 248 def hash [tracking_id, name, processing_rule, flow_syntax, flow_profile, sha256].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 140 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@tracking_id.nil? && @tracking_id.to_s.length > 36 invalid_properties.push('invalid value for "tracking_id", the character length must be smaller than or equal to 36.') end if !@name.nil? && @name.to_s.length > 255 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.') end if @flow_syntax.nil? invalid_properties.push('invalid value for "flow_syntax", flow_syntax cannot be nil.') end pattern = Regexp.new(/^[a-f0-9]{64}$/) if !@sha256.nil? && @sha256 !~ pattern invalid_properties.push("invalid value for \"sha256\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 277 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
165 166 167 168 169 170 171 172 |
# File 'lib/factpulse/models/afnor_flow_info.rb', line 165 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@tracking_id.nil? && @tracking_id.to_s.length > 36 return false if !@name.nil? && @name.to_s.length > 255 return false if @flow_syntax.nil? return false if !@sha256.nil? && @sha256 !~ Regexp.new(/^[a-f0-9]{64}$/) true end |