Class: FactPulse::AFNORFullFlowInfo

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/afnor_full_flow_info.rb

Overview

Identified Flow info: flow info + id + timestamp

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AFNORFullFlowInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORFullFlowInfo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORFullFlowInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'tracking_id')
    self.tracking_id = attributes[:'tracking_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'processing_rule')
    self.processing_rule = attributes[:'processing_rule']
  end

  if attributes.key?(:'flow_syntax')
    self.flow_syntax = attributes[:'flow_syntax']
  else
    self.flow_syntax = nil
  end

  if attributes.key?(:'flow_profile')
    self.flow_profile = attributes[:'flow_profile']
  end

  if attributes.key?(:'sha256')
    self.sha256 = attributes[:'sha256']
  end

  if attributes.key?(:'flow_id')
    self.flow_id = attributes[:'flow_id']
  end

  if attributes.key?(:'submitted_at')
    self. = attributes[:'submitted_at']
  end
end

Instance Attribute Details

#flow_id ⇒ Object

Unique identifier supporting UUID but not only, for flexibility purpose



34
35
36
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 34

def flow_id
  @flow_id
end

#flow_profile ⇒ Object

Returns the value of attribute flow_profile.



29
30
31
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 29

def flow_profile
  @flow_profile
end

#flow_syntax ⇒ Object

Returns the value of attribute flow_syntax.



27
28
29
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 27

def flow_syntax
  @flow_syntax
end

#name ⇒ Object

Name of the file



23
24
25
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 23

def name
  @name
end

#processing_rule ⇒ Object

Returns the value of attribute processing_rule.



25
26
27
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 25

def processing_rule
  @processing_rule
end

#sha256 ⇒ Object

Returns the value of attribute sha256.



31
32
33
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 31

def sha256
  @sha256
end

#submitted_at ⇒ Object

The flow submission date and time (the date and time when the flow was created on the system) This property should be used by the API consumer as a time reference to avoid clock synchronization issues



37
38
39
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 37

def 
  @submitted_at
end

#tracking_id ⇒ Object

Unique identifier supporting UUID but not only, for flexibility purpose



20
21
22
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 20

def tracking_id
  @tracking_id
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



76
77
78
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 76

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 81

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 62

def self.attribute_map
  {
    :'tracking_id' => :'trackingId',
    :'name' => :'name',
    :'processing_rule' => :'processingRule',
    :'flow_syntax' => :'flowSyntax',
    :'flow_profile' => :'flowProfile',
    :'sha256' => :'sha256',
    :'flow_id' => :'flowId',
    :'submitted_at' => :'submittedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 301

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_of ⇒ Object

List of class defined in allOf (OpenAPI v3)



106
107
108
109
110
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 106

def self.openapi_all_of
  [
  :'AFNORFlowInfo'
  ]
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



100
101
102
103
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 100

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 86

def self.openapi_types
  {
    :'tracking_id' => :'String',
    :'name' => :'String',
    :'processing_rule' => :'AFNORProcessingRule',
    :'flow_syntax' => :'AFNORFlowSyntax',
    :'flow_profile' => :'AFNORFlowProfile',
    :'sha256' => :'String',
    :'flow_id' => :'String',
    :'submitted_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 273

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      tracking_id == o.tracking_id &&
      name == o.name &&
      processing_rule == o.processing_rule &&
      flow_syntax == o.flow_syntax &&
      flow_profile == o.flow_profile &&
      sha256 == o.sha256 &&
      flow_id == o.flow_id &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


288
289
290
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 288

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



294
295
296
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 294

def hash
  [tracking_id, name, processing_rule, flow_syntax, flow_profile, sha256, flow_id, ].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 165

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@tracking_id.nil? && @tracking_id.to_s.length > 36
    invalid_properties.push('invalid value for "tracking_id", the character length must be smaller than or equal to 36.')
  end

  if !@name.nil? && @name.to_s.length > 255
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.')
  end

  if @flow_syntax.nil?
    invalid_properties.push('invalid value for "flow_syntax", flow_syntax cannot be nil.')
  end

  pattern = Regexp.new(/^[a-f0-9]{64}$/)
  if !@sha256.nil? && @sha256 !~ pattern
    invalid_properties.push("invalid value for \"sha256\", must conform to the pattern #{pattern}.")
  end

  if !@flow_id.nil? && @flow_id.to_s.length > 36
    invalid_properties.push('invalid value for "flow_id", the character length must be smaller than or equal to 36.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 323

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



194
195
196
197
198
199
200
201
202
# File 'lib/factpulse/models/afnor_full_flow_info.rb', line 194

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@tracking_id.nil? && @tracking_id.to_s.length > 36
  return false if !@name.nil? && @name.to_s.length > 255
  return false if @flow_syntax.nil?
  return false if !@sha256.nil? && @sha256 !~ Regexp.new(/^[a-f0-9]{64}$/)
  return false if !@flow_id.nil? && @flow_id.to_s.length > 36
  true
end