Class: FactPulse::AFNORLegalUnitPayloadIncludedNoSiren

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/factpulse/models/afnor_legal_unit_payload_included_no_siren.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AFNORLegalUnitPayloadIncludedNoSiren

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/factpulse/models/afnor_legal_unit_payload_included_no_siren.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORLegalUnitPayloadIncludedNoSiren` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORLegalUnitPayloadIncludedNoSiren`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'business_name')
    self.business_name = attributes[:'business_name']
  end

  if attributes.key?(:'entity_type')
    self.entity_type = attributes[:'entity_type']
  end

  if attributes.key?(:'administrative_status')
    self.administrative_status = attributes[:'administrative_status']
  end
end

Instance Attribute Details

#administrative_status ⇒ Object

Returns the value of attribute administrative_status.



23
24
25
# File 'lib/factpulse/models/afnor_legal_unit_payload_included_no_siren.rb', line 23

def administrative_status
  @administrative_status
end

#business_name ⇒ Object

Business name



19
20
21
# File 'lib/factpulse/models/afnor_legal_unit_payload_included_no_siren.rb', line 19

def business_name
  @business_name
end

#entity_type ⇒ Object

Returns the value of attribute entity_type.



21
22
23
# File 'lib/factpulse/models/afnor_legal_unit_payload_included_no_siren.rb', line 21

def entity_type
  @entity_type
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



57
58
59
# File 'lib/factpulse/models/afnor_legal_unit_payload_included_no_siren.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/factpulse/models/afnor_legal_unit_payload_included_no_siren.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
# File 'lib/factpulse/models/afnor_legal_unit_payload_included_no_siren.rb', line 48

def self.attribute_map
  {
    :'business_name' => :'businessName',
    :'entity_type' => :'entityType',
    :'administrative_status' => :'administrativeStatus'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/factpulse/models/afnor_legal_unit_payload_included_no_siren.rb', line 169

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



76
77
78
79
# File 'lib/factpulse/models/afnor_legal_unit_payload_included_no_siren.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



67
68
69
70
71
72
73
# File 'lib/factpulse/models/afnor_legal_unit_payload_included_no_siren.rb', line 67

def self.openapi_types
  {
    :'business_name' => :'String',
    :'entity_type' => :'AFNOREntityType',
    :'administrative_status' => :'AFNORLegalUnitAdministrativeStatus'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



146
147
148
149
150
151
152
# File 'lib/factpulse/models/afnor_legal_unit_payload_included_no_siren.rb', line 146

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      business_name == o.business_name &&
      entity_type == o.entity_type &&
      administrative_status == o.administrative_status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/factpulse/models/afnor_legal_unit_payload_included_no_siren.rb', line 156

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



162
163
164
# File 'lib/factpulse/models/afnor_legal_unit_payload_included_no_siren.rb', line 162

def hash
  [business_name, entity_type, administrative_status].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



112
113
114
115
116
117
118
119
120
# File 'lib/factpulse/models/afnor_legal_unit_payload_included_no_siren.rb', line 112

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@business_name.nil? && @business_name.to_s.length > 150
    invalid_properties.push('invalid value for "business_name", the character length must be smaller than or equal to 150.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/factpulse/models/afnor_legal_unit_payload_included_no_siren.rb', line 191

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



124
125
126
127
128
# File 'lib/factpulse/models/afnor_legal_unit_payload_included_no_siren.rb', line 124

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@business_name.nil? && @business_name.to_s.length > 150
  true
end