Class: FactPulse::AFNORPDPPAFlowServiceApi
- Inherits:
-
Object
- Object
- FactPulse::AFNORPDPPAFlowServiceApi
- Defined in:
- lib/factpulse/api/afnorpdppa_flow_service_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#download_flow_proxy_api_v1_afnor_flow_v1_flows_flow_id_get(flow_id, opts = {}) ⇒ AFNORFlow
Download a flow Download a file related to a given flow (AFNOR XP Z12-013 compliant): - Metadata [Default]: provides the flow metadata as JSON - Original: the document initially sent by the emitter - Converted: the document optionally converted by the system - ReadableView: the document optionally generated as readable file.
-
#download_flow_proxy_api_v1_afnor_flow_v1_flows_flow_id_get_with_http_info(flow_id, opts = {}) ⇒ Array<(AFNORFlow, Integer, Hash)>
Download a flow Download a file related to a given flow (AFNOR XP Z12-013 compliant): - Metadata [Default]: provides the flow metadata as JSON - Original: the document initially sent by the emitter - Converted: the document optionally converted by the system - ReadableView: the document optionally generated as readable file.
-
#flow_healthcheck_proxy_api_v1_afnor_flow_v1_healthcheck_get(opts = {}) ⇒ Object
Healthcheck Flow Service Check Flow Service availability (AFNOR XP Z12-013 compliant).
-
#flow_healthcheck_proxy_api_v1_afnor_flow_v1_healthcheck_get_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Healthcheck Flow Service Check Flow Service availability (AFNOR XP Z12-013 compliant).
-
#initialize(api_client = ApiClient.default) ⇒ AFNORPDPPAFlowServiceApi
constructor
A new instance of AFNORPDPPAFlowServiceApi.
-
#search_flows_proxy_api_v1_afnor_flow_v1_flows_search_post(afnor_search_flow_params, opts = {}) ⇒ AFNORSearchFlowContent
Search flows Search invoicing flows by criteria (AFNOR XP Z12-013 compliant).
-
#search_flows_proxy_api_v1_afnor_flow_v1_flows_search_post_with_http_info(afnor_search_flow_params, opts = {}) ⇒ Array<(AFNORSearchFlowContent, Integer, Hash)>
Search flows Search invoicing flows by criteria (AFNOR XP Z12-013 compliant).
-
#submit_flow_proxy_api_v1_afnor_flow_v1_flows_post(flow_info, file, opts = {}) ⇒ Object
Submit an invoicing flow Submits an electronic invoice to a Partner Dematerialization Platform (PDP) in compliance with the AFNOR XP Z12-013 standard.
-
#submit_flow_proxy_api_v1_afnor_flow_v1_flows_post_with_http_info(flow_info, file, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Submit an invoicing flow Submits an electronic invoice to a Partner Dematerialization Platform (PDP) in compliance with the AFNOR XP Z12-013 standard.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AFNORPDPPAFlowServiceApi
Returns a new instance of AFNORPDPPAFlowServiceApi.
19 20 21 |
# File 'lib/factpulse/api/afnorpdppa_flow_service_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/factpulse/api/afnorpdppa_flow_service_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#download_flow_proxy_api_v1_afnor_flow_v1_flows_flow_id_get(flow_id, opts = {}) ⇒ AFNORFlow
Download a flow Download a file related to a given flow (AFNOR XP Z12-013 compliant): - Metadata [Default]: provides the flow metadata as JSON - Original: the document initially sent by the emitter - Converted: the document optionally converted by the system - ReadableView: the document optionally generated as readable file
28 29 30 31 |
# File 'lib/factpulse/api/afnorpdppa_flow_service_api.rb', line 28 def download_flow_proxy_api_v1_afnor_flow_v1_flows_flow_id_get(flow_id, opts = {}) data, _status_code, _headers = download_flow_proxy_api_v1_afnor_flow_v1_flows_flow_id_get_with_http_info(flow_id, opts) data end |
#download_flow_proxy_api_v1_afnor_flow_v1_flows_flow_id_get_with_http_info(flow_id, opts = {}) ⇒ Array<(AFNORFlow, Integer, Hash)>
Download a flow Download a file related to a given flow (AFNOR XP Z12-013 compliant): - Metadata [Default]: provides the flow metadata as JSON - Original: the document initially sent by the emitter - Converted: the document optionally converted by the system - ReadableView: the document optionally generated as readable file
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/factpulse/api/afnorpdppa_flow_service_api.rb', line 39 def download_flow_proxy_api_v1_afnor_flow_v1_flows_flow_id_get_with_http_info(flow_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AFNORPDPPAFlowServiceApi.download_flow_proxy_api_v1_afnor_flow_v1_flows_flow_id_get ...' end # verify the required parameter 'flow_id' is set if @api_client.config.client_side_validation && flow_id.nil? fail ArgumentError, "Missing the required parameter 'flow_id' when calling AFNORPDPPAFlowServiceApi.download_flow_proxy_api_v1_afnor_flow_v1_flows_flow_id_get" end # resource path local_var_path = '/api/v1/afnor/flow/v1/flows/{flowId}'.sub('{' + 'flowId' + '}', CGI.escape(flow_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'docType'] = opts[:'doc_type'] if !opts[:'doc_type'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/pdf', 'application/xml']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AFNORFlow' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AFNORPDPPAFlowServiceApi.download_flow_proxy_api_v1_afnor_flow_v1_flows_flow_id_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AFNORPDPPAFlowServiceApi#download_flow_proxy_api_v1_afnor_flow_v1_flows_flow_id_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#flow_healthcheck_proxy_api_v1_afnor_flow_v1_healthcheck_get(opts = {}) ⇒ Object
Healthcheck Flow Service Check Flow Service availability (AFNOR XP Z12-013 compliant)
92 93 94 95 |
# File 'lib/factpulse/api/afnorpdppa_flow_service_api.rb', line 92 def flow_healthcheck_proxy_api_v1_afnor_flow_v1_healthcheck_get(opts = {}) data, _status_code, _headers = flow_healthcheck_proxy_api_v1_afnor_flow_v1_healthcheck_get_with_http_info(opts) data end |
#flow_healthcheck_proxy_api_v1_afnor_flow_v1_healthcheck_get_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Healthcheck Flow Service Check Flow Service availability (AFNOR XP Z12-013 compliant)
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/factpulse/api/afnorpdppa_flow_service_api.rb', line 101 def flow_healthcheck_proxy_api_v1_afnor_flow_v1_healthcheck_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AFNORPDPPAFlowServiceApi.flow_healthcheck_proxy_api_v1_afnor_flow_v1_healthcheck_get ...' end # resource path local_var_path = '/api/v1/afnor/flow/v1/healthcheck' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AFNORPDPPAFlowServiceApi.flow_healthcheck_proxy_api_v1_afnor_flow_v1_healthcheck_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AFNORPDPPAFlowServiceApi#flow_healthcheck_proxy_api_v1_afnor_flow_v1_healthcheck_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#search_flows_proxy_api_v1_afnor_flow_v1_flows_search_post(afnor_search_flow_params, opts = {}) ⇒ AFNORSearchFlowContent
Search flows Search invoicing flows by criteria (AFNOR XP Z12-013 compliant)
150 151 152 153 |
# File 'lib/factpulse/api/afnorpdppa_flow_service_api.rb', line 150 def search_flows_proxy_api_v1_afnor_flow_v1_flows_search_post(afnor_search_flow_params, opts = {}) data, _status_code, _headers = search_flows_proxy_api_v1_afnor_flow_v1_flows_search_post_with_http_info(afnor_search_flow_params, opts) data end |
#search_flows_proxy_api_v1_afnor_flow_v1_flows_search_post_with_http_info(afnor_search_flow_params, opts = {}) ⇒ Array<(AFNORSearchFlowContent, Integer, Hash)>
Search flows Search invoicing flows by criteria (AFNOR XP Z12-013 compliant)
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/factpulse/api/afnorpdppa_flow_service_api.rb', line 160 def search_flows_proxy_api_v1_afnor_flow_v1_flows_search_post_with_http_info(afnor_search_flow_params, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AFNORPDPPAFlowServiceApi.search_flows_proxy_api_v1_afnor_flow_v1_flows_search_post ...' end # verify the required parameter 'afnor_search_flow_params' is set if @api_client.config.client_side_validation && afnor_search_flow_params.nil? fail ArgumentError, "Missing the required parameter 'afnor_search_flow_params' when calling AFNORPDPPAFlowServiceApi.search_flows_proxy_api_v1_afnor_flow_v1_flows_search_post" end # resource path local_var_path = '/api/v1/afnor/flow/v1/flows/search' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(afnor_search_flow_params) # return_type return_type = opts[:debug_return_type] || 'AFNORSearchFlowContent' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AFNORPDPPAFlowServiceApi.search_flows_proxy_api_v1_afnor_flow_v1_flows_search_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AFNORPDPPAFlowServiceApi#search_flows_proxy_api_v1_afnor_flow_v1_flows_search_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#submit_flow_proxy_api_v1_afnor_flow_v1_flows_post(flow_info, file, opts = {}) ⇒ Object
Submit an invoicing flow Submits an electronic invoice to a Partner Dematerialization Platform (PDP) in compliance with the AFNOR XP Z12-013 standard
219 220 221 222 |
# File 'lib/factpulse/api/afnorpdppa_flow_service_api.rb', line 219 def submit_flow_proxy_api_v1_afnor_flow_v1_flows_post(flow_info, file, opts = {}) data, _status_code, _headers = submit_flow_proxy_api_v1_afnor_flow_v1_flows_post_with_http_info(flow_info, file, opts) data end |
#submit_flow_proxy_api_v1_afnor_flow_v1_flows_post_with_http_info(flow_info, file, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Submit an invoicing flow Submits an electronic invoice to a Partner Dematerialization Platform (PDP) in compliance with the AFNOR XP Z12-013 standard
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/factpulse/api/afnorpdppa_flow_service_api.rb', line 230 def submit_flow_proxy_api_v1_afnor_flow_v1_flows_post_with_http_info(flow_info, file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AFNORPDPPAFlowServiceApi.submit_flow_proxy_api_v1_afnor_flow_v1_flows_post ...' end # verify the required parameter 'flow_info' is set if @api_client.config.client_side_validation && flow_info.nil? fail ArgumentError, "Missing the required parameter 'flow_info' when calling AFNORPDPPAFlowServiceApi.submit_flow_proxy_api_v1_afnor_flow_v1_flows_post" end # verify the required parameter 'file' is set if @api_client.config.client_side_validation && file.nil? fail ArgumentError, "Missing the required parameter 'file' when calling AFNORPDPPAFlowServiceApi.submit_flow_proxy_api_v1_afnor_flow_v1_flows_post" end # resource path local_var_path = '/api/v1/afnor/flow/v1/flows' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} form_params['flowInfo'] = flow_info form_params['file'] = file # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"AFNORPDPPAFlowServiceApi.submit_flow_proxy_api_v1_afnor_flow_v1_flows_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AFNORPDPPAFlowServiceApi#submit_flow_proxy_api_v1_afnor_flow_v1_flows_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |