Class: FactPulse::AFNORRoutingCodePayloadHistoryLegalUnitFacility

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AFNORRoutingCodePayloadHistoryLegalUnitFacility

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORRoutingCodePayloadHistoryLegalUnitFacility` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORRoutingCodePayloadHistoryLegalUnitFacility`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'routing_identifier')
    self.routing_identifier = attributes[:'routing_identifier']
  end

  if attributes.key?(:'siret')
    self.siret = attributes[:'siret']
  end

  if attributes.key?(:'routing_identifier_type')
    self.routing_identifier_type = attributes[:'routing_identifier_type']
  end

  if attributes.key?(:'routing_code_name')
    self.routing_code_name = attributes[:'routing_code_name']
  end

  if attributes.key?(:'manages_legal_commitment_code')
    self.manages_legal_commitment_code = attributes[:'manages_legal_commitment_code']
  end

  if attributes.key?(:'administrative_status')
    self.administrative_status = attributes[:'administrative_status']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'legal_unit')
    self.legal_unit = attributes[:'legal_unit']
  end

  if attributes.key?(:'facility')
    self.facility = attributes[:'facility']
  end
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



35
36
37
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 35

def address
  @address
end

#administrative_statusObject

Returns the value of attribute administrative_status.



33
34
35
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 33

def administrative_status
  @administrative_status
end

#facilityObject

Returns the value of attribute facility.



39
40
41
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 39

def facility
  @facility
end

Returns the value of attribute legal_unit.



37
38
39
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 37

def legal_unit
  @legal_unit
end

Indicates whether the public structure requires a legal commitment number. This attribute is only returned if the directory line is defined for a public structure at the SIREN / SIRET or SIREN / SIRET / Routing code level.



31
32
33
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 31

def manages_legal_commitment_code
  @manages_legal_commitment_code
end

#routing_code_nameObject

Name of the directory line routing code. This attribute is only returned if the directory line is defined at the SIREN / SIRET / Routing code mesh.



28
29
30
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 28

def routing_code_name
  @routing_code_name
end

#routing_identifierObject

Routing identifier od a routing code.



19
20
21
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 19

def routing_identifier
  @routing_identifier
end

#routing_identifier_typeObject

Routing Identifier type.



25
26
27
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 25

def routing_identifier_type
  @routing_identifier_type
end

#siretObject

SIRET Number



22
23
24
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 22

def siret
  @siret
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 64

def self.attribute_map
  {
    :'routing_identifier' => :'routingIdentifier',
    :'siret' => :'siret',
    :'routing_identifier_type' => :'routingIdentifierType',
    :'routing_code_name' => :'routingCodeName',
    :'manages_legal_commitment_code' => :'managesLegalCommitmentCode',
    :'administrative_status' => :'administrativeStatus',
    :'address' => :'address',
    :'legal_unit' => :'legalUnit',
    :'facility' => :'facility'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 328

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



104
105
106
107
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 104

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 89

def self.openapi_types
  {
    :'routing_identifier' => :'String',
    :'siret' => :'String',
    :'routing_identifier_type' => :'String',
    :'routing_code_name' => :'String',
    :'manages_legal_commitment_code' => :'Boolean',
    :'administrative_status' => :'AFNORRoutingCodeAdministrativeStatus',
    :'address' => :'AFNORAddressRead',
    :'legal_unit' => :'AFNORLegalUnitPayloadIncluded',
    :'facility' => :'AFNORFacilityPayloadIncluded'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 299

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      routing_identifier == o.routing_identifier &&
      siret == o.siret &&
      routing_identifier_type == o.routing_identifier_type &&
      routing_code_name == o.routing_code_name &&
      manages_legal_commitment_code == o.manages_legal_commitment_code &&
      administrative_status == o.administrative_status &&
      address == o.address &&
      legal_unit == o.legal_unit &&
      facility == o.facility
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


315
316
317
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 315

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



321
322
323
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 321

def hash
  [routing_identifier, siret, routing_identifier_type, routing_code_name, manages_legal_commitment_code, administrative_status, address, legal_unit, facility].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 164

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@routing_identifier.nil? && @routing_identifier.to_s.length > 100
    invalid_properties.push('invalid value for "routing_identifier", the character length must be smaller than or equal to 100.')
  end

  pattern = Regexp.new(/^(?!\s+$)[\-_\/a-zA-Z0-9]{1,100}$/)
  if !@routing_identifier.nil? && @routing_identifier !~ pattern
    invalid_properties.push("invalid value for \"routing_identifier\", must conform to the pattern #{pattern}.")
  end

  if !@siret.nil? && @siret.to_s.length > 14
    invalid_properties.push('invalid value for "siret", the character length must be smaller than or equal to 14.')
  end

  pattern = Regexp.new(/^([0-9]{14})$/)
  if !@siret.nil? && @siret !~ pattern
    invalid_properties.push("invalid value for \"siret\", must conform to the pattern #{pattern}.")
  end

  if !@routing_identifier_type.nil? && @routing_identifier_type.to_s.length > 4
    invalid_properties.push('invalid value for "routing_identifier_type", the character length must be smaller than or equal to 4.')
  end

  pattern = Regexp.new(/^(?!\s*$).+/)
  if !@routing_identifier_type.nil? && @routing_identifier_type !~ pattern
    invalid_properties.push("invalid value for \"routing_identifier_type\", must conform to the pattern #{pattern}.")
  end

  if !@routing_code_name.nil? && @routing_code_name.to_s.length > 100
    invalid_properties.push('invalid value for "routing_code_name", the character length must be smaller than or equal to 100.')
  end

  pattern = Regexp.new(/^(?!\s*$).+/)
  if !@routing_code_name.nil? && @routing_code_name !~ pattern
    invalid_properties.push("invalid value for \"routing_code_name\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 350

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/factpulse/models/afnor_routing_code_payload_history_legal_unit_facility.rb', line 208

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@routing_identifier.nil? && @routing_identifier.to_s.length > 100
  return false if !@routing_identifier.nil? && @routing_identifier !~ Regexp.new(/^(?!\s+$)[\-_\/a-zA-Z0-9]{1,100}$/)
  return false if !@siret.nil? && @siret.to_s.length > 14
  return false if !@siret.nil? && @siret !~ Regexp.new(/^([0-9]{14})$/)
  return false if !@routing_identifier_type.nil? && @routing_identifier_type.to_s.length > 4
  return false if !@routing_identifier_type.nil? && @routing_identifier_type !~ Regexp.new(/^(?!\s*$).+/)
  return false if !@routing_code_name.nil? && @routing_code_name.to_s.length > 100
  return false if !@routing_code_name.nil? && @routing_code_name !~ Regexp.new(/^(?!\s*$).+/)
  true
end