Class: FactPulse::AFNORRoutingCodeSearch
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::AFNORRoutingCodeSearch
- Defined in:
- lib/factpulse/models/afnor_routing_code_search.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#fields ⇒ Object
Allows you to filter the desired fields in the response.
-
#filters ⇒ Object
Returns the value of attribute filters.
-
#ignore ⇒ Object
Number of results to skip.
-
#include ⇒ Object
Returns the value of attribute include.
-
#limit ⇒ Object
Maximum number of results.
-
#sorting ⇒ Object
Sorting criteria on a field and an order (ascending or descending).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AFNORRoutingCodeSearch
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AFNORRoutingCodeSearch
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORRoutingCodeSearch` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORRoutingCodeSearch`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'filters') self.filters = attributes[:'filters'] end if attributes.key?(:'sorting') if (value = attributes[:'sorting']).is_a?(Array) self.sorting = value end end if attributes.key?(:'fields') if (value = attributes[:'fields']).is_a?(Array) self.fields = value end end if attributes.key?(:'include') if (value = attributes[:'include']).is_a?(Array) self.include = value end end if attributes.key?(:'limit') self.limit = attributes[:'limit'] end if attributes.key?(:'ignore') self.ignore = attributes[:'ignore'] end end |
Instance Attribute Details
#fields ⇒ Object
Allows you to filter the desired fields in the response.
24 25 26 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 24 def fields @fields end |
#filters ⇒ Object
Returns the value of attribute filters.
18 19 20 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 18 def filters @filters end |
#ignore ⇒ Object
Number of results to skip
32 33 34 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 32 def ignore @ignore end |
#include ⇒ Object
Returns the value of attribute include.
26 27 28 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 26 def include @include end |
#limit ⇒ Object
Maximum number of results
29 30 31 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 29 def limit @limit end |
#sorting ⇒ Object
Sorting criteria on a field and an order (ascending or descending).
21 22 23 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 21 def sorting @sorting end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 57 def self.attribute_map { :'filters' => :'filters', :'sorting' => :'sorting', :'fields' => :'fields', :'include' => :'include', :'limit' => :'limit', :'ignore' => :'ignore' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 186 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 79 def self.openapi_types { :'filters' => :'AFNORRoutingCodeSearchFilters', :'sorting' => :'Array<AFNORRoutingCodeSearchSortingInner>', :'fields' => :'Array<AFNORRoutingCodeField>', :'include' => :'Array<String>', :'limit' => :'Integer', :'ignore' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
160 161 162 163 164 165 166 167 168 169 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 160 def ==(o) return true if self.equal?(o) self.class == o.class && filters == o.filters && sorting == o.sorting && fields == o.fields && include == o.include && limit == o.limit && ignore == o.ignore end |
#eql?(o) ⇒ Boolean
173 174 175 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 173 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
179 180 181 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 179 def hash [filters, sorting, fields, include, limit, ignore].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 208 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 |
# File 'lib/factpulse/models/afnor_routing_code_search.rb', line 153 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |