Class: FactPulse::AFNORRoutingCodeSearchFilters
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::AFNORRoutingCodeSearchFilters
- Defined in:
- lib/factpulse/models/afnor_routing_code_search_filters.rb
Instance Attribute Summary collapse
-
#address_lines ⇒ Object
Returns the value of attribute address_lines.
-
#administrative_status ⇒ Object
Returns the value of attribute administrative_status.
-
#locality ⇒ Object
Returns the value of attribute locality.
-
#postal_code ⇒ Object
Returns the value of attribute postal_code.
-
#routing_code_name ⇒ Object
Returns the value of attribute routing_code_name.
-
#routing_identifier ⇒ Object
Returns the value of attribute routing_identifier.
-
#siret ⇒ Object
Returns the value of attribute siret.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AFNORRoutingCodeSearchFilters
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AFNORRoutingCodeSearchFilters
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORRoutingCodeSearchFilters` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORRoutingCodeSearchFilters`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'routing_identifier') self.routing_identifier = attributes[:'routing_identifier'] end if attributes.key?(:'siret') self.siret = attributes[:'siret'] end if attributes.key?(:'routing_code_name') self.routing_code_name = attributes[:'routing_code_name'] end if attributes.key?(:'administrative_status') self.administrative_status = attributes[:'administrative_status'] end if attributes.key?(:'address_lines') self.address_lines = attributes[:'address_lines'] end if attributes.key?(:'postal_code') self.postal_code = attributes[:'postal_code'] end if attributes.key?(:'locality') self.locality = attributes[:'locality'] end end |
Instance Attribute Details
#address_lines ⇒ Object
Returns the value of attribute address_lines.
26 27 28 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 26 def address_lines @address_lines end |
#administrative_status ⇒ Object
Returns the value of attribute administrative_status.
24 25 26 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 24 def administrative_status @administrative_status end |
#locality ⇒ Object
Returns the value of attribute locality.
30 31 32 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 30 def locality @locality end |
#postal_code ⇒ Object
Returns the value of attribute postal_code.
28 29 30 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 28 def postal_code @postal_code end |
#routing_code_name ⇒ Object
Returns the value of attribute routing_code_name.
22 23 24 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 22 def routing_code_name @routing_code_name end |
#routing_identifier ⇒ Object
Returns the value of attribute routing_identifier.
18 19 20 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 18 def routing_identifier @routing_identifier end |
#siret ⇒ Object
Returns the value of attribute siret.
20 21 22 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 20 def siret @siret end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 33 def self.attribute_map { :'routing_identifier' => :'routingIdentifier', :'siret' => :'siret', :'routing_code_name' => :'routingCodeName', :'administrative_status' => :'administrativeStatus', :'address_lines' => :'addressLines', :'postal_code' => :'postalCode', :'locality' => :'locality' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 163 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 69 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 56 def self.openapi_types { :'routing_identifier' => :'AFNORRoutingCodeSearchFiltersRoutingIdentifier', :'siret' => :'AFNORSearchSiretFiltersSiret', :'routing_code_name' => :'AFNORRoutingCodeSearchFiltersRoutingCodeName', :'administrative_status' => :'AFNORRoutingCodeSearchFiltersAdministrativeStatus', :'address_lines' => :'AFNORSearchSiretFiltersAddressLines', :'postal_code' => :'AFNORSearchSiretFiltersPostalCode', :'locality' => :'AFNORSearchSiretFiltersLocality' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 136 def ==(o) return true if self.equal?(o) self.class == o.class && routing_identifier == o.routing_identifier && siret == o.siret && routing_code_name == o.routing_code_name && administrative_status == o.administrative_status && address_lines == o.address_lines && postal_code == o.postal_code && locality == o.locality end |
#eql?(o) ⇒ Boolean
150 151 152 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 150 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
156 157 158 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 156 def hash [routing_identifier, siret, routing_code_name, administrative_status, address_lines, postal_code, locality].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
121 122 123 124 125 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 121 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 185 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
129 130 131 132 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters.rb', line 129 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |