Class: FactPulse::AFNORRoutingCodeSearchFiltersRoutingCodeName
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::AFNORRoutingCodeSearchFiltersRoutingCodeName
- Defined in:
- lib/factpulse/models/afnor_routing_code_search_filters_routing_code_name.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#op ⇒ Object
Returns the value of attribute op.
-
#value ⇒ Object
Name of the routing code.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AFNORRoutingCodeSearchFiltersRoutingCodeName
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AFNORRoutingCodeSearchFiltersRoutingCodeName
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters_routing_code_name.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORRoutingCodeSearchFiltersRoutingCodeName` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORRoutingCodeSearchFiltersRoutingCodeName`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'op') self.op = attributes[:'op'] end if attributes.key?(:'value') self.value = attributes[:'value'] end end |
Instance Attribute Details
#op ⇒ Object
Returns the value of attribute op.
18 19 20 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters_routing_code_name.rb', line 18 def op @op end |
#value ⇒ Object
Name of the routing code.
21 22 23 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters_routing_code_name.rb', line 21 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters_routing_code_name.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters_routing_code_name.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters_routing_code_name.rb', line 46 def self.attribute_map { :'op' => :'op', :'value' => :'value' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters_routing_code_name.rb', line 171 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters_routing_code_name.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters_routing_code_name.rb', line 64 def self.openapi_types { :'op' => :'AFNORContainsOrStrictOperator', :'value' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
149 150 151 152 153 154 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters_routing_code_name.rb', line 149 def ==(o) return true if self.equal?(o) self.class == o.class && op == o.op && value == o.value end |
#eql?(o) ⇒ Boolean
158 159 160 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters_routing_code_name.rb', line 158 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
164 165 166 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters_routing_code_name.rb', line 164 def hash [op, value].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters_routing_code_name.rb', line 104 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@value.nil? && @value.to_s.length > 100 invalid_properties.push('invalid value for "value", the character length must be smaller than or equal to 100.') end pattern = Regexp.new(/^$|^(?!\s*$).+/) if !@value.nil? && @value !~ pattern invalid_properties.push("invalid value for \"value\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters_routing_code_name.rb', line 193 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
121 122 123 124 125 126 |
# File 'lib/factpulse/models/afnor_routing_code_search_filters_routing_code_name.rb', line 121 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@value.nil? && @value.to_s.length > 100 return false if !@value.nil? && @value !~ Regexp.new(/^$|^(?!\s*$).+/) true end |