Class: FactPulse::AFNORSearchFlowFilters

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/afnor_search_flow_filters.rb

Overview

Filtering criteria, at least one is required

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AFNORSearchFlowFilters

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORSearchFlowFilters` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORSearchFlowFilters`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'updated_after')
    self.updated_after = attributes[:'updated_after']
  end

  if attributes.key?(:'updated_before')
    self.updated_before = attributes[:'updated_before']
  end

  if attributes.key?(:'processing_rule')
    if (value = attributes[:'processing_rule']).is_a?(Array)
      self.processing_rule = value
    end
  end

  if attributes.key?(:'flow_type')
    if (value = attributes[:'flow_type']).is_a?(Array)
      self.flow_type = value
    end
  end

  if attributes.key?(:'flow_direction')
    if (value = attributes[:'flow_direction']).is_a?(Array)
      self.flow_direction = value
    end
  end

  if attributes.key?(:'tracking_id')
    self.tracking_id = attributes[:'tracking_id']
  end

  if attributes.key?(:'ack_status')
    self.ack_status = attributes[:'ack_status']
  end
end

Instance Attribute Details

#ack_status ⇒ Object

Returns the value of attribute ack_status.



32
33
34
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 32

def ack_status
  @ack_status
end

#flow_direction ⇒ Object

Returns the value of attribute flow_direction.



27
28
29
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 27

def flow_direction
  @flow_direction
end

#flow_type ⇒ Object

Returns the value of attribute flow_type.



25
26
27
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 25

def flow_type
  @flow_type
end

#processing_rule ⇒ Object

Returns the value of attribute processing_rule.



23
24
25
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 23

def processing_rule
  @processing_rule
end

#tracking_id ⇒ Object

Unique identifier supporting UUID but not only, for flexibility purpose



30
31
32
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 30

def tracking_id
  @tracking_id
end

#updated_after ⇒ Object

Returns the value of attribute updated_after.



19
20
21
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 19

def updated_after
  @updated_after
end

#updated_before ⇒ Object

Returns the value of attribute updated_before.



21
22
23
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 21

def updated_before
  @updated_before
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



70
71
72
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 57

def self.attribute_map
  {
    :'updated_after' => :'updatedAfter',
    :'updated_before' => :'updatedBefore',
    :'processing_rule' => :'processingRule',
    :'flow_type' => :'flowType',
    :'flow_direction' => :'flowDirection',
    :'tracking_id' => :'trackingId',
    :'ack_status' => :'ackStatus'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 212

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



93
94
95
96
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 80

def self.openapi_types
  {
    :'updated_after' => :'Time',
    :'updated_before' => :'Time',
    :'processing_rule' => :'Array<AFNORProcessingRule>',
    :'flow_type' => :'Array<AFNORFlowType>',
    :'flow_direction' => :'Array<AFNORFlowDirection>',
    :'tracking_id' => :'String',
    :'ack_status' => :'AFNORFlowAckStatus'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



185
186
187
188
189
190
191
192
193
194
195
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 185

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      updated_after == o.updated_after &&
      updated_before == o.updated_before &&
      processing_rule == o.processing_rule &&
      flow_type == o.flow_type &&
      flow_direction == o.flow_direction &&
      tracking_id == o.tracking_id &&
      ack_status == o.ack_status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


199
200
201
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 199

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



205
206
207
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 205

def hash
  [updated_after, updated_before, processing_rule, flow_type, flow_direction, tracking_id, ack_status].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



151
152
153
154
155
156
157
158
159
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 151

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@tracking_id.nil? && @tracking_id.to_s.length > 36
    invalid_properties.push('invalid value for "tracking_id", the character length must be smaller than or equal to 36.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 234

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



163
164
165
166
167
# File 'lib/factpulse/models/afnor_search_flow_filters.rb', line 163

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@tracking_id.nil? && @tracking_id.to_s.length > 36
  true
end