Class: FactPulse::AggregatedTransactionInput

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/aggregated_transaction_input.rb

Overview

Aggregated transaction for B2C reporting (flux 10.3). Represents daily aggregation by category (TLB1, TPS1, etc.). Each occurrence corresponds to one day + one currency + one category. Source: Annexe 6 v1.9, bloc TG-31 "Transactions"

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AggregatedTransactionInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AggregatedTransactionInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AggregatedTransactionInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  else
    self.date = nil
  end

  if attributes.key?(:'category_code')
    self.category_code = attributes[:'category_code']
  else
    self.category_code = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'tax_exclusive_amount')
    self.tax_exclusive_amount = attributes[:'tax_exclusive_amount']
  else
    self.tax_exclusive_amount = nil
  end

  if attributes.key?(:'tax_amount')
    self.tax_amount = attributes[:'tax_amount']
  else
    self.tax_amount = nil
  end

  if attributes.key?(:'tax_breakdown')
    if (value = attributes[:'tax_breakdown']).is_a?(Array)
      self.tax_breakdown = value
    end
  else
    self.tax_breakdown = nil
  end

  if attributes.key?(:'transaction_count')
    self.transaction_count = attributes[:'transaction_count']
  end

  if attributes.key?(:'tax_due_type')
    self.tax_due_type = attributes[:'tax_due_type']
  end
end

Instance Attribute Details

#category_code ⇒ Object

Transaction category code (TT-81). Use TLB1 for goods, TPS1 for services.



23
24
25
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 23

def category_code
  @category_code
end

#currency ⇒ Object

Returns the value of attribute currency.



25
26
27
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 25

def currency
  @currency
end

#date ⇒ Object

Transaction date (TT-77)



20
21
22
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 20

def date
  @date
end

#tax_amount ⇒ Object

Returns the value of attribute tax_amount.



29
30
31
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 29

def tax_amount
  @tax_amount
end

#tax_breakdown ⇒ Object

VAT breakdown by rate



32
33
34
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 32

def tax_breakdown
  @tax_breakdown
end

#tax_due_type ⇒ Object

Returns the value of attribute tax_due_type.



36
37
38
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 36

def tax_due_type
  @tax_due_type
end

#tax_exclusive_amount ⇒ Object

Returns the value of attribute tax_exclusive_amount.



27
28
29
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 27

def tax_exclusive_amount
  @tax_exclusive_amount
end

#transaction_count ⇒ Object

Returns the value of attribute transaction_count.



34
35
36
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 34

def transaction_count
  @transaction_count
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



75
76
77
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 61

def self.attribute_map
  {
    :'date' => :'date',
    :'category_code' => :'categoryCode',
    :'currency' => :'currency',
    :'tax_exclusive_amount' => :'taxExclusiveAmount',
    :'tax_amount' => :'taxAmount',
    :'tax_breakdown' => :'taxBreakdown',
    :'transaction_count' => :'transactionCount',
    :'tax_due_type' => :'taxDueType'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 311

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



99
100
101
102
103
104
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 99

def self.openapi_nullable
  Set.new([
    :'transaction_count',
    :'tax_due_type'
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 85

def self.openapi_types
  {
    :'date' => :'Date',
    :'category_code' => :'TransactionCategory',
    :'currency' => :'Currency',
    :'tax_exclusive_amount' => :'Taxexclusiveamount',
    :'tax_amount' => :'Taxamount',
    :'tax_breakdown' => :'Array<TaxBreakdownInput>',
    :'transaction_count' => :'Integer',
    :'tax_due_type' => :'TaxDueDateType'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 283

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      date == o.date &&
      category_code == o.category_code &&
      currency == o.currency &&
      tax_exclusive_amount == o.tax_exclusive_amount &&
      tax_amount == o.tax_amount &&
      tax_breakdown == o.tax_breakdown &&
      transaction_count == o.transaction_count &&
      tax_due_type == o.tax_due_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


298
299
300
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 298

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



304
305
306
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 304

def hash
  [date, category_code, currency, tax_exclusive_amount, tax_amount, tax_breakdown, transaction_count, tax_due_type].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 169

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @date.nil?
    invalid_properties.push('invalid value for "date", date cannot be nil.')
  end

  if @category_code.nil?
    invalid_properties.push('invalid value for "category_code", category_code cannot be nil.')
  end

  if @tax_exclusive_amount.nil?
    invalid_properties.push('invalid value for "tax_exclusive_amount", tax_exclusive_amount cannot be nil.')
  end

  if @tax_amount.nil?
    invalid_properties.push('invalid value for "tax_amount", tax_amount cannot be nil.')
  end

  if @tax_breakdown.nil?
    invalid_properties.push('invalid value for "tax_breakdown", tax_breakdown cannot be nil.')
  end

  if @tax_breakdown.length < 1
    invalid_properties.push('invalid value for "tax_breakdown", number of items must be greater than or equal to 1.')
  end

  if !@transaction_count.nil? && @transaction_count < 1
    invalid_properties.push('invalid value for "transaction_count", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 333

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



205
206
207
208
209
210
211
212
213
214
215
# File 'lib/factpulse/models/aggregated_transaction_input.rb', line 205

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @date.nil?
  return false if @category_code.nil?
  return false if @tax_exclusive_amount.nil?
  return false if @tax_amount.nil?
  return false if @tax_breakdown.nil?
  return false if @tax_breakdown.length < 1
  return false if !@transaction_count.nil? && @transaction_count < 1
  true
end