Class: FactPulse::ConvertErrorResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::ConvertErrorResponse
- Defined in:
- lib/factpulse/models/convert_error_response.rb
Overview
Reponse erreur de conversion.
Instance Attribute Summary collapse
-
#conversion_id ⇒ Object
Returns the value of attribute conversion_id.
-
#error ⇒ Object
Code erreur.
-
#message ⇒ Object
Message d'erreur.
-
#resume_url ⇒ Object
Returns the value of attribute resume_url.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConvertErrorResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ConvertErrorResponse
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/factpulse/models/convert_error_response.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::ConvertErrorResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::ConvertErrorResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = 'error' end if attributes.key?(:'error') self.error = attributes[:'error'] else self.error = nil end if attributes.key?(:'message') self. = attributes[:'message'] else self. = nil end if attributes.key?(:'conversion_id') self.conversion_id = attributes[:'conversion_id'] end if attributes.key?(:'resume_url') self.resume_url = attributes[:'resume_url'] end end |
Instance Attribute Details
#conversion_id ⇒ Object
Returns the value of attribute conversion_id.
27 28 29 |
# File 'lib/factpulse/models/convert_error_response.rb', line 27 def conversion_id @conversion_id end |
#error ⇒ Object
Code erreur
22 23 24 |
# File 'lib/factpulse/models/convert_error_response.rb', line 22 def error @error end |
#message ⇒ Object
Message d'erreur
25 26 27 |
# File 'lib/factpulse/models/convert_error_response.rb', line 25 def end |
#resume_url ⇒ Object
Returns the value of attribute resume_url.
29 30 31 |
# File 'lib/factpulse/models/convert_error_response.rb', line 29 def resume_url @resume_url end |
#status ⇒ Object
Returns the value of attribute status.
19 20 21 |
# File 'lib/factpulse/models/convert_error_response.rb', line 19 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/factpulse/models/convert_error_response.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/factpulse/models/convert_error_response.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 |
# File 'lib/factpulse/models/convert_error_response.rb', line 32 def self.attribute_map { :'status' => :'status', :'error' => :'error', :'message' => :'message', :'conversion_id' => :'conversion_id', :'resume_url' => :'resume_url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/factpulse/models/convert_error_response.rb', line 186 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
64 65 66 67 68 69 |
# File 'lib/factpulse/models/convert_error_response.rb', line 64 def self.openapi_nullable Set.new([ :'conversion_id', :'resume_url' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 |
# File 'lib/factpulse/models/convert_error_response.rb', line 53 def self.openapi_types { :'status' => :'String', :'error' => :'String', :'message' => :'String', :'conversion_id' => :'String', :'resume_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 |
# File 'lib/factpulse/models/convert_error_response.rb', line 161 def ==(o) return true if self.equal?(o) self.class == o.class && status == o.status && error == o.error && == o. && conversion_id == o.conversion_id && resume_url == o.resume_url end |
#eql?(o) ⇒ Boolean
173 174 175 |
# File 'lib/factpulse/models/convert_error_response.rb', line 173 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
179 180 181 |
# File 'lib/factpulse/models/convert_error_response.rb', line 179 def hash [status, error, , conversion_id, resume_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/factpulse/models/convert_error_response.rb', line 116 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @error.nil? invalid_properties.push('invalid value for "error", error cannot be nil.') end if .nil? invalid_properties.push('invalid value for "message", message cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/factpulse/models/convert_error_response.rb', line 208 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
132 133 134 135 136 137 |
# File 'lib/factpulse/models/convert_error_response.rb', line 132 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @error.nil? return false if .nil? true end |