Class: FactPulse::DownloadsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/factpulse/api/downloads_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ DownloadsApi

Returns a new instance of DownloadsApi.



19
20
21
# File 'lib/factpulse/api/downloads_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_client ⇒ Object

Returns the value of attribute api_client.



17
18
19
# File 'lib/factpulse/api/downloads_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#check_file_api_v1_download_download_id_head(download_id, opts = {}) ⇒ Object

Check if a file exists Check if a temporary file exists and get its metadata without downloading. Useful for: - Verifying a download URL is still valid - Getting file size before downloading - Checking expiration time Security: Requires authentication, only file owner can check.

Parameters:

  • download_id (String)
  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:

  • (Object)


27
28
29
30
# File 'lib/factpulse/api/downloads_api.rb', line 27

def check_file_api_v1_download_download_id_head(download_id, opts = {})
  data, _status_code, _headers = check_file_api_v1_download_download_id_head_with_http_info(download_id, opts)
  data
end

#check_file_api_v1_download_download_id_head_0(download_id, opts = {}) ⇒ Object

Check if a file exists Check if a temporary file exists and get its metadata without downloading. Useful for: - Verifying a download URL is still valid - Getting file size before downloading - Checking expiration time Security: Requires authentication, only file owner can check.

Parameters:

  • download_id (String)
  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:

  • (Object)


90
91
92
93
# File 'lib/factpulse/api/downloads_api.rb', line 90

def check_file_api_v1_download_download_id_head_0(download_id, opts = {})
  data, _status_code, _headers = check_file_api_v1_download_download_id_head_0_with_http_info(download_id, opts)
  data
end

#check_file_api_v1_download_download_id_head_0_with_http_info(download_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Check if a file exists Check if a temporary file exists and get its metadata without downloading. Useful for: - Verifying a download URL is still valid - Getting file size before downloading - Checking expiration time Security: Requires authentication, only file owner can check.

Parameters:

  • download_id (String)
  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:

  • (Array<(Object, Integer, Hash)>) —

    Object data, response status code and response headers



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/factpulse/api/downloads_api.rb', line 100

def check_file_api_v1_download_download_id_head_0_with_http_info(download_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DownloadsApi.check_file_api_v1_download_download_id_head_0 ...'
  end
  # verify the required parameter 'download_id' is set
  if @api_client.config.client_side_validation && download_id.nil?
    fail ArgumentError, "Missing the required parameter 'download_id' when calling DownloadsApi.check_file_api_v1_download_download_id_head_0"
  end
  # resource path
  local_var_path = '/api/v1/download/{download_id}'.sub('{' + 'download_id' + '}', CGI.escape(download_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBearer']

  new_options = opts.merge(
    :operation => :"DownloadsApi.check_file_api_v1_download_download_id_head_0",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:HEAD, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DownloadsApi#check_file_api_v1_download_download_id_head_0\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#check_file_api_v1_download_download_id_head_with_http_info(download_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Check if a file exists Check if a temporary file exists and get its metadata without downloading. Useful for: - Verifying a download URL is still valid - Getting file size before downloading - Checking expiration time Security: Requires authentication, only file owner can check.

Parameters:

  • download_id (String)
  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:

  • (Array<(Object, Integer, Hash)>) —

    Object data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/factpulse/api/downloads_api.rb', line 37

def check_file_api_v1_download_download_id_head_with_http_info(download_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DownloadsApi.check_file_api_v1_download_download_id_head ...'
  end
  # verify the required parameter 'download_id' is set
  if @api_client.config.client_side_validation && download_id.nil?
    fail ArgumentError, "Missing the required parameter 'download_id' when calling DownloadsApi.check_file_api_v1_download_download_id_head"
  end
  # resource path
  local_var_path = '/api/v1/download/{download_id}'.sub('{' + 'download_id' + '}', CGI.escape(download_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBearer']

  new_options = opts.merge(
    :operation => :"DownloadsApi.check_file_api_v1_download_download_id_head",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:HEAD, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DownloadsApi#check_file_api_v1_download_download_id_head\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#download_file_api_v1_download_download_id_get(download_id, opts = {}) ⇒ Object

Download a temporary file Download a file stored temporarily after asynchronous processing. Usage: - This URL is provided in webhook notifications when using webhook_mode: \"download_url\" - Files are automatically deleted after 1 hour - Each file can only be downloaded until it expires Security: - Requires a valid JWT token - Only the user who initiated the task can download the file

Parameters:

  • download_id (String)
  • opts (Hash) (defaults to: {}) —

    the optional parameters

Options Hash (opts):

  • :delete_after (Boolean) —

    If true, delete the file after download (one-time download) (default to false)

Returns:

  • (Object)


154
155
156
157
# File 'lib/factpulse/api/downloads_api.rb', line 154

def download_file_api_v1_download_download_id_get(download_id, opts = {})
  data, _status_code, _headers = download_file_api_v1_download_download_id_get_with_http_info(download_id, opts)
  data
end

#download_file_api_v1_download_download_id_get_0(download_id, opts = {}) ⇒ Object

Download a temporary file Download a file stored temporarily after asynchronous processing. Usage: - This URL is provided in webhook notifications when using webhook_mode: \"download_url\" - Files are automatically deleted after 1 hour - Each file can only be downloaded until it expires Security: - Requires a valid JWT token - Only the user who initiated the task can download the file

Parameters:

  • download_id (String)
  • opts (Hash) (defaults to: {}) —

    the optional parameters

Options Hash (opts):

  • :delete_after (Boolean) —

    If true, delete the file after download (one-time download) (default to false)

Returns:

  • (Object)


220
221
222
223
# File 'lib/factpulse/api/downloads_api.rb', line 220

def download_file_api_v1_download_download_id_get_0(download_id, opts = {})
  data, _status_code, _headers = download_file_api_v1_download_download_id_get_0_with_http_info(download_id, opts)
  data
end

#download_file_api_v1_download_download_id_get_0_with_http_info(download_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Download a temporary file Download a file stored temporarily after asynchronous processing. Usage: - This URL is provided in webhook notifications when using `webhook_mode: &quot;download_url&quot;` - Files are automatically deleted after 1 hour - Each file can only be downloaded until it expires Security: - Requires a valid JWT token - Only the user who initiated the task can download the file

Parameters:

  • download_id (String)
  • opts (Hash) (defaults to: {}) —

    the optional parameters

Options Hash (opts):

  • :delete_after (Boolean) —

    If true, delete the file after download (one-time download) (default to false)

Returns:

  • (Array<(Object, Integer, Hash)>) —

    Object data, response status code and response headers



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/factpulse/api/downloads_api.rb', line 231

def download_file_api_v1_download_download_id_get_0_with_http_info(download_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DownloadsApi.download_file_api_v1_download_download_id_get_0 ...'
  end
  # verify the required parameter 'download_id' is set
  if @api_client.config.client_side_validation && download_id.nil?
    fail ArgumentError, "Missing the required parameter 'download_id' when calling DownloadsApi.download_file_api_v1_download_download_id_get_0"
  end
  # resource path
  local_var_path = '/api/v1/download/{download_id}'.sub('{' + 'download_id' + '}', CGI.escape(download_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'delete_after'] = opts[:'delete_after'] if !opts[:'delete_after'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/pdf', 'application/xml', 'application/octet-stream']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBearer']

  new_options = opts.merge(
    :operation => :"DownloadsApi.download_file_api_v1_download_download_id_get_0",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DownloadsApi#download_file_api_v1_download_download_id_get_0\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#download_file_api_v1_download_download_id_get_with_http_info(download_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Download a temporary file Download a file stored temporarily after asynchronous processing. Usage: - This URL is provided in webhook notifications when using `webhook_mode: &quot;download_url&quot;` - Files are automatically deleted after 1 hour - Each file can only be downloaded until it expires Security: - Requires a valid JWT token - Only the user who initiated the task can download the file

Parameters:

  • download_id (String)
  • opts (Hash) (defaults to: {}) —

    the optional parameters

Options Hash (opts):

  • :delete_after (Boolean) —

    If true, delete the file after download (one-time download) (default to false)

Returns:

  • (Array<(Object, Integer, Hash)>) —

    Object data, response status code and response headers



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/factpulse/api/downloads_api.rb', line 165

def download_file_api_v1_download_download_id_get_with_http_info(download_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DownloadsApi.download_file_api_v1_download_download_id_get ...'
  end
  # verify the required parameter 'download_id' is set
  if @api_client.config.client_side_validation && download_id.nil?
    fail ArgumentError, "Missing the required parameter 'download_id' when calling DownloadsApi.download_file_api_v1_download_download_id_get"
  end
  # resource path
  local_var_path = '/api/v1/download/{download_id}'.sub('{' + 'download_id' + '}', CGI.escape(download_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'delete_after'] = opts[:'delete_after'] if !opts[:'delete_after'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/pdf', 'application/xml', 'application/octet-stream']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBearer']

  new_options = opts.merge(
    :operation => :"DownloadsApi.download_file_api_v1_download_download_id_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DownloadsApi#download_file_api_v1_download_download_id_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end