Class: FactPulse::ElectronicAddress

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/electronic_address.rb

Overview

Represents an electronic invoicing address, composed of an identifier and its scheme (SchemeID) in accordance with EN16931. Example: { "identifier": "123456789", "scheme_id": "0225" }

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ElectronicAddress

Initializes the object



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/factpulse/models/electronic_address.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::ElectronicAddress` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::ElectronicAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'identifier')
    self.identifier = attributes[:'identifier']
  else
    self.identifier = nil
  end

  if attributes.key?(:'scheme_id')
    self.scheme_id = attributes[:'scheme_id']
  end
end

Instance Attribute Details

#identifier ⇒ Object

Electronic address identifier (e.g., SIREN, SIRET, routing code)



20
21
22
# File 'lib/factpulse/models/electronic_address.rb', line 20

def identifier
  @identifier
end

#scheme_id ⇒ Object

Identification scheme (EAS code)



23
24
25
# File 'lib/factpulse/models/electronic_address.rb', line 23

def scheme_id
  @scheme_id
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



56
57
58
# File 'lib/factpulse/models/electronic_address.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/factpulse/models/electronic_address.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
# File 'lib/factpulse/models/electronic_address.rb', line 48

def self.attribute_map
  {
    :'identifier' => :'identifier',
    :'scheme_id' => :'schemeId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/factpulse/models/electronic_address.rb', line 160

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



74
75
76
77
# File 'lib/factpulse/models/electronic_address.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



66
67
68
69
70
71
# File 'lib/factpulse/models/electronic_address.rb', line 66

def self.openapi_types
  {
    :'identifier' => :'String',
    :'scheme_id' => :'SchemeID'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



138
139
140
141
142
143
# File 'lib/factpulse/models/electronic_address.rb', line 138

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      identifier == o.identifier &&
      scheme_id == o.scheme_id
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


147
148
149
# File 'lib/factpulse/models/electronic_address.rb', line 147

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.



153
154
155
# File 'lib/factpulse/models/electronic_address.rb', line 153

def hash
  [identifier, scheme_id].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?



108
109
110
111
112
113
114
115
116
# File 'lib/factpulse/models/electronic_address.rb', line 108

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @identifier.nil?
    invalid_properties.push('invalid value for "identifier", identifier cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash



182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/factpulse/models/electronic_address.rb', line 182

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid



120
121
122
123
124
# File 'lib/factpulse/models/electronic_address.rb', line 120

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @identifier.nil?
  true
end