Class: FactPulse::FlowSummary

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/flow_summary.rb

Overview

Summary of a flow in search results.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FlowSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/factpulse/models/flow_summary.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::FlowSummary` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::FlowSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'flow_id')
    self.flow_id = attributes[:'flow_id']
  else
    self.flow_id = nil
  end

  if attributes.key?(:'tracking_id')
    self.tracking_id = attributes[:'tracking_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'flow_type')
    self.flow_type = attributes[:'flow_type']
  end

  if attributes.key?(:'flow_direction')
    self.flow_direction = attributes[:'flow_direction']
  end

  if attributes.key?(:'acknowledgment_status')
    self.acknowledgment_status = attributes[:'acknowledgment_status']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#acknowledgment_status ⇒ Object

Returns the value of attribute acknowledgment_status.



31
32
33
# File 'lib/factpulse/models/flow_summary.rb', line 31

def acknowledgment_status
  @acknowledgment_status
end

#created_at ⇒ Object

Returns the value of attribute created_at.



33
34
35
# File 'lib/factpulse/models/flow_summary.rb', line 33

def created_at
  @created_at
end

#flow_direction ⇒ Object

Returns the value of attribute flow_direction.



29
30
31
# File 'lib/factpulse/models/flow_summary.rb', line 29

def flow_direction
  @flow_direction
end

#flow_id ⇒ Object

Unique flow identifier



20
21
22
# File 'lib/factpulse/models/flow_summary.rb', line 20

def flow_id
  @flow_id
end

#flow_type ⇒ Object

Returns the value of attribute flow_type.



27
28
29
# File 'lib/factpulse/models/flow_summary.rb', line 27

def flow_type
  @flow_type
end

#name ⇒ Object

Flow name



25
26
27
# File 'lib/factpulse/models/flow_summary.rb', line 25

def name
  @name
end

#tracking_id ⇒ Object

Returns the value of attribute tracking_id.



22
23
24
# File 'lib/factpulse/models/flow_summary.rb', line 22

def tracking_id
  @tracking_id
end

#updated_at ⇒ Object

Returns the value of attribute updated_at.



35
36
37
# File 'lib/factpulse/models/flow_summary.rb', line 35

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



52
53
54
# File 'lib/factpulse/models/flow_summary.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/factpulse/models/flow_summary.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/factpulse/models/flow_summary.rb', line 38

def self.attribute_map
  {
    :'flow_id' => :'flow_id',
    :'tracking_id' => :'tracking_id',
    :'name' => :'name',
    :'flow_type' => :'flow_type',
    :'flow_direction' => :'flow_direction',
    :'acknowledgment_status' => :'acknowledgment_status',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/factpulse/models/flow_summary.rb', line 215

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



76
77
78
79
80
81
82
83
84
85
# File 'lib/factpulse/models/flow_summary.rb', line 76

def self.openapi_nullable
  Set.new([
    :'tracking_id',
    :'flow_type',
    :'flow_direction',
    :'acknowledgment_status',
    :'created_at',
    :'updated_at'
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/factpulse/models/flow_summary.rb', line 62

def self.openapi_types
  {
    :'flow_id' => :'String',
    :'tracking_id' => :'String',
    :'name' => :'String',
    :'flow_type' => :'String',
    :'flow_direction' => :'String',
    :'acknowledgment_status' => :'String',
    :'created_at' => :'String',
    :'updated_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/factpulse/models/flow_summary.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      flow_id == o.flow_id &&
      tracking_id == o.tracking_id &&
      name == o.name &&
      flow_type == o.flow_type &&
      flow_direction == o.flow_direction &&
      acknowledgment_status == o.acknowledgment_status &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


202
203
204
# File 'lib/factpulse/models/flow_summary.rb', line 202

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



208
209
210
# File 'lib/factpulse/models/flow_summary.rb', line 208

def hash
  [flow_id, tracking_id, name, flow_type, flow_direction, acknowledgment_status, created_at, updated_at].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/factpulse/models/flow_summary.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @flow_id.nil?
    invalid_properties.push('invalid value for "flow_id", flow_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/factpulse/models/flow_summary.rb', line 237

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



158
159
160
161
162
163
# File 'lib/factpulse/models/flow_summary.rb', line 158

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @flow_id.nil?
  return false if @name.nil?
  true
end