Class: FactPulse::Fournisseur

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/fournisseur.rb

Overview

Informations sur le fournisseur qui émet la facture.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Fournisseur

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/factpulse/models/fournisseur.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::Fournisseur` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::Fournisseur`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'adresse_electronique')
    self.adresse_electronique = attributes[:'adresse_electronique']
  else
    self.adresse_electronique = nil
  end

  if attributes.key?(:'id_fournisseur')
    self.id_fournisseur = attributes[:'id_fournisseur']
  else
    self.id_fournisseur = nil
  end

  if attributes.key?(:'code_coordonnees_bancaires_fournisseur')
    self.code_coordonnees_bancaires_fournisseur = attributes[:'code_coordonnees_bancaires_fournisseur']
  end

  if attributes.key?(:'id_service_fournisseur')
    self.id_service_fournisseur = attributes[:'id_service_fournisseur']
  end

  if attributes.key?(:'nom')
    self.nom = attributes[:'nom']
  end

  if attributes.key?(:'siret')
    self.siret = attributes[:'siret']
  end

  if attributes.key?(:'numero_tva_intra')
    self.numero_tva_intra = attributes[:'numero_tva_intra']
  end

  if attributes.key?(:'iban')
    self.iban = attributes[:'iban']
  end

  if attributes.key?(:'adresse_postale')
    self.adresse_postale = attributes[:'adresse_postale']
  end
end

Instance Attribute Details

#adresse_electronique ⇒ Object

Returns the value of attribute adresse_electronique.



19
20
21
# File 'lib/factpulse/models/fournisseur.rb', line 19

def adresse_electronique
  @adresse_electronique
end

#adresse_postale ⇒ Object

Returns the value of attribute adresse_postale.



35
36
37
# File 'lib/factpulse/models/fournisseur.rb', line 35

def adresse_postale
  @adresse_postale
end

#code_coordonnees_bancaires_fournisseur ⇒ Object

Returns the value of attribute code_coordonnees_bancaires_fournisseur.



23
24
25
# File 'lib/factpulse/models/fournisseur.rb', line 23

def code_coordonnees_bancaires_fournisseur
  @code_coordonnees_bancaires_fournisseur
end

#iban ⇒ Object

Returns the value of attribute iban.



33
34
35
# File 'lib/factpulse/models/fournisseur.rb', line 33

def iban
  @iban
end

#id_fournisseur ⇒ Object

Returns the value of attribute id_fournisseur.



21
22
23
# File 'lib/factpulse/models/fournisseur.rb', line 21

def id_fournisseur
  @id_fournisseur
end

#id_service_fournisseur ⇒ Object

Returns the value of attribute id_service_fournisseur.



25
26
27
# File 'lib/factpulse/models/fournisseur.rb', line 25

def id_service_fournisseur
  @id_service_fournisseur
end

#nom ⇒ Object

Returns the value of attribute nom.



27
28
29
# File 'lib/factpulse/models/fournisseur.rb', line 27

def nom
  @nom
end

#numero_tva_intra ⇒ Object

Returns the value of attribute numero_tva_intra.



31
32
33
# File 'lib/factpulse/models/fournisseur.rb', line 31

def numero_tva_intra
  @numero_tva_intra
end

#siret ⇒ Object

Returns the value of attribute siret.



29
30
31
# File 'lib/factpulse/models/fournisseur.rb', line 29

def siret
  @siret
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



53
54
55
# File 'lib/factpulse/models/fournisseur.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/factpulse/models/fournisseur.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/factpulse/models/fournisseur.rb', line 38

def self.attribute_map
  {
    :'adresse_electronique' => :'adresseElectronique',
    :'id_fournisseur' => :'idFournisseur',
    :'code_coordonnees_bancaires_fournisseur' => :'codeCoordonneesBancairesFournisseur',
    :'id_service_fournisseur' => :'idServiceFournisseur',
    :'nom' => :'nom',
    :'siret' => :'siret',
    :'numero_tva_intra' => :'numeroTvaIntra',
    :'iban' => :'iban',
    :'adresse_postale' => :'adressePostale'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/factpulse/models/fournisseur.rb', line 223

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



78
79
80
81
82
83
84
85
86
87
88
# File 'lib/factpulse/models/fournisseur.rb', line 78

def self.openapi_nullable
  Set.new([
    :'code_coordonnees_bancaires_fournisseur',
    :'id_service_fournisseur',
    :'nom',
    :'siret',
    :'numero_tva_intra',
    :'iban',
    :'adresse_postale'
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/factpulse/models/fournisseur.rb', line 63

def self.openapi_types
  {
    :'adresse_electronique' => :'AdresseElectronique',
    :'id_fournisseur' => :'Integer',
    :'code_coordonnees_bancaires_fournisseur' => :'Integer',
    :'id_service_fournisseur' => :'Integer',
    :'nom' => :'String',
    :'siret' => :'String',
    :'numero_tva_intra' => :'String',
    :'iban' => :'String',
    :'adresse_postale' => :'AdressePostale'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/factpulse/models/fournisseur.rb', line 194

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      adresse_electronique == o.adresse_electronique &&
      id_fournisseur == o.id_fournisseur &&
      code_coordonnees_bancaires_fournisseur == o.code_coordonnees_bancaires_fournisseur &&
      id_service_fournisseur == o.id_service_fournisseur &&
      nom == o.nom &&
      siret == o.siret &&
      numero_tva_intra == o.numero_tva_intra &&
      iban == o.iban &&
      adresse_postale == o.adresse_postale
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


210
211
212
# File 'lib/factpulse/models/fournisseur.rb', line 210

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



216
217
218
# File 'lib/factpulse/models/fournisseur.rb', line 216

def hash
  [adresse_electronique, id_fournisseur, code_coordonnees_bancaires_fournisseur, id_service_fournisseur, nom, siret, numero_tva_intra, iban, adresse_postale].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/factpulse/models/fournisseur.rb', line 149

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @adresse_electronique.nil?
    invalid_properties.push('invalid value for "adresse_electronique", adresse_electronique cannot be nil.')
  end

  if @id_fournisseur.nil?
    invalid_properties.push('invalid value for "id_fournisseur", id_fournisseur cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/factpulse/models/fournisseur.rb', line 245

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



165
166
167
168
169
170
# File 'lib/factpulse/models/fournisseur.rb', line 165

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @adresse_electronique.nil?
  return false if @id_fournisseur.nil?
  true
end