Class: FactPulse::GetStructureResponse

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/get_structure_response.rb

Overview

Structure details.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetStructureResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/factpulse/models/get_structure_response.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::GetStructureResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::GetStructureResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'return_code')
    self.return_code = attributes[:'return_code']
  else
    self.return_code = nil
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  else
    self.message = nil
  end

  if attributes.key?(:'structure_id')
    self.structure_id = attributes[:'structure_id']
  end

  if attributes.key?(:'structure_identifier')
    self.structure_identifier = attributes[:'structure_identifier']
  end

  if attributes.key?(:'structure_label')
    self.structure_label = attributes[:'structure_label']
  end

  if attributes.key?(:'company_name')
    self.company_name = attributes[:'company_name']
  end

  if attributes.key?(:'vat_number')
    self.vat_number = attributes[:'vat_number']
  end

  if attributes.key?(:'structure_email')
    self.structure_email = attributes[:'structure_email']
  end

  if attributes.key?(:'parameters')
    self.parameters = attributes[:'parameters']
  end
end

Instance Attribute Details

#company_nameObject

Returns the value of attribute company_name.



31
32
33
# File 'lib/factpulse/models/get_structure_response.rb', line 31

def company_name
  @company_name
end

#messageObject

Response message



23
24
25
# File 'lib/factpulse/models/get_structure_response.rb', line 23

def message
  @message
end

#parametersObject

Returns the value of attribute parameters.



37
38
39
# File 'lib/factpulse/models/get_structure_response.rb', line 37

def parameters
  @parameters
end

#return_codeObject

Return code (0 = success)



20
21
22
# File 'lib/factpulse/models/get_structure_response.rb', line 20

def return_code
  @return_code
end

#structure_emailObject

Returns the value of attribute structure_email.



35
36
37
# File 'lib/factpulse/models/get_structure_response.rb', line 35

def structure_email
  @structure_email
end

#structure_idObject

Returns the value of attribute structure_id.



25
26
27
# File 'lib/factpulse/models/get_structure_response.rb', line 25

def structure_id
  @structure_id
end

#structure_identifierObject

Returns the value of attribute structure_identifier.



27
28
29
# File 'lib/factpulse/models/get_structure_response.rb', line 27

def structure_identifier
  @structure_identifier
end

#structure_labelObject

Returns the value of attribute structure_label.



29
30
31
# File 'lib/factpulse/models/get_structure_response.rb', line 29

def structure_label
  @structure_label
end

#vat_numberObject

Returns the value of attribute vat_number.



33
34
35
# File 'lib/factpulse/models/get_structure_response.rb', line 33

def vat_number
  @vat_number
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/factpulse/models/get_structure_response.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/factpulse/models/get_structure_response.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/factpulse/models/get_structure_response.rb', line 40

def self.attribute_map
  {
    :'return_code' => :'returnCode',
    :'message' => :'message',
    :'structure_id' => :'structureId',
    :'structure_identifier' => :'structureIdentifier',
    :'structure_label' => :'structureLabel',
    :'company_name' => :'companyName',
    :'vat_number' => :'vatNumber',
    :'structure_email' => :'structureEmail',
    :'parameters' => :'parameters'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/factpulse/models/get_structure_response.rb', line 225

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



80
81
82
83
84
85
86
87
88
89
90
# File 'lib/factpulse/models/get_structure_response.rb', line 80

def self.openapi_nullable
  Set.new([
    :'structure_id',
    :'structure_identifier',
    :'structure_label',
    :'company_name',
    :'vat_number',
    :'structure_email',
    :'parameters'
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/factpulse/models/get_structure_response.rb', line 65

def self.openapi_types
  {
    :'return_code' => :'Integer',
    :'message' => :'String',
    :'structure_id' => :'Integer',
    :'structure_identifier' => :'String',
    :'structure_label' => :'String',
    :'company_name' => :'String',
    :'vat_number' => :'String',
    :'structure_email' => :'String',
    :'parameters' => :'StructureParameters'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/factpulse/models/get_structure_response.rb', line 196

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      return_code == o.return_code &&
      message == o.message &&
      structure_id == o.structure_id &&
      structure_identifier == o.structure_identifier &&
      structure_label == o.structure_label &&
      company_name == o.company_name &&
      vat_number == o.vat_number &&
      structure_email == o.structure_email &&
      parameters == o.parameters
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


212
213
214
# File 'lib/factpulse/models/get_structure_response.rb', line 212

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



218
219
220
# File 'lib/factpulse/models/get_structure_response.rb', line 218

def hash
  [return_code, message, structure_id, structure_identifier, structure_label, company_name, vat_number, structure_email, parameters].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/factpulse/models/get_structure_response.rb', line 151

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @return_code.nil?
    invalid_properties.push('invalid value for "return_code", return_code cannot be nil.')
  end

  if @message.nil?
    invalid_properties.push('invalid value for "message", message cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/factpulse/models/get_structure_response.rb', line 247

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
170
171
172
# File 'lib/factpulse/models/get_structure_response.rb', line 167

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @return_code.nil?
  return false if @message.nil?
  true
end