Class: FactPulse::InvoiceLifecycle

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/invoice_lifecycle.rb

Overview

Cycle de vie d'une facture specifique.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InvoiceLifecycle

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/factpulse/models/invoice_lifecycle.rb', line 69

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::InvoiceLifecycle` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::InvoiceLifecycle`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'seller_id')
    self.seller_id = attributes[:'seller_id']
  end

  if attributes.key?(:'invoice_id')
    self.invoice_id = attributes[:'invoice_id']
  else
    self.invoice_id = nil
  end

  if attributes.key?(:'events')
    if (value = attributes[:'events']).is_a?(Array)
      self.events = value
    end
  end

  if attributes.key?(:'total_events')
    self.total_events = attributes[:'total_events']
  else
    self.total_events = nil
  end
end

Instance Attribute Details

#eventsObject

Evenements de cycle de vie tries chronologiquement



25
26
27
# File 'lib/factpulse/models/invoice_lifecycle.rb', line 25

def events
  @events
end

#invoice_idObject

Reference de la facture (IssuerAssignedID du CDAR)



22
23
24
# File 'lib/factpulse/models/invoice_lifecycle.rb', line 22

def invoice_id
  @invoice_id
end

#seller_idObject

Returns the value of attribute seller_id.



19
20
21
# File 'lib/factpulse/models/invoice_lifecycle.rb', line 19

def seller_id
  @seller_id
end

#total_eventsObject

Nombre total d'evenements



28
29
30
# File 'lib/factpulse/models/invoice_lifecycle.rb', line 28

def total_events
  @total_events
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/factpulse/models/invoice_lifecycle.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/factpulse/models/invoice_lifecycle.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/factpulse/models/invoice_lifecycle.rb', line 31

def self.attribute_map
  {
    :'seller_id' => :'sellerId',
    :'invoice_id' => :'invoiceId',
    :'events' => :'events',
    :'total_events' => :'totalEvents'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/factpulse/models/invoice_lifecycle.rb', line 177

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
65
# File 'lib/factpulse/models/invoice_lifecycle.rb', line 61

def self.openapi_nullable
  Set.new([
    :'seller_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/factpulse/models/invoice_lifecycle.rb', line 51

def self.openapi_types
  {
    :'seller_id' => :'String',
    :'invoice_id' => :'String',
    :'events' => :'Array<LifecycleEvent>',
    :'total_events' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



153
154
155
156
157
158
159
160
# File 'lib/factpulse/models/invoice_lifecycle.rb', line 153

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      seller_id == o.seller_id &&
      invoice_id == o.invoice_id &&
      events == o.events &&
      total_events == o.total_events
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


164
165
166
# File 'lib/factpulse/models/invoice_lifecycle.rb', line 164

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



170
171
172
# File 'lib/factpulse/models/invoice_lifecycle.rb', line 170

def hash
  [seller_id, invoice_id, events, total_events].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/factpulse/models/invoice_lifecycle.rb', line 108

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @invoice_id.nil?
    invalid_properties.push('invalid value for "invoice_id", invoice_id cannot be nil.')
  end

  if @total_events.nil?
    invalid_properties.push('invalid value for "total_events", total_events cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/factpulse/models/invoice_lifecycle.rb', line 199

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



124
125
126
127
128
129
# File 'lib/factpulse/models/invoice_lifecycle.rb', line 124

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @invoice_id.nil?
  return false if @total_events.nil?
  true
end