Class: FactPulse::InvoicePaymentInput

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/invoice_payment_input.rb

Overview

Payment linked to a specific invoice (flux 10.2). Used for B2B international invoice payments.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InvoicePaymentInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/factpulse/models/invoice_payment_input.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::InvoicePaymentInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::InvoicePaymentInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'invoice_id')
    self.invoice_id = attributes[:'invoice_id']
  else
    self.invoice_id = nil
  end

  if attributes.key?(:'invoice_date')
    self.invoice_date = attributes[:'invoice_date']
  else
    self.invoice_date = nil
  end

  if attributes.key?(:'payment_date')
    self.payment_date = attributes[:'payment_date']
  else
    self.payment_date = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'amounts_by_rate')
    if (value = attributes[:'amounts_by_rate']).is_a?(Array)
      self.amounts_by_rate = value
    end
  else
    self.amounts_by_rate = nil
  end
end

Instance Attribute Details

#amounts_by_rate ⇒ Object

Payment amounts by VAT rate



31
32
33
# File 'lib/factpulse/models/invoice_payment_input.rb', line 31

def amounts_by_rate
  @amounts_by_rate
end

#currency ⇒ Object

Returns the value of attribute currency.



28
29
30
# File 'lib/factpulse/models/invoice_payment_input.rb', line 28

def currency
  @currency
end

#invoice_date ⇒ Object

Original invoice date



23
24
25
# File 'lib/factpulse/models/invoice_payment_input.rb', line 23

def invoice_date
  @invoice_date
end

#invoice_id ⇒ Object

Invoice identifier



20
21
22
# File 'lib/factpulse/models/invoice_payment_input.rb', line 20

def invoice_id
  @invoice_id
end

#payment_date ⇒ Object

Payment date



26
27
28
# File 'lib/factpulse/models/invoice_payment_input.rb', line 26

def payment_date
  @payment_date
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



45
46
47
# File 'lib/factpulse/models/invoice_payment_input.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/factpulse/models/invoice_payment_input.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/factpulse/models/invoice_payment_input.rb', line 34

def self.attribute_map
  {
    :'invoice_id' => :'invoiceId',
    :'invoice_date' => :'invoiceDate',
    :'payment_date' => :'paymentDate',
    :'currency' => :'currency',
    :'amounts_by_rate' => :'amountsByRate'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/factpulse/models/invoice_payment_input.rb', line 229

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



66
67
68
69
# File 'lib/factpulse/models/invoice_payment_input.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/factpulse/models/invoice_payment_input.rb', line 55

def self.openapi_types
  {
    :'invoice_id' => :'String',
    :'invoice_date' => :'Date',
    :'payment_date' => :'Date',
    :'currency' => :'Currency',
    :'amounts_by_rate' => :'Array<PaymentAmountByRate>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



204
205
206
207
208
209
210
211
212
# File 'lib/factpulse/models/invoice_payment_input.rb', line 204

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      invoice_id == o.invoice_id &&
      invoice_date == o.invoice_date &&
      payment_date == o.payment_date &&
      currency == o.currency &&
      amounts_by_rate == o.amounts_by_rate
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


216
217
218
# File 'lib/factpulse/models/invoice_payment_input.rb', line 216

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



222
223
224
# File 'lib/factpulse/models/invoice_payment_input.rb', line 222

def hash
  [invoice_id, invoice_date, payment_date, currency, amounts_by_rate].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/factpulse/models/invoice_payment_input.rb', line 120

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @invoice_id.nil?
    invalid_properties.push('invalid value for "invoice_id", invoice_id cannot be nil.')
  end

  if @invoice_date.nil?
    invalid_properties.push('invalid value for "invoice_date", invoice_date cannot be nil.')
  end

  if @payment_date.nil?
    invalid_properties.push('invalid value for "payment_date", payment_date cannot be nil.')
  end

  if @amounts_by_rate.nil?
    invalid_properties.push('invalid value for "amounts_by_rate", amounts_by_rate cannot be nil.')
  end

  if @amounts_by_rate.length < 1
    invalid_properties.push('invalid value for "amounts_by_rate", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/factpulse/models/invoice_payment_input.rb', line 251

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



148
149
150
151
152
153
154
155
156
# File 'lib/factpulse/models/invoice_payment_input.rb', line 148

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @invoice_id.nil?
  return false if @invoice_date.nil?
  return false if @payment_date.nil?
  return false if @amounts_by_rate.nil?
  return false if @amounts_by_rate.length < 1
  true
end