Class: FactPulse::InvoiceReferences

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/invoice_references.rb

Overview

Contains various invoice references (currency, type, etc.).

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InvoiceReferences

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/factpulse/models/invoice_references.rb', line 160

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::InvoiceReferences` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::InvoiceReferences`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'business_process_id')
    self.business_process_id = attributes[:'business_process_id']
  end

  if attributes.key?(:'invoice_currency')
    self.invoice_currency = attributes[:'invoice_currency']
  else
    self.invoice_currency = 'EUR'
  end

  if attributes.key?(:'payment_means')
    self.payment_means = attributes[:'payment_means']
  else
    self.payment_means = nil
  end

  if attributes.key?(:'payment_means_text')
    self.payment_means_text = attributes[:'payment_means_text']
  end

  if attributes.key?(:'invoice_type')
    self.invoice_type = attributes[:'invoice_type']
  else
    self.invoice_type = nil
  end

  if attributes.key?(:'vat_accounting_code')
    self.vat_accounting_code = attributes[:'vat_accounting_code']
  else
    self.vat_accounting_code = nil
  end

  if attributes.key?(:'buyer_reference')
    self.buyer_reference = attributes[:'buyer_reference']
  end

  if attributes.key?(:'contract_reference')
    self.contract_reference = attributes[:'contract_reference']
  end

  if attributes.key?(:'purchase_order_reference')
    self.purchase_order_reference = attributes[:'purchase_order_reference']
  end

  if attributes.key?(:'seller_order_reference')
    self.seller_order_reference = attributes[:'seller_order_reference']
  end

  if attributes.key?(:'receiving_advice_reference')
    self.receiving_advice_reference = attributes[:'receiving_advice_reference']
  end

  if attributes.key?(:'despatch_advice_reference')
    self.despatch_advice_reference = attributes[:'despatch_advice_reference']
  end

  if attributes.key?(:'tender_reference')
    self.tender_reference = attributes[:'tender_reference']
  end

  if attributes.key?(:'preceding_invoice_reference')
    self.preceding_invoice_reference = attributes[:'preceding_invoice_reference']
  end

  if attributes.key?(:'preceding_invoice_date')
    self.preceding_invoice_date = attributes[:'preceding_invoice_date']
  end

  if attributes.key?(:'project_reference')
    self.project_reference = attributes[:'project_reference']
  end

  if attributes.key?(:'project_name')
    self.project_name = attributes[:'project_name']
  end

  if attributes.key?(:'vat_exemption_reason')
    self.vat_exemption_reason = attributes[:'vat_exemption_reason']
  end
end

Instance Attribute Details

#business_process_id ⇒ Object

Returns the value of attribute business_process_id.



19
20
21
# File 'lib/factpulse/models/invoice_references.rb', line 19

def business_process_id
  @business_process_id
end

#buyer_reference ⇒ Object

Returns the value of attribute buyer_reference.



34
35
36
# File 'lib/factpulse/models/invoice_references.rb', line 34

def buyer_reference
  @buyer_reference
end

#contract_reference ⇒ Object

Returns the value of attribute contract_reference.



36
37
38
# File 'lib/factpulse/models/invoice_references.rb', line 36

def contract_reference
  @contract_reference
end

#despatch_advice_reference ⇒ Object

Returns the value of attribute despatch_advice_reference.



44
45
46
# File 'lib/factpulse/models/invoice_references.rb', line 44

def despatch_advice_reference
  @despatch_advice_reference
end

#invoice_currency ⇒ Object

Invoice currency code (BT-5). ISO 4217.



22
23
24
# File 'lib/factpulse/models/invoice_references.rb', line 22

def invoice_currency
  @invoice_currency
end

#invoice_type ⇒ Object

Returns the value of attribute invoice_type.



29
30
31
# File 'lib/factpulse/models/invoice_references.rb', line 29

def invoice_type
  @invoice_type
end

#payment_means ⇒ Object

Payment means type code (BT-81).



25
26
27
# File 'lib/factpulse/models/invoice_references.rb', line 25

def payment_means
  @payment_means
end

#payment_means_text ⇒ Object

Returns the value of attribute payment_means_text.



27
28
29
# File 'lib/factpulse/models/invoice_references.rb', line 27

def payment_means_text
  @payment_means_text
end

#preceding_invoice_date ⇒ Object

Returns the value of attribute preceding_invoice_date.



50
51
52
# File 'lib/factpulse/models/invoice_references.rb', line 50

def preceding_invoice_date
  @preceding_invoice_date
end

#preceding_invoice_reference ⇒ Object

Returns the value of attribute preceding_invoice_reference.



48
49
50
# File 'lib/factpulse/models/invoice_references.rb', line 48

def preceding_invoice_reference
  @preceding_invoice_reference
end

#project_name ⇒ Object

Returns the value of attribute project_name.



54
55
56
# File 'lib/factpulse/models/invoice_references.rb', line 54

def project_name
  @project_name
end

#project_reference ⇒ Object

Returns the value of attribute project_reference.



52
53
54
# File 'lib/factpulse/models/invoice_references.rb', line 52

def project_reference
  @project_reference
end

#purchase_order_reference ⇒ Object

Returns the value of attribute purchase_order_reference.



38
39
40
# File 'lib/factpulse/models/invoice_references.rb', line 38

def purchase_order_reference
  @purchase_order_reference
end

#receiving_advice_reference ⇒ Object

Returns the value of attribute receiving_advice_reference.



42
43
44
# File 'lib/factpulse/models/invoice_references.rb', line 42

def receiving_advice_reference
  @receiving_advice_reference
end

#seller_order_reference ⇒ Object

Returns the value of attribute seller_order_reference.



40
41
42
# File 'lib/factpulse/models/invoice_references.rb', line 40

def seller_order_reference
  @seller_order_reference
end

#tender_reference ⇒ Object

Returns the value of attribute tender_reference.



46
47
48
# File 'lib/factpulse/models/invoice_references.rb', line 46

def tender_reference
  @tender_reference
end

#vat_accounting_code ⇒ Object

VAT accounting code.



32
33
34
# File 'lib/factpulse/models/invoice_references.rb', line 32

def vat_accounting_code
  @vat_accounting_code
end

#vat_exemption_reason ⇒ Object

Returns the value of attribute vat_exemption_reason.



56
57
58
# File 'lib/factpulse/models/invoice_references.rb', line 56

def vat_exemption_reason
  @vat_exemption_reason
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



105
106
107
# File 'lib/factpulse/models/invoice_references.rb', line 105

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



110
111
112
# File 'lib/factpulse/models/invoice_references.rb', line 110

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/factpulse/models/invoice_references.rb', line 81

def self.attribute_map
  {
    :'business_process_id' => :'business_process_id',
    :'invoice_currency' => :'invoice_currency',
    :'payment_means' => :'payment_means',
    :'payment_means_text' => :'payment_means_text',
    :'invoice_type' => :'invoice_type',
    :'vat_accounting_code' => :'vat_accounting_code',
    :'buyer_reference' => :'buyer_reference',
    :'contract_reference' => :'contract_reference',
    :'purchase_order_reference' => :'purchase_order_reference',
    :'seller_order_reference' => :'seller_order_reference',
    :'receiving_advice_reference' => :'receiving_advice_reference',
    :'despatch_advice_reference' => :'despatch_advice_reference',
    :'tender_reference' => :'tender_reference',
    :'preceding_invoice_reference' => :'preceding_invoice_reference',
    :'preceding_invoice_date' => :'preceding_invoice_date',
    :'project_reference' => :'project_reference',
    :'project_name' => :'project_name',
    :'vat_exemption_reason' => :'vat_exemption_reason'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/factpulse/models/invoice_references.rb', line 355

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/factpulse/models/invoice_references.rb', line 139

def self.openapi_nullable
  Set.new([
    :'business_process_id',
    :'payment_means_text',
    :'buyer_reference',
    :'contract_reference',
    :'purchase_order_reference',
    :'seller_order_reference',
    :'receiving_advice_reference',
    :'despatch_advice_reference',
    :'tender_reference',
    :'preceding_invoice_reference',
    :'preceding_invoice_date',
    :'project_reference',
    :'project_name',
    :'vat_exemption_reason'
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/factpulse/models/invoice_references.rb', line 115

def self.openapi_types
  {
    :'business_process_id' => :'String',
    :'invoice_currency' => :'String',
    :'payment_means' => :'PaymentMeans',
    :'payment_means_text' => :'String',
    :'invoice_type' => :'InvoiceTypeCode',
    :'vat_accounting_code' => :'VATAccountingCode',
    :'buyer_reference' => :'String',
    :'contract_reference' => :'String',
    :'purchase_order_reference' => :'String',
    :'seller_order_reference' => :'String',
    :'receiving_advice_reference' => :'String',
    :'despatch_advice_reference' => :'String',
    :'tender_reference' => :'String',
    :'preceding_invoice_reference' => :'String',
    :'preceding_invoice_date' => :'String',
    :'project_reference' => :'String',
    :'project_name' => :'String',
    :'vat_exemption_reason' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/factpulse/models/invoice_references.rb', line 317

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      business_process_id == o.business_process_id &&
      invoice_currency == o.invoice_currency &&
      payment_means == o.payment_means &&
      payment_means_text == o.payment_means_text &&
      invoice_type == o.invoice_type &&
      vat_accounting_code == o.vat_accounting_code &&
      buyer_reference == o.buyer_reference &&
      contract_reference == o.contract_reference &&
      purchase_order_reference == o.purchase_order_reference &&
      seller_order_reference == o.seller_order_reference &&
      receiving_advice_reference == o.receiving_advice_reference &&
      despatch_advice_reference == o.despatch_advice_reference &&
      tender_reference == o.tender_reference &&
      preceding_invoice_reference == o.preceding_invoice_reference &&
      preceding_invoice_date == o.preceding_invoice_date &&
      project_reference == o.project_reference &&
      project_name == o.project_name &&
      vat_exemption_reason == o.vat_exemption_reason
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


342
343
344
# File 'lib/factpulse/models/invoice_references.rb', line 342

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



348
349
350
# File 'lib/factpulse/models/invoice_references.rb', line 348

def hash
  [business_process_id, invoice_currency, payment_means, payment_means_text, invoice_type, vat_accounting_code, buyer_reference, contract_reference, purchase_order_reference, seller_order_reference, receiving_advice_reference, despatch_advice_reference, tender_reference, preceding_invoice_reference, preceding_invoice_date, project_reference, project_name, vat_exemption_reason].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/factpulse/models/invoice_references.rb', line 257

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @payment_means.nil?
    invalid_properties.push('invalid value for "payment_means", payment_means cannot be nil.')
  end

  if @invoice_type.nil?
    invalid_properties.push('invalid value for "invoice_type", invoice_type cannot be nil.')
  end

  if @vat_accounting_code.nil?
    invalid_properties.push('invalid value for "vat_accounting_code", vat_accounting_code cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/factpulse/models/invoice_references.rb', line 377

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



277
278
279
280
281
282
283
# File 'lib/factpulse/models/invoice_references.rb', line 277

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @payment_means.nil?
  return false if @invoice_type.nil?
  return false if @vat_accounting_code.nil?
  true
end