Class: FactPulse::InvoiceTotals

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/invoice_totals.rb

Overview

Contains all invoice total amounts (BG-22).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InvoiceTotals

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/factpulse/models/invoice_totals.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::InvoiceTotals` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::InvoiceTotals`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'line_total_amount')
    self.line_total_amount = attributes[:'line_total_amount']
  end

  if attributes.key?(:'allowance_total_amount')
    self.allowance_total_amount = attributes[:'allowance_total_amount']
  end

  if attributes.key?(:'charge_total_amount')
    self.charge_total_amount = attributes[:'charge_total_amount']
  end

  if attributes.key?(:'total_net_amount')
    self.total_net_amount = attributes[:'total_net_amount']
  else
    self.total_net_amount = nil
  end

  if attributes.key?(:'vat_amount')
    self.vat_amount = attributes[:'vat_amount']
  else
    self.vat_amount = nil
  end

  if attributes.key?(:'total_gross_amount')
    self.total_gross_amount = attributes[:'total_gross_amount']
  else
    self.total_gross_amount = nil
  end

  if attributes.key?(:'prepayment')
    self.prepayment = attributes[:'prepayment']
  end

  if attributes.key?(:'rounding_amount')
    self.rounding_amount = attributes[:'rounding_amount']
  end

  if attributes.key?(:'amount_due')
    self.amount_due = attributes[:'amount_due']
  else
    self.amount_due = nil
  end

  if attributes.key?(:'global_allowance_amount')
    self.global_allowance_amount = attributes[:'global_allowance_amount']
  end

  if attributes.key?(:'global_allowance_reason')
    self.global_allowance_reason = attributes[:'global_allowance_reason']
  end
end

Instance Attribute Details

#allowance_total_amount ⇒ Object

Returns the value of attribute allowance_total_amount.



21
22
23
# File 'lib/factpulse/models/invoice_totals.rb', line 21

def allowance_total_amount
  @allowance_total_amount
end

#amount_due ⇒ Object

Returns the value of attribute amount_due.



35
36
37
# File 'lib/factpulse/models/invoice_totals.rb', line 35

def amount_due
  @amount_due
end

#charge_total_amount ⇒ Object

Returns the value of attribute charge_total_amount.



23
24
25
# File 'lib/factpulse/models/invoice_totals.rb', line 23

def charge_total_amount
  @charge_total_amount
end

#global_allowance_amount ⇒ Object

Returns the value of attribute global_allowance_amount.



37
38
39
# File 'lib/factpulse/models/invoice_totals.rb', line 37

def global_allowance_amount
  @global_allowance_amount
end

#global_allowance_reason ⇒ Object

Returns the value of attribute global_allowance_reason.



39
40
41
# File 'lib/factpulse/models/invoice_totals.rb', line 39

def global_allowance_reason
  @global_allowance_reason
end

#line_total_amount ⇒ Object

Returns the value of attribute line_total_amount.



19
20
21
# File 'lib/factpulse/models/invoice_totals.rb', line 19

def line_total_amount
  @line_total_amount
end

#prepayment ⇒ Object

Returns the value of attribute prepayment.



31
32
33
# File 'lib/factpulse/models/invoice_totals.rb', line 31

def prepayment
  @prepayment
end

#rounding_amount ⇒ Object

Returns the value of attribute rounding_amount.



33
34
35
# File 'lib/factpulse/models/invoice_totals.rb', line 33

def rounding_amount
  @rounding_amount
end

#total_gross_amount ⇒ Object

Returns the value of attribute total_gross_amount.



29
30
31
# File 'lib/factpulse/models/invoice_totals.rb', line 29

def total_gross_amount
  @total_gross_amount
end

#total_net_amount ⇒ Object

Returns the value of attribute total_net_amount.



25
26
27
# File 'lib/factpulse/models/invoice_totals.rb', line 25

def total_net_amount
  @total_net_amount
end

#vat_amount ⇒ Object

Returns the value of attribute vat_amount.



27
28
29
# File 'lib/factpulse/models/invoice_totals.rb', line 27

def vat_amount
  @vat_amount
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



59
60
61
# File 'lib/factpulse/models/invoice_totals.rb', line 59

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/factpulse/models/invoice_totals.rb', line 64

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/factpulse/models/invoice_totals.rb', line 42

def self.attribute_map
  {
    :'line_total_amount' => :'line_total_amount',
    :'allowance_total_amount' => :'allowance_total_amount',
    :'charge_total_amount' => :'charge_total_amount',
    :'total_net_amount' => :'total_net_amount',
    :'vat_amount' => :'vat_amount',
    :'total_gross_amount' => :'total_gross_amount',
    :'prepayment' => :'prepayment',
    :'rounding_amount' => :'rounding_amount',
    :'amount_due' => :'amount_due',
    :'global_allowance_amount' => :'globalAllowanceAmount',
    :'global_allowance_reason' => :'globalAllowanceReason'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/factpulse/models/invoice_totals.rb', line 274

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



86
87
88
89
90
91
92
93
94
95
# File 'lib/factpulse/models/invoice_totals.rb', line 86

def self.openapi_nullable
  Set.new([
    :'line_total_amount',
    :'allowance_total_amount',
    :'charge_total_amount',
    :'prepayment',
    :'rounding_amount',
    :'global_allowance_reason'
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/factpulse/models/invoice_totals.rb', line 69

def self.openapi_types
  {
    :'line_total_amount' => :'LineTotalAmount',
    :'allowance_total_amount' => :'AllowanceTotalAmount',
    :'charge_total_amount' => :'ChargeTotalAmount',
    :'total_net_amount' => :'TotalNetAmount',
    :'vat_amount' => :'TotalVATAmount',
    :'total_gross_amount' => :'TotalGrossAmount',
    :'prepayment' => :'InvoiceTotalsPrepayment',
    :'rounding_amount' => :'RoundingAmount',
    :'amount_due' => :'AmountDue',
    :'global_allowance_amount' => :'GlobalAllowanceAmount',
    :'global_allowance_reason' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/factpulse/models/invoice_totals.rb', line 243

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      line_total_amount == o.line_total_amount &&
      allowance_total_amount == o.allowance_total_amount &&
      charge_total_amount == o.charge_total_amount &&
      total_net_amount == o.total_net_amount &&
      vat_amount == o.vat_amount &&
      total_gross_amount == o.total_gross_amount &&
      prepayment == o.prepayment &&
      rounding_amount == o.rounding_amount &&
      amount_due == o.amount_due &&
      global_allowance_amount == o.global_allowance_amount &&
      global_allowance_reason == o.global_allowance_reason
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


261
262
263
# File 'lib/factpulse/models/invoice_totals.rb', line 261

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



267
268
269
# File 'lib/factpulse/models/invoice_totals.rb', line 267

def hash
  [line_total_amount, allowance_total_amount, charge_total_amount, total_net_amount, vat_amount, total_gross_amount, prepayment, rounding_amount, amount_due, global_allowance_amount, global_allowance_reason].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/factpulse/models/invoice_totals.rb', line 168

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @total_net_amount.nil?
    invalid_properties.push('invalid value for "total_net_amount", total_net_amount cannot be nil.')
  end

  if @vat_amount.nil?
    invalid_properties.push('invalid value for "vat_amount", vat_amount cannot be nil.')
  end

  if @total_gross_amount.nil?
    invalid_properties.push('invalid value for "total_gross_amount", total_gross_amount cannot be nil.')
  end

  if @amount_due.nil?
    invalid_properties.push('invalid value for "amount_due", amount_due cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/factpulse/models/invoice_totals.rb', line 296

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



192
193
194
195
196
197
198
199
# File 'lib/factpulse/models/invoice_totals.rb', line 192

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @total_net_amount.nil?
  return false if @vat_amount.nil?
  return false if @total_gross_amount.nil?
  return false if @amount_due.nil?
  true
end