Class: FactPulse::KeyRotationRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::KeyRotationRequest
- Defined in:
- lib/factpulse/models/key_rotation_request.rb
Overview
Request to rotate the client encryption key. This operation re-encrypts all secrets from the old key to the new key. Both keys must be base64-encoded AES-256 keys (32 bytes each).
Instance Attribute Summary collapse
-
#new_key ⇒ Object
New encryption key (base64-encoded AES-256).
-
#old_key ⇒ Object
Current encryption key (base64-encoded AES-256).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ KeyRotationRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ KeyRotationRequest
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/factpulse/models/key_rotation_request.rb', line 59 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::KeyRotationRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::KeyRotationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'old_key') self.old_key = attributes[:'old_key'] else self.old_key = nil end if attributes.key?(:'new_key') self.new_key = attributes[:'new_key'] else self.new_key = nil end end |
Instance Attribute Details
#new_key ⇒ Object
New encryption key (base64-encoded AES-256)
23 24 25 |
# File 'lib/factpulse/models/key_rotation_request.rb', line 23 def new_key @new_key end |
#old_key ⇒ Object
Current encryption key (base64-encoded AES-256)
20 21 22 |
# File 'lib/factpulse/models/key_rotation_request.rb', line 20 def old_key @old_key end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
34 35 36 |
# File 'lib/factpulse/models/key_rotation_request.rb', line 34 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/factpulse/models/key_rotation_request.rb', line 39 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 |
# File 'lib/factpulse/models/key_rotation_request.rb', line 26 def self.attribute_map { :'old_key' => :'oldKey', :'new_key' => :'newKey' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/factpulse/models/key_rotation_request.rb', line 173 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
52 53 54 55 |
# File 'lib/factpulse/models/key_rotation_request.rb', line 52 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 |
# File 'lib/factpulse/models/key_rotation_request.rb', line 44 def self.openapi_types { :'old_key' => :'String', :'new_key' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
151 152 153 154 155 156 |
# File 'lib/factpulse/models/key_rotation_request.rb', line 151 def ==(o) return true if self.equal?(o) self.class == o.class && old_key == o.old_key && new_key == o.new_key end |
#eql?(o) ⇒ Boolean
160 161 162 |
# File 'lib/factpulse/models/key_rotation_request.rb', line 160 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/factpulse/models/key_rotation_request.rb', line 166 def hash [old_key, new_key].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/factpulse/models/key_rotation_request.rb', line 88 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @old_key.nil? invalid_properties.push('invalid value for "old_key", old_key cannot be nil.') end if @old_key.to_s.length < 40 invalid_properties.push('invalid value for "old_key", the character length must be greater than or equal to 40.') end if @new_key.nil? invalid_properties.push('invalid value for "new_key", new_key cannot be nil.') end if @new_key.to_s.length < 40 invalid_properties.push('invalid value for "new_key", the character length must be greater than or equal to 40.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/factpulse/models/key_rotation_request.rb', line 195 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
112 113 114 115 116 117 118 119 |
# File 'lib/factpulse/models/key_rotation_request.rb', line 112 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @old_key.nil? return false if @old_key.to_s.length < 40 return false if @new_key.nil? return false if @new_key.to_s.length < 40 true end |