Class: FactPulse::Payee

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/payee.rb

Overview

Information about the payment beneficiary (BG-10 / PayeeTradeParty). The payee is the party receiving payment. This block is used only if the payee is different from the seller (supplier). Main use case: Factoring When an invoice is factored, the factor (factoring company) becomes the payment beneficiary instead of the supplier. Business Terms (EN16931): - BT-59: Payee name (mandatory) - BT-60: Payee identifier (SIRET with schemeID 0009) - BT-61: Payee legal identifier (SIREN with schemeID 0002) Reference: docs/guide_affacturage.md

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Payee

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/factpulse/models/payee.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::Payee` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::Payee`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'nom')
    self.nom = attributes[:'nom']
  else
    self.nom = nil
  end

  if attributes.key?(:'payee_id')
    self.payee_id = attributes[:'payee_id']
  end

  if attributes.key?(:'siret')
    self.siret = attributes[:'siret']
  end

  if attributes.key?(:'siren')
    self.siren = attributes[:'siren']
  end

  if attributes.key?(:'electronic_address')
    self.electronic_address = attributes[:'electronic_address']
  end

  if attributes.key?(:'iban')
    self.iban = attributes[:'iban']
  end

  if attributes.key?(:'bic')
    self.bic = attributes[:'bic']
  end

  if attributes.key?(:'global_ids')
    if (value = attributes[:'global_ids']).is_a?(Array)
      self.global_ids = value
    end
  end
end

Instance Attribute Details

#bic ⇒ Object

Returns the value of attribute bic.



32
33
34
# File 'lib/factpulse/models/payee.rb', line 32

def bic
  @bic
end

#electronic_address ⇒ Object

Returns the value of attribute electronic_address.



28
29
30
# File 'lib/factpulse/models/payee.rb', line 28

def electronic_address
  @electronic_address
end

#global_ids ⇒ Object

Returns the value of attribute global_ids.



34
35
36
# File 'lib/factpulse/models/payee.rb', line 34

def global_ids
  @global_ids
end

#iban ⇒ Object

Returns the value of attribute iban.



30
31
32
# File 'lib/factpulse/models/payee.rb', line 30

def iban
  @iban
end

#nom ⇒ Object

Payee name (BT-59). Mandatory.



20
21
22
# File 'lib/factpulse/models/payee.rb', line 20

def nom
  @nom
end

#payee_id ⇒ Object

Returns the value of attribute payee_id.



22
23
24
# File 'lib/factpulse/models/payee.rb', line 22

def payee_id
  @payee_id
end

#siren ⇒ Object

Returns the value of attribute siren.



26
27
28
# File 'lib/factpulse/models/payee.rb', line 26

def siren
  @siren
end

#siret ⇒ Object

Returns the value of attribute siret.



24
25
26
# File 'lib/factpulse/models/payee.rb', line 24

def siret
  @siret
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



51
52
53
# File 'lib/factpulse/models/payee.rb', line 51

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



56
57
58
# File 'lib/factpulse/models/payee.rb', line 56

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/factpulse/models/payee.rb', line 37

def self.attribute_map
  {
    :'nom' => :'nom',
    :'payee_id' => :'payeeId',
    :'siret' => :'siret',
    :'siren' => :'siren',
    :'electronic_address' => :'electronicAddress',
    :'iban' => :'iban',
    :'bic' => :'bic',
    :'global_ids' => :'global_ids'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/factpulse/models/payee.rb', line 243

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



75
76
77
78
79
80
81
82
83
84
85
# File 'lib/factpulse/models/payee.rb', line 75

def self.openapi_nullable
  Set.new([
    :'payee_id',
    :'siret',
    :'siren',
    :'electronic_address',
    :'iban',
    :'bic',
    :'global_ids'
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/factpulse/models/payee.rb', line 61

def self.openapi_types
  {
    :'nom' => :'String',
    :'payee_id' => :'String',
    :'siret' => :'String',
    :'siren' => :'String',
    :'electronic_address' => :'ElectronicAddress',
    :'iban' => :'String',
    :'bic' => :'String',
    :'global_ids' => :'Array<ElectronicAddress>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/factpulse/models/payee.rb', line 215

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      nom == o.nom &&
      payee_id == o.payee_id &&
      siret == o.siret &&
      siren == o.siren &&
      electronic_address == o.electronic_address &&
      iban == o.iban &&
      bic == o.bic &&
      global_ids == o.global_ids
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


230
231
232
# File 'lib/factpulse/models/payee.rb', line 230

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



236
237
238
# File 'lib/factpulse/models/payee.rb', line 236

def hash
  [nom, payee_id, siret, siren, electronic_address, iban, bic, global_ids].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/factpulse/models/payee.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @nom.nil?
    invalid_properties.push('invalid value for "nom", nom cannot be nil.')
  end

  if @nom.to_s.length < 1
    invalid_properties.push('invalid value for "nom", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^\d{14}$/)
  if !@siret.nil? && @siret !~ pattern
    invalid_properties.push("invalid value for \"siret\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^\d{9}$/)
  if !@siren.nil? && @siren !~ pattern
    invalid_properties.push("invalid value for \"siren\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/factpulse/models/payee.rb', line 265

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



168
169
170
171
172
173
174
175
# File 'lib/factpulse/models/payee.rb', line 168

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @nom.nil?
  return false if @nom.to_s.length < 1
  return false if !@siret.nil? && @siret !~ Regexp.new(/^\d{14}$/)
  return false if !@siren.nil? && @siren !~ Regexp.new(/^\d{9}$/)
  true
end