Class: FactPulse::PostalAddress

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/postal_address.rb

Overview

Represents a postal address (BG-5, BG-8, BG-12, BG-15).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PostalAddress

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/factpulse/models/postal_address.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::PostalAddress` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::PostalAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'line_one')
    self.line_one = attributes[:'line_one']
  end

  if attributes.key?(:'line_two')
    self.line_two = attributes[:'line_two']
  end

  if attributes.key?(:'line_three')
    self.line_three = attributes[:'line_three']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'country_code')
    self.country_code = attributes[:'country_code']
  end

  if attributes.key?(:'country_subdivision')
    self.country_subdivision = attributes[:'country_subdivision']
  end
end

Instance Attribute Details

#city ⇒ Object

Returns the value of attribute city.



27
28
29
# File 'lib/factpulse/models/postal_address.rb', line 27

def city
  @city
end

#country_code ⇒ Object

Returns the value of attribute country_code.



29
30
31
# File 'lib/factpulse/models/postal_address.rb', line 29

def country_code
  @country_code
end

#country_subdivision ⇒ Object

Returns the value of attribute country_subdivision.



31
32
33
# File 'lib/factpulse/models/postal_address.rb', line 31

def country_subdivision
  @country_subdivision
end

#line_one ⇒ Object

Returns the value of attribute line_one.



21
22
23
# File 'lib/factpulse/models/postal_address.rb', line 21

def line_one
  @line_one
end

#line_three ⇒ Object

Returns the value of attribute line_three.



25
26
27
# File 'lib/factpulse/models/postal_address.rb', line 25

def line_three
  @line_three
end

#line_two ⇒ Object

Returns the value of attribute line_two.



23
24
25
# File 'lib/factpulse/models/postal_address.rb', line 23

def line_two
  @line_two
end

#postal_code ⇒ Object

Returns the value of attribute postal_code.



19
20
21
# File 'lib/factpulse/models/postal_address.rb', line 19

def postal_code
  @postal_code
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



47
48
49
# File 'lib/factpulse/models/postal_address.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/factpulse/models/postal_address.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
44
# File 'lib/factpulse/models/postal_address.rb', line 34

def self.attribute_map
  {
    :'postal_code' => :'postalCode',
    :'line_one' => :'lineOne',
    :'line_two' => :'lineTwo',
    :'line_three' => :'lineThree',
    :'city' => :'city',
    :'country_code' => :'countryCode',
    :'country_subdivision' => :'countrySubdivision'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/factpulse/models/postal_address.rb', line 171

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



70
71
72
73
74
75
76
77
78
79
80
# File 'lib/factpulse/models/postal_address.rb', line 70

def self.openapi_nullable
  Set.new([
    :'postal_code',
    :'line_one',
    :'line_two',
    :'line_three',
    :'city',
    :'country_code',
    :'country_subdivision'
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/factpulse/models/postal_address.rb', line 57

def self.openapi_types
  {
    :'postal_code' => :'String',
    :'line_one' => :'String',
    :'line_two' => :'String',
    :'line_three' => :'String',
    :'city' => :'String',
    :'country_code' => :'String',
    :'country_subdivision' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



144
145
146
147
148
149
150
151
152
153
154
# File 'lib/factpulse/models/postal_address.rb', line 144

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      postal_code == o.postal_code &&
      line_one == o.line_one &&
      line_two == o.line_two &&
      line_three == o.line_three &&
      city == o.city &&
      country_code == o.country_code &&
      country_subdivision == o.country_subdivision
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


158
159
160
# File 'lib/factpulse/models/postal_address.rb', line 158

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



164
165
166
# File 'lib/factpulse/models/postal_address.rb', line 164

def hash
  [postal_code, line_one, line_two, line_three, city, country_code, country_subdivision].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



129
130
131
132
133
# File 'lib/factpulse/models/postal_address.rb', line 129

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/factpulse/models/postal_address.rb', line 193

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



137
138
139
140
# File 'lib/factpulse/models/postal_address.rb', line 137

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end