Class: FactPulse::RecipientInput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::RecipientInput
- Defined in:
- lib/factpulse/models/recipient_input.rb
Overview
Destinataire du message CDAR.
Instance Attribute Summary collapse
-
#email ⇒ Object
Returns the value of attribute email.
-
#name ⇒ Object
Returns the value of attribute name.
-
#role ⇒ Object
Code rôle (BY, SE, WK, etc.).
-
#siren ⇒ Object
Returns the value of attribute siren.
-
#siret ⇒ Object
Returns the value of attribute siret.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RecipientInput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RecipientInput
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/factpulse/models/recipient_input.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::RecipientInput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::RecipientInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'siren') self.siren = attributes[:'siren'] end if attributes.key?(:'siret') self.siret = attributes[:'siret'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'role') self.role = attributes[:'role'] else self.role = 'BY' end if attributes.key?(:'email') self.email = attributes[:'email'] end end |
Instance Attribute Details
#email ⇒ Object
Returns the value of attribute email.
28 29 30 |
# File 'lib/factpulse/models/recipient_input.rb', line 28 def email @email end |
#name ⇒ Object
Returns the value of attribute name.
23 24 25 |
# File 'lib/factpulse/models/recipient_input.rb', line 23 def name @name end |
#role ⇒ Object
Code rôle (BY, SE, WK, etc.)
26 27 28 |
# File 'lib/factpulse/models/recipient_input.rb', line 26 def role @role end |
#siren ⇒ Object
Returns the value of attribute siren.
19 20 21 |
# File 'lib/factpulse/models/recipient_input.rb', line 19 def siren @siren end |
#siret ⇒ Object
Returns the value of attribute siret.
21 22 23 |
# File 'lib/factpulse/models/recipient_input.rb', line 21 def siret @siret end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
42 43 44 |
# File 'lib/factpulse/models/recipient_input.rb', line 42 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/factpulse/models/recipient_input.rb', line 47 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 |
# File 'lib/factpulse/models/recipient_input.rb', line 31 def self.attribute_map { :'siren' => :'siren', :'siret' => :'siret', :'name' => :'name', :'role' => :'role', :'email' => :'email' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/factpulse/models/recipient_input.rb', line 153 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
63 64 65 66 67 68 69 70 |
# File 'lib/factpulse/models/recipient_input.rb', line 63 def self.openapi_nullable Set.new([ :'siren', :'siret', :'name', :'email' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 60 |
# File 'lib/factpulse/models/recipient_input.rb', line 52 def self.openapi_types { :'siren' => :'String', :'siret' => :'String', :'name' => :'String', :'role' => :'String', :'email' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
128 129 130 131 132 133 134 135 136 |
# File 'lib/factpulse/models/recipient_input.rb', line 128 def ==(o) return true if self.equal?(o) self.class == o.class && siren == o.siren && siret == o.siret && name == o.name && role == o.role && email == o.email end |
#eql?(o) ⇒ Boolean
140 141 142 |
# File 'lib/factpulse/models/recipient_input.rb', line 140 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/factpulse/models/recipient_input.rb', line 146 def hash [siren, siret, name, role, email].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
113 114 115 116 117 |
# File 'lib/factpulse/models/recipient_input.rb', line 113 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/factpulse/models/recipient_input.rb', line 175 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
121 122 123 124 |
# File 'lib/factpulse/models/recipient_input.rb', line 121 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |