Class: FactPulse::ReportSender

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/report_sender.rb

Overview

Report sender/issuer information.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ReportSender

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/factpulse/models/report_sender.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::ReportSender` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::ReportSender`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'siren')
    self.siren = attributes[:'siren']
  else
    self.siren = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'vat_id')
    self.vat_id = attributes[:'vat_id']
  end
end

Instance Attribute Details

#name ⇒ Object

Company name



23
24
25
# File 'lib/factpulse/models/report_sender.rb', line 23

def name
  @name
end

#siren ⇒ Object

SIREN or SIRET number



20
21
22
# File 'lib/factpulse/models/report_sender.rb', line 20

def siren
  @siren
end

#vat_id ⇒ Object

Returns the value of attribute vat_id.



25
26
27
# File 'lib/factpulse/models/report_sender.rb', line 25

def vat_id
  @vat_id
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



37
38
39
# File 'lib/factpulse/models/report_sender.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/factpulse/models/report_sender.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
# File 'lib/factpulse/models/report_sender.rb', line 28

def self.attribute_map
  {
    :'siren' => :'siren',
    :'name' => :'name',
    :'vat_id' => :'vatId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/factpulse/models/report_sender.rb', line 183

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



56
57
58
59
60
# File 'lib/factpulse/models/report_sender.rb', line 56

def self.openapi_nullable
  Set.new([
    :'vat_id'
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



47
48
49
50
51
52
53
# File 'lib/factpulse/models/report_sender.rb', line 47

def self.openapi_types
  {
    :'siren' => :'String',
    :'name' => :'String',
    :'vat_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



160
161
162
163
164
165
166
# File 'lib/factpulse/models/report_sender.rb', line 160

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      siren == o.siren &&
      name == o.name &&
      vat_id == o.vat_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


170
171
172
# File 'lib/factpulse/models/report_sender.rb', line 170

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



176
177
178
# File 'lib/factpulse/models/report_sender.rb', line 176

def hash
  [siren, name, vat_id].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/factpulse/models/report_sender.rb', line 97

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @siren.nil?
    invalid_properties.push('invalid value for "siren", siren cannot be nil.')
  end

  if @siren.to_s.length > 14
    invalid_properties.push('invalid value for "siren", the character length must be smaller than or equal to 14.')
  end

  if @siren.to_s.length < 9
    invalid_properties.push('invalid value for "siren", the character length must be greater than or equal to 9.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/factpulse/models/report_sender.rb', line 205

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



121
122
123
124
125
126
127
128
# File 'lib/factpulse/models/report_sender.rb', line 121

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @siren.nil?
  return false if @siren.to_s.length > 14
  return false if @siren.to_s.length < 9
  return false if @name.nil?
  true
end