Class: FactPulse::SubmitEReportingResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::SubmitEReportingResponse
- Defined in:
- lib/factpulse/models/submit_e_reporting_response.rb
Overview
Response after submitting e-reporting to PA/PDP.
Instance Attribute Summary collapse
-
#afnor_flow_type ⇒ Object
Returns the value of attribute afnor_flow_type.
-
#afnor_response ⇒ Object
Returns the value of attribute afnor_response.
-
#flow_id ⇒ Object
Flow identifier from PA/PDP.
-
#flow_type ⇒ Object
Flux type.
-
#message ⇒ Object
Status message.
-
#report_id ⇒ Object
Report identifier.
-
#sha256 ⇒ Object
SHA256 hash of submitted XML.
-
#tracking_id ⇒ Object
Returns the value of attribute tracking_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SubmitEReportingResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SubmitEReportingResponse
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::SubmitEReportingResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::SubmitEReportingResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'flow_id') self.flow_id = attributes[:'flow_id'] else self.flow_id = nil end if attributes.key?(:'report_id') self.report_id = attributes[:'report_id'] else self.report_id = nil end if attributes.key?(:'tracking_id') self.tracking_id = attributes[:'tracking_id'] end if attributes.key?(:'flow_type') self.flow_type = attributes[:'flow_type'] else self.flow_type = nil end if attributes.key?(:'sha256') self.sha256 = attributes[:'sha256'] else self.sha256 = nil end if attributes.key?(:'afnor_flow_type') self.afnor_flow_type = attributes[:'afnor_flow_type'] end if attributes.key?(:'afnor_response') if (value = attributes[:'afnor_response']).is_a?(Hash) self.afnor_response = value end end if attributes.key?(:'message') self. = attributes[:'message'] else self. = nil end end |
Instance Attribute Details
#afnor_flow_type ⇒ Object
Returns the value of attribute afnor_flow_type.
33 34 35 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 33 def afnor_flow_type @afnor_flow_type end |
#afnor_response ⇒ Object
Returns the value of attribute afnor_response.
35 36 37 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 35 def afnor_response @afnor_response end |
#flow_id ⇒ Object
Flow identifier from PA/PDP
20 21 22 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 20 def flow_id @flow_id end |
#flow_type ⇒ Object
Flux type
28 29 30 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 28 def flow_type @flow_type end |
#message ⇒ Object
Status message
38 39 40 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 38 def @message end |
#report_id ⇒ Object
Report identifier
23 24 25 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 23 def report_id @report_id end |
#sha256 ⇒ Object
SHA256 hash of submitted XML
31 32 33 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 31 def sha256 @sha256 end |
#tracking_id ⇒ Object
Returns the value of attribute tracking_id.
25 26 27 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 25 def tracking_id @tracking_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 41 def self.attribute_map { :'flow_id' => :'flowId', :'report_id' => :'reportId', :'tracking_id' => :'trackingId', :'flow_type' => :'flowType', :'sha256' => :'sha256', :'afnor_flow_type' => :'afnorFlowType', :'afnor_response' => :'afnorResponse', :'message' => :'message' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 268 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 83 84 85 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 79 def self.openapi_nullable Set.new([ :'tracking_id', :'afnor_flow_type', :'afnor_response', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 65 def self.openapi_types { :'flow_id' => :'String', :'report_id' => :'String', :'tracking_id' => :'String', :'flow_type' => :'String', :'sha256' => :'String', :'afnor_flow_type' => :'String', :'afnor_response' => :'Hash<String, Object>', :'message' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 240 def ==(o) return true if self.equal?(o) self.class == o.class && flow_id == o.flow_id && report_id == o.report_id && tracking_id == o.tracking_id && flow_type == o.flow_type && sha256 == o.sha256 && afnor_flow_type == o.afnor_flow_type && afnor_response == o.afnor_response && == o. end |
#eql?(o) ⇒ Boolean
255 256 257 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 255 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
261 262 263 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 261 def hash [flow_id, report_id, tracking_id, flow_type, sha256, afnor_flow_type, afnor_response, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 150 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @flow_id.nil? invalid_properties.push('invalid value for "flow_id", flow_id cannot be nil.') end if @report_id.nil? invalid_properties.push('invalid value for "report_id", report_id cannot be nil.') end if @flow_type.nil? invalid_properties.push('invalid value for "flow_type", flow_type cannot be nil.') end if @sha256.nil? invalid_properties.push('invalid value for "sha256", sha256 cannot be nil.') end if @message.nil? invalid_properties.push('invalid value for "message", message cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 290 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
178 179 180 181 182 183 184 185 186 |
# File 'lib/factpulse/models/submit_e_reporting_response.rb', line 178 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @flow_id.nil? return false if @report_id.nil? return false if @flow_type.nil? return false if @sha256.nil? return false if @message.nil? true end |