Class: FactPulse::UserApi
- Inherits:
-
Object
- Object
- FactPulse::UserApi
- Defined in:
- lib/factpulse/api/user_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_user_info_api_v1_me_get(opts = {}) ⇒ Object
Get current user information Returns information about the authenticated user.
-
#get_user_info_api_v1_me_get_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get current user information Returns information about the authenticated user.
-
#initialize(api_client = ApiClient.default) ⇒ UserApi
constructor
A new instance of UserApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ UserApi
Returns a new instance of UserApi.
19 20 21 |
# File 'lib/factpulse/api/user_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/factpulse/api/user_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_user_info_api_v1_me_get(opts = {}) ⇒ Object
Get current user information Returns information about the authenticated user. This endpoint allows you to: - Verify that authentication works - Get connected account details - Test JWT token validity - Check your consumption quota Requires valid authentication.
26 27 28 29 |
# File 'lib/factpulse/api/user_api.rb', line 26 def get_user_info_api_v1_me_get(opts = {}) data, _status_code, _headers = get_user_info_api_v1_me_get_with_http_info(opts) data end |
#get_user_info_api_v1_me_get_with_http_info(opts = {}) ⇒ Array<(Object, Integer, Hash)>
Get current user information Returns information about the authenticated user. This endpoint allows you to: - Verify that authentication works - Get connected account details - Test JWT token validity - Check your consumption quota Requires valid authentication.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/factpulse/api/user_api.rb', line 35 def get_user_info_api_v1_me_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserApi.get_user_info_api_v1_me_get ...' end # resource path local_var_path = '/api/v1/me' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"UserApi.get_user_info_api_v1_me_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserApi#get_user_info_api_v1_me_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |