Class: FactPulse::VATLine

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/vat_line.rb

Overview

Represents a VAT breakdown line by rate (BG-23). For exemptions (categories E, AE, K, G, O), the fields exemption_reason and vatex_code are required per EN16931.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VATLine

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/factpulse/models/vat_line.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::VATLine` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::VATLine`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'taxable_amount')
    self.taxable_amount = attributes[:'taxable_amount']
  else
    self.taxable_amount = nil
  end

  if attributes.key?(:'vat_amount')
    self.vat_amount = attributes[:'vat_amount']
  else
    self.vat_amount = nil
  end

  if attributes.key?(:'rate')
    self.rate = attributes[:'rate']
  end

  if attributes.key?(:'manual_rate')
    self.manual_rate = attributes[:'manual_rate']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'due_date_type_code')
    self.due_date_type_code = attributes[:'due_date_type_code']
  end

  if attributes.key?(:'exemption_reason')
    self.exemption_reason = attributes[:'exemption_reason']
  end

  if attributes.key?(:'vatex_code')
    self.vatex_code = attributes[:'vatex_code']
  end
end

Instance Attribute Details

#category ⇒ Object

Returns the value of attribute category.



27
28
29
# File 'lib/factpulse/models/vat_line.rb', line 27

def category
  @category
end

#due_date_type_code ⇒ Object

Returns the value of attribute due_date_type_code.



29
30
31
# File 'lib/factpulse/models/vat_line.rb', line 29

def due_date_type_code
  @due_date_type_code
end

#exemption_reason ⇒ Object

Returns the value of attribute exemption_reason.



31
32
33
# File 'lib/factpulse/models/vat_line.rb', line 31

def exemption_reason
  @exemption_reason
end

#manual_rate ⇒ Object

Returns the value of attribute manual_rate.



25
26
27
# File 'lib/factpulse/models/vat_line.rb', line 25

def manual_rate
  @manual_rate
end

#rate ⇒ Object

Returns the value of attribute rate.



23
24
25
# File 'lib/factpulse/models/vat_line.rb', line 23

def rate
  @rate
end

#taxable_amount ⇒ Object

Returns the value of attribute taxable_amount.



19
20
21
# File 'lib/factpulse/models/vat_line.rb', line 19

def taxable_amount
  @taxable_amount
end

#vat_amount ⇒ Object

Returns the value of attribute vat_amount.



21
22
23
# File 'lib/factpulse/models/vat_line.rb', line 21

def vat_amount
  @vat_amount
end

#vatex_code ⇒ Object

Returns the value of attribute vatex_code.



33
34
35
# File 'lib/factpulse/models/vat_line.rb', line 33

def vatex_code
  @vatex_code
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



72
73
74
# File 'lib/factpulse/models/vat_line.rb', line 72

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/factpulse/models/vat_line.rb', line 77

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/factpulse/models/vat_line.rb', line 58

def self.attribute_map
  {
    :'taxable_amount' => :'taxable_amount',
    :'vat_amount' => :'vat_amount',
    :'rate' => :'rate',
    :'manual_rate' => :'manual_rate',
    :'category' => :'category',
    :'due_date_type_code' => :'due_date_type_code',
    :'exemption_reason' => :'exemption_reason',
    :'vatex_code' => :'vatex_code'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/factpulse/models/vat_line.rb', line 234

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



96
97
98
99
100
101
102
103
104
# File 'lib/factpulse/models/vat_line.rb', line 96

def self.openapi_nullable
  Set.new([
    :'rate',
    :'category',
    :'due_date_type_code',
    :'exemption_reason',
    :'vatex_code'
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/factpulse/models/vat_line.rb', line 82

def self.openapi_types
  {
    :'taxable_amount' => :'TaxableAmount',
    :'vat_amount' => :'VATAmount',
    :'rate' => :'String',
    :'manual_rate' => :'ManualRate',
    :'category' => :'VATCategory',
    :'due_date_type_code' => :'VATPointDateCode',
    :'exemption_reason' => :'String',
    :'vatex_code' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/factpulse/models/vat_line.rb', line 206

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      taxable_amount == o.taxable_amount &&
      vat_amount == o.vat_amount &&
      rate == o.rate &&
      manual_rate == o.manual_rate &&
      category == o.category &&
      due_date_type_code == o.due_date_type_code &&
      exemption_reason == o.exemption_reason &&
      vatex_code == o.vatex_code
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/factpulse/models/vat_line.rb', line 221

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



227
228
229
# File 'lib/factpulse/models/vat_line.rb', line 227

def hash
  [taxable_amount, vat_amount, rate, manual_rate, category, due_date_type_code, exemption_reason, vatex_code].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/factpulse/models/vat_line.rb', line 161

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @taxable_amount.nil?
    invalid_properties.push('invalid value for "taxable_amount", taxable_amount cannot be nil.')
  end

  if @vat_amount.nil?
    invalid_properties.push('invalid value for "vat_amount", vat_amount cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/factpulse/models/vat_line.rb', line 256

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



177
178
179
180
181
182
# File 'lib/factpulse/models/vat_line.rb', line 177

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @taxable_amount.nil?
  return false if @vat_amount.nil?
  true
end