Class: FactPulse::ValidateEReportingResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::ValidateEReportingResponse
- Defined in:
- lib/factpulse/models/validate_e_reporting_response.rb
Overview
Response after validating e-reporting data.
Instance Attribute Summary collapse
-
#errors ⇒ Object
List of validation errors (if any).
-
#flow_type ⇒ Object
Flux type.
-
#message ⇒ Object
Status message.
-
#report_id ⇒ Object
Report identifier.
-
#valid ⇒ Object
Whether the data is valid.
-
#warnings ⇒ Object
List of validation warnings (if any).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ValidateEReportingResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ValidateEReportingResponse
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::ValidateEReportingResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::ValidateEReportingResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'valid') self.valid = attributes[:'valid'] else self.valid = nil end if attributes.key?(:'report_id') self.report_id = attributes[:'report_id'] else self.report_id = nil end if attributes.key?(:'flow_type') self.flow_type = attributes[:'flow_type'] else self.flow_type = nil end if attributes.key?(:'errors') if (value = attributes[:'errors']).is_a?(Array) self.errors = value end end if attributes.key?(:'warnings') if (value = attributes[:'warnings']).is_a?(Array) self.warnings = value end end if attributes.key?(:'message') self. = attributes[:'message'] else self. = nil end end |
Instance Attribute Details
#errors ⇒ Object
List of validation errors (if any)
29 30 31 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 29 def errors @errors end |
#flow_type ⇒ Object
Flux type
26 27 28 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 26 def flow_type @flow_type end |
#message ⇒ Object
Status message
35 36 37 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 35 def @message end |
#report_id ⇒ Object
Report identifier
23 24 25 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 23 def report_id @report_id end |
#valid ⇒ Object
Whether the data is valid
20 21 22 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 20 def valid @valid end |
#warnings ⇒ Object
List of validation warnings (if any)
32 33 34 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 32 def warnings @warnings end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 38 def self.attribute_map { :'valid' => :'valid', :'report_id' => :'reportId', :'flow_type' => :'flowType', :'errors' => :'errors', :'warnings' => :'warnings', :'message' => :'message' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 233 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 60 def self.openapi_types { :'valid' => :'Boolean', :'report_id' => :'String', :'flow_type' => :'String', :'errors' => :'Array<EReportingValidationError>', :'warnings' => :'Array<EReportingValidationError>', :'message' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
207 208 209 210 211 212 213 214 215 216 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 207 def ==(o) return true if self.equal?(o) self.class == o.class && valid == o.valid && report_id == o.report_id && flow_type == o.flow_type && errors == o.errors && warnings == o.warnings && == o. end |
#eql?(o) ⇒ Boolean
220 221 222 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 220 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
226 227 228 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 226 def hash [valid, report_id, flow_type, errors, warnings, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 132 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @valid.nil? invalid_properties.push('invalid value for "valid", valid cannot be nil.') end if @report_id.nil? invalid_properties.push('invalid value for "report_id", report_id cannot be nil.') end if @flow_type.nil? invalid_properties.push('invalid value for "flow_type", flow_type cannot be nil.') end if @message.nil? invalid_properties.push('invalid value for "message", message cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 255 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
156 157 158 159 160 161 162 163 |
# File 'lib/factpulse/models/validate_e_reporting_response.rb', line 156 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @valid.nil? return false if @report_id.nil? return false if @flow_type.nil? return false if @message.nil? true end |