Class: FactPulse::ValidationError

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/helpers/exceptions.rb,
lib/factpulse/models/validation_error.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ValidationError

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



60
61
62
63
# File 'lib/factpulse/models/validation_error.rb', line 60

def initialize(msg, errors = [])
  @errors = errors
  super(errors.empty? ? msg : "#{msg}\n\nDetails:\n#{errors.map { |e| "  - #{e}" }.join("\n")}")
end

Instance Attribute Details

#errorsObject (readonly)

Returns the value of attribute errors.



38
39
40
# File 'lib/factpulse/helpers/exceptions.rb', line 38

def errors
  @errors
end

#locObject

Returns the value of attribute loc.



18
19
20
# File 'lib/factpulse/models/validation_error.rb', line 18

def loc
  @loc
end

#msgObject

Returns the value of attribute msg.



20
21
22
# File 'lib/factpulse/models/validation_error.rb', line 20

def msg
  @msg
end

#typeObject

Returns the value of attribute type.



22
23
24
# File 'lib/factpulse/models/validation_error.rb', line 22

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



34
35
36
# File 'lib/factpulse/models/validation_error.rb', line 34

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



39
40
41
# File 'lib/factpulse/models/validation_error.rb', line 39

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
31
# File 'lib/factpulse/models/validation_error.rb', line 25

def self.attribute_map
  {
    :'loc' => :'loc',
    :'msg' => :'msg',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/factpulse/models/validation_error.rb', line 180

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



53
54
55
56
# File 'lib/factpulse/models/validation_error.rb', line 53

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
# File 'lib/factpulse/models/validation_error.rb', line 44

def self.openapi_types
  {
    :'loc' => :'Array<LocationInner>',
    :'msg' => :'String',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



157
158
159
160
161
162
163
# File 'lib/factpulse/models/validation_error.rb', line 157

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      loc == o.loc &&
      msg == o.msg &&
      type == o.type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


167
168
169
# File 'lib/factpulse/models/validation_error.rb', line 167

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



173
174
175
# File 'lib/factpulse/models/validation_error.rb', line 173

def hash
  [loc, msg, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/factpulse/models/validation_error.rb', line 97

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @loc.nil?
    invalid_properties.push('invalid value for "loc", loc cannot be nil.')
  end

  if @msg.nil?
    invalid_properties.push('invalid value for "msg", msg cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/factpulse/models/validation_error.rb', line 202

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



117
118
119
120
121
122
123
# File 'lib/factpulse/models/validation_error.rb', line 117

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @loc.nil?
  return false if @msg.nil?
  return false if @type.nil?
  true
end