Class: FactPulse::ValidationInfo

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/validation_info.rb

Overview

Informations sur la validation.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ValidationInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/factpulse/models/validation_info.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::ValidationInfo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::ValidationInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'profile')
    self.profile = attributes[:'profile']
  else
    self.profile = nil
  end

  if attributes.key?(:'schematron_rules_passed')
    self.schematron_rules_passed = attributes[:'schematron_rules_passed']
  else
    self.schematron_rules_passed = nil
  end

  if attributes.key?(:'schematron_rules_total')
    self.schematron_rules_total = attributes[:'schematron_rules_total']
  else
    self.schematron_rules_total = nil
  end

  if attributes.key?(:'pdfa_compliant')
    self.pdfa_compliant = attributes[:'pdfa_compliant']
  else
    self.pdfa_compliant = true
  end

  if attributes.key?(:'xml_embedded')
    self.xml_embedded = attributes[:'xml_embedded']
  else
    self.xml_embedded = true
  end

  if attributes.key?(:'errors')
    if (value = attributes[:'errors']).is_a?(Array)
      self.errors = value
    end
  end
end

Instance Attribute Details

#errors ⇒ Object

Returns the value of attribute errors.



34
35
36
# File 'lib/factpulse/models/validation_info.rb', line 34

def errors
  @errors
end

#pdfa_compliant ⇒ Object

PDF/A-3 conforme



29
30
31
# File 'lib/factpulse/models/validation_info.rb', line 29

def pdfa_compliant
  @pdfa_compliant
end

#profile ⇒ Object

Profil Factur-X utilise



20
21
22
# File 'lib/factpulse/models/validation_info.rb', line 20

def profile
  @profile
end

#schematron_rules_passed ⇒ Object

Regles passees



23
24
25
# File 'lib/factpulse/models/validation_info.rb', line 23

def schematron_rules_passed
  @schematron_rules_passed
end

#schematron_rules_total ⇒ Object

Total regles



26
27
28
# File 'lib/factpulse/models/validation_info.rb', line 26

def schematron_rules_total
  @schematron_rules_total
end

#xml_embedded ⇒ Object

XML embarque dans PDF



32
33
34
# File 'lib/factpulse/models/validation_info.rb', line 32

def xml_embedded
  @xml_embedded
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



49
50
51
# File 'lib/factpulse/models/validation_info.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/factpulse/models/validation_info.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/factpulse/models/validation_info.rb', line 37

def self.attribute_map
  {
    :'profile' => :'profile',
    :'schematron_rules_passed' => :'schematron_rules_passed',
    :'schematron_rules_total' => :'schematron_rules_total',
    :'pdfa_compliant' => :'pdfa_compliant',
    :'xml_embedded' => :'xml_embedded',
    :'errors' => :'errors'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/factpulse/models/validation_info.rb', line 217

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



71
72
73
74
# File 'lib/factpulse/models/validation_info.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/factpulse/models/validation_info.rb', line 59

def self.openapi_types
  {
    :'profile' => :'String',
    :'schematron_rules_passed' => :'Integer',
    :'schematron_rules_total' => :'Integer',
    :'pdfa_compliant' => :'Boolean',
    :'xml_embedded' => :'Boolean',
    :'errors' => :'Array<FactureElectroniqueRestApiSchemasConvertValidationError>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



191
192
193
194
195
196
197
198
199
200
# File 'lib/factpulse/models/validation_info.rb', line 191

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      profile == o.profile &&
      schematron_rules_passed == o.schematron_rules_passed &&
      schematron_rules_total == o.schematron_rules_total &&
      pdfa_compliant == o.pdfa_compliant &&
      xml_embedded == o.xml_embedded &&
      errors == o.errors
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


204
205
206
# File 'lib/factpulse/models/validation_info.rb', line 204

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



210
211
212
# File 'lib/factpulse/models/validation_info.rb', line 210

def hash
  [profile, schematron_rules_passed, schematron_rules_total, pdfa_compliant, xml_embedded, errors].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/factpulse/models/validation_info.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @profile.nil?
    invalid_properties.push('invalid value for "profile", profile cannot be nil.')
  end

  if @schematron_rules_passed.nil?
    invalid_properties.push('invalid value for "schematron_rules_passed", schematron_rules_passed cannot be nil.')
  end

  if @schematron_rules_total.nil?
    invalid_properties.push('invalid value for "schematron_rules_total", schematron_rules_total cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/factpulse/models/validation_info.rb', line 239

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



151
152
153
154
155
156
157
# File 'lib/factpulse/models/validation_info.rb', line 151

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @profile.nil?
  return false if @schematron_rules_passed.nil?
  return false if @schematron_rules_total.nil?
  true
end