Class: FactPulse::VerificationSuccessTaskResult
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::VerificationSuccessTaskResult
- Defined in:
- lib/factpulse/models/verification_success_task_result.rb
Overview
Successful result from task_verify_pdf.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#status ⇒ Object
Returns the value of attribute status.
-
#verification_result ⇒ Object
Returns the value of attribute verification_result.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VerificationSuccessTaskResult
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VerificationSuccessTaskResult
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/factpulse/models/verification_success_task_result.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::VerificationSuccessTaskResult` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::VerificationSuccessTaskResult`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = 'SUCCESS' end if attributes.key?(:'verification_result') self.verification_result = attributes[:'verification_result'] else self.verification_result = nil end end |
Instance Attribute Details
#status ⇒ Object
Returns the value of attribute status.
19 20 21 |
# File 'lib/factpulse/models/verification_success_task_result.rb', line 19 def status @status end |
#verification_result ⇒ Object
Returns the value of attribute verification_result.
21 22 23 |
# File 'lib/factpulse/models/verification_success_task_result.rb', line 21 def verification_result @verification_result end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/factpulse/models/verification_success_task_result.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/factpulse/models/verification_success_task_result.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 |
# File 'lib/factpulse/models/verification_success_task_result.rb', line 46 def self.attribute_map { :'status' => :'status', :'verification_result' => :'verification_result' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/factpulse/models/verification_success_task_result.rb', line 172 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/factpulse/models/verification_success_task_result.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 |
# File 'lib/factpulse/models/verification_success_task_result.rb', line 64 def self.openapi_types { :'status' => :'String', :'verification_result' => :'VerificationSuccessResponse' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 |
# File 'lib/factpulse/models/verification_success_task_result.rb', line 150 def ==(o) return true if self.equal?(o) self.class == o.class && status == o.status && verification_result == o.verification_result end |
#eql?(o) ⇒ Boolean
159 160 161 |
# File 'lib/factpulse/models/verification_success_task_result.rb', line 159 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/factpulse/models/verification_success_task_result.rb', line 165 def hash [status, verification_result].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
108 109 110 111 112 113 114 115 116 |
# File 'lib/factpulse/models/verification_success_task_result.rb', line 108 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @verification_result.nil? invalid_properties.push('invalid value for "verification_result", verification_result cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/factpulse/models/verification_success_task_result.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
120 121 122 123 124 125 126 |
# File 'lib/factpulse/models/verification_success_task_result.rb', line 120 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["SUCCESS"]) return false unless status_validator.valid?(@status) return false if @verification_result.nil? true end |