Class: FactPulse::WebhookSecretStatusResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::WebhookSecretStatusResponse
- Defined in:
- lib/factpulse/models/webhook_secret_status_response.rb
Overview
Webhook secret status for a client.
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#has_secret ⇒ Object
Whether a webhook secret is configured.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookSecretStatusResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebhookSecretStatusResponse
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/factpulse/models/webhook_secret_status_response.rb', line 59 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::WebhookSecretStatusResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::WebhookSecretStatusResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'has_secret') self.has_secret = attributes[:'has_secret'] else self.has_secret = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
22 23 24 |
# File 'lib/factpulse/models/webhook_secret_status_response.rb', line 22 def created_at @created_at end |
#has_secret ⇒ Object
Whether a webhook secret is configured
20 21 22 |
# File 'lib/factpulse/models/webhook_secret_status_response.rb', line 20 def has_secret @has_secret end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/factpulse/models/webhook_secret_status_response.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/factpulse/models/webhook_secret_status_response.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 |
# File 'lib/factpulse/models/webhook_secret_status_response.rb', line 25 def self.attribute_map { :'has_secret' => :'hasSecret', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/factpulse/models/webhook_secret_status_response.rb', line 138 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
51 52 53 54 55 |
# File 'lib/factpulse/models/webhook_secret_status_response.rb', line 51 def self.openapi_nullable Set.new([ :'created_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 |
# File 'lib/factpulse/models/webhook_secret_status_response.rb', line 43 def self.openapi_types { :'has_secret' => :'Boolean', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
116 117 118 119 120 121 |
# File 'lib/factpulse/models/webhook_secret_status_response.rb', line 116 def ==(o) return true if self.equal?(o) self.class == o.class && has_secret == o.has_secret && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
125 126 127 |
# File 'lib/factpulse/models/webhook_secret_status_response.rb', line 125 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
131 132 133 |
# File 'lib/factpulse/models/webhook_secret_status_response.rb', line 131 def hash [has_secret, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
86 87 88 89 90 91 92 93 94 |
# File 'lib/factpulse/models/webhook_secret_status_response.rb', line 86 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @has_secret.nil? invalid_properties.push('invalid value for "has_secret", has_secret cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/factpulse/models/webhook_secret_status_response.rb', line 160 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
98 99 100 101 102 |
# File 'lib/factpulse/models/webhook_secret_status_response.rb', line 98 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @has_secret.nil? true end |