Class: FactPulse::AFNORFacilityPayloadHistory
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::AFNORFacilityPayloadHistory
- Defined in:
- lib/factpulse/models/afnor_facility_payload_history.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#administrative_status ⇒ Object
Returns the value of attribute administrative_status.
-
#b2g_additional_data ⇒ Object
Returns the value of attribute b2g_additional_data.
-
#diffusible ⇒ Object
Returns the value of attribute diffusible.
-
#facility_type ⇒ Object
Returns the value of attribute facility_type.
-
#legal_unit ⇒ Object
Returns the value of attribute legal_unit.
-
#name ⇒ Object
business name.
-
#siren ⇒ Object
SIREN number.
-
#siret ⇒ Object
SIRET Number.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AFNORFacilityPayloadHistory
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AFNORFacilityPayloadHistory
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 109 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORFacilityPayloadHistory` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORFacilityPayloadHistory`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'siret') self.siret = attributes[:'siret'] end if attributes.key?(:'siren') self.siren = attributes[:'siren'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'facility_type') self.facility_type = attributes[:'facility_type'] end if attributes.key?(:'diffusible') self.diffusible = attributes[:'diffusible'] end if attributes.key?(:'administrative_status') self.administrative_status = attributes[:'administrative_status'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'b2g_additional_data') self.b2g_additional_data = attributes[:'b2g_additional_data'] end if attributes.key?(:'legal_unit') self.legal_unit = attributes[:'legal_unit'] end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
33 34 35 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 33 def address @address end |
#administrative_status ⇒ Object
Returns the value of attribute administrative_status.
31 32 33 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 31 def administrative_status @administrative_status end |
#b2g_additional_data ⇒ Object
Returns the value of attribute b2g_additional_data.
35 36 37 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 35 def b2g_additional_data @b2g_additional_data end |
#diffusible ⇒ Object
Returns the value of attribute diffusible.
29 30 31 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 29 def diffusible @diffusible end |
#facility_type ⇒ Object
Returns the value of attribute facility_type.
27 28 29 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 27 def facility_type @facility_type end |
#legal_unit ⇒ Object
Returns the value of attribute legal_unit.
37 38 39 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 37 def legal_unit @legal_unit end |
#name ⇒ Object
business name
25 26 27 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 25 def name @name end |
#siren ⇒ Object
SIREN number
22 23 24 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 22 def siren @siren end |
#siret ⇒ Object
SIRET Number
19 20 21 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 19 def siret @siret end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
77 78 79 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 77 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 82 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 62 def self.attribute_map { :'siret' => :'siret', :'siren' => :'siren', :'name' => :'name', :'facility_type' => :'facilityType', :'diffusible' => :'diffusible', :'administrative_status' => :'administrativeStatus', :'address' => :'address', :'b2g_additional_data' => :'b2gAdditionalData', :'legal_unit' => :'legalUnit' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 285 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 105 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 102 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 87 def self.openapi_types { :'siret' => :'String', :'siren' => :'String', :'name' => :'String', :'facility_type' => :'AFNORFacilityType', :'diffusible' => :'AFNORDiffusionStatus', :'administrative_status' => :'AFNORFacilityAdministrativeStatus', :'address' => :'AFNORAddressRead', :'b2g_additional_data' => :'AFNORFacilityPayloadHistoryUleB2gAdditionalData', :'legal_unit' => :'AFNORLegalUnitPayloadIncludedNoSiren' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 256 def ==(o) return true if self.equal?(o) self.class == o.class && siret == o.siret && siren == o.siren && name == o.name && facility_type == o.facility_type && diffusible == o.diffusible && administrative_status == o.administrative_status && address == o.address && b2g_additional_data == o.b2g_additional_data && legal_unit == o.legal_unit end |
#eql?(o) ⇒ Boolean
272 273 274 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 272 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
278 279 280 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 278 def hash [siret, siren, name, facility_type, diffusible, administrative_status, address, b2g_additional_data, legal_unit].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 162 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@siret.nil? && @siret.to_s.length > 14 invalid_properties.push('invalid value for "siret", the character length must be smaller than or equal to 14.') end pattern = Regexp.new(/^([0-9]{14})$/) if !@siret.nil? && @siret !~ pattern invalid_properties.push("invalid value for \"siret\", must conform to the pattern #{pattern}.") end if !@siren.nil? && @siren.to_s.length > 9 invalid_properties.push('invalid value for "siren", the character length must be smaller than or equal to 9.') end pattern = Regexp.new(/^([0-9]{9})$/) if !@siren.nil? && @siren !~ pattern invalid_properties.push("invalid value for \"siren\", must conform to the pattern #{pattern}.") end if !@name.nil? && @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 307 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
192 193 194 195 196 197 198 199 200 |
# File 'lib/factpulse/models/afnor_facility_payload_history.rb', line 192 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@siret.nil? && @siret.to_s.length > 14 return false if !@siret.nil? && @siret !~ Regexp.new(/^([0-9]{14})$/) return false if !@siren.nil? && @siren.to_s.length > 9 return false if !@siren.nil? && @siren !~ Regexp.new(/^([0-9]{9})$/) return false if !@name.nil? && @name.to_s.length > 100 true end |