Class: FactPulse::AFNORUpdatePatchRoutingCodeBody
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::AFNORUpdatePatchRoutingCodeBody
- Defined in:
- lib/factpulse/models/afnor_update_patch_routing_code_body.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#administrative_status ⇒ Object
Returns the value of attribute administrative_status.
-
#routing_code_name ⇒ Object
Name of the directory line routing code.
-
#routing_identifier_type ⇒ Object
Routing Identifier type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AFNORUpdatePatchRoutingCodeBody
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AFNORUpdatePatchRoutingCodeBody
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/factpulse/models/afnor_update_patch_routing_code_body.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AFNORUpdatePatchRoutingCodeBody` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AFNORUpdatePatchRoutingCodeBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'routing_identifier_type') self.routing_identifier_type = attributes[:'routing_identifier_type'] end if attributes.key?(:'routing_code_name') self.routing_code_name = attributes[:'routing_code_name'] end if attributes.key?(:'administrative_status') self.administrative_status = attributes[:'administrative_status'] end if attributes.key?(:'address') self.address = attributes[:'address'] end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
26 27 28 |
# File 'lib/factpulse/models/afnor_update_patch_routing_code_body.rb', line 26 def address @address end |
#administrative_status ⇒ Object
Returns the value of attribute administrative_status.
24 25 26 |
# File 'lib/factpulse/models/afnor_update_patch_routing_code_body.rb', line 24 def administrative_status @administrative_status end |
#routing_code_name ⇒ Object
Name of the directory line routing code. This attribute is only returned if the directory line is defined at the SIREN / SIRET / Routing code mesh.
22 23 24 |
# File 'lib/factpulse/models/afnor_update_patch_routing_code_body.rb', line 22 def routing_code_name @routing_code_name end |
#routing_identifier_type ⇒ Object
Routing Identifier type.
19 20 21 |
# File 'lib/factpulse/models/afnor_update_patch_routing_code_body.rb', line 19 def routing_identifier_type @routing_identifier_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/factpulse/models/afnor_update_patch_routing_code_body.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/factpulse/models/afnor_update_patch_routing_code_body.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 |
# File 'lib/factpulse/models/afnor_update_patch_routing_code_body.rb', line 51 def self.attribute_map { :'routing_identifier_type' => :'routingIdentifierType', :'routing_code_name' => :'routingCodeName', :'administrative_status' => :'administrativeStatus', :'address' => :'address' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/factpulse/models/afnor_update_patch_routing_code_body.rb', line 220 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/factpulse/models/afnor_update_patch_routing_code_body.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 |
# File 'lib/factpulse/models/afnor_update_patch_routing_code_body.rb', line 71 def self.openapi_types { :'routing_identifier_type' => :'String', :'routing_code_name' => :'String', :'administrative_status' => :'AFNORRoutingCodeAdministrativeStatus', :'address' => :'AFNORAddressPatch' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
196 197 198 199 200 201 202 203 |
# File 'lib/factpulse/models/afnor_update_patch_routing_code_body.rb', line 196 def ==(o) return true if self.equal?(o) self.class == o.class && routing_identifier_type == o.routing_identifier_type && routing_code_name == o.routing_code_name && administrative_status == o.administrative_status && address == o.address end |
#eql?(o) ⇒ Boolean
207 208 209 |
# File 'lib/factpulse/models/afnor_update_patch_routing_code_body.rb', line 207 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
213 214 215 |
# File 'lib/factpulse/models/afnor_update_patch_routing_code_body.rb', line 213 def hash [routing_identifier_type, routing_code_name, administrative_status, address].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/factpulse/models/afnor_update_patch_routing_code_body.rb', line 121 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@routing_identifier_type.nil? && @routing_identifier_type.to_s.length > 4 invalid_properties.push('invalid value for "routing_identifier_type", the character length must be smaller than or equal to 4.') end pattern = Regexp.new(/^(?!\s*$).+/) if !@routing_identifier_type.nil? && @routing_identifier_type !~ pattern invalid_properties.push("invalid value for \"routing_identifier_type\", must conform to the pattern #{pattern}.") end if !@routing_code_name.nil? && @routing_code_name.to_s.length > 100 invalid_properties.push('invalid value for "routing_code_name", the character length must be smaller than or equal to 100.') end pattern = Regexp.new(/^(?!\s*$).+/) if !@routing_code_name.nil? && @routing_code_name !~ pattern invalid_properties.push("invalid value for \"routing_code_name\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/factpulse/models/afnor_update_patch_routing_code_body.rb', line 242 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
147 148 149 150 151 152 153 154 |
# File 'lib/factpulse/models/afnor_update_patch_routing_code_body.rb', line 147 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@routing_identifier_type.nil? && @routing_identifier_type.to_s.length > 4 return false if !@routing_identifier_type.nil? && @routing_identifier_type !~ Regexp.new(/^(?!\s*$).+/) return false if !@routing_code_name.nil? && @routing_code_name.to_s.length > 100 return false if !@routing_code_name.nil? && @routing_code_name !~ Regexp.new(/^(?!\s*$).+/) true end |