Class: FactPulse::AllowanceCharge
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::AllowanceCharge
- Defined in:
- lib/factpulse/models/allowance_charge.rb
Overview
Document-level or line-level allowance/charge. Represents BG-20 (Document level allowances), BG-21 (Document level charges), BG-27 (Invoice line allowances), or BG-28 (Invoice line charges).
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
Returns the value of attribute amount.
-
#base_amount ⇒ Object
Returns the value of attribute base_amount.
-
#is_charge ⇒ Object
True for charge, False for allowance (ChargeIndicator).
-
#percentage ⇒ Object
Returns the value of attribute percentage.
-
#reason ⇒ Object
Returns the value of attribute reason.
-
#reason_code ⇒ Object
Returns the value of attribute reason_code.
-
#vat_category ⇒ Object
Returns the value of attribute vat_category.
-
#vat_rate ⇒ Object
Returns the value of attribute vat_rate.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AllowanceCharge
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AllowanceCharge
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/factpulse/models/allowance_charge.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AllowanceCharge` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AllowanceCharge`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'is_charge') self.is_charge = attributes[:'is_charge'] else self.is_charge = nil end if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'base_amount') self.base_amount = attributes[:'base_amount'] end if attributes.key?(:'percentage') self.percentage = attributes[:'percentage'] end if attributes.key?(:'reason') self.reason = attributes[:'reason'] end if attributes.key?(:'reason_code') self.reason_code = attributes[:'reason_code'] end if attributes.key?(:'vat_category') self.vat_category = attributes[:'vat_category'] end if attributes.key?(:'vat_rate') self.vat_rate = attributes[:'vat_rate'] end end |
Instance Attribute Details
#amount ⇒ Object
Returns the value of attribute amount.
22 23 24 |
# File 'lib/factpulse/models/allowance_charge.rb', line 22 def amount @amount end |
#base_amount ⇒ Object
Returns the value of attribute base_amount.
24 25 26 |
# File 'lib/factpulse/models/allowance_charge.rb', line 24 def base_amount @base_amount end |
#is_charge ⇒ Object
True for charge, False for allowance (ChargeIndicator).
20 21 22 |
# File 'lib/factpulse/models/allowance_charge.rb', line 20 def is_charge @is_charge end |
#percentage ⇒ Object
Returns the value of attribute percentage.
26 27 28 |
# File 'lib/factpulse/models/allowance_charge.rb', line 26 def percentage @percentage end |
#reason ⇒ Object
Returns the value of attribute reason.
28 29 30 |
# File 'lib/factpulse/models/allowance_charge.rb', line 28 def reason @reason end |
#reason_code ⇒ Object
Returns the value of attribute reason_code.
30 31 32 |
# File 'lib/factpulse/models/allowance_charge.rb', line 30 def reason_code @reason_code end |
#vat_category ⇒ Object
Returns the value of attribute vat_category.
32 33 34 |
# File 'lib/factpulse/models/allowance_charge.rb', line 32 def vat_category @vat_category end |
#vat_rate ⇒ Object
Returns the value of attribute vat_rate.
34 35 36 |
# File 'lib/factpulse/models/allowance_charge.rb', line 34 def vat_rate @vat_rate end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/factpulse/models/allowance_charge.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/factpulse/models/allowance_charge.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/factpulse/models/allowance_charge.rb', line 59 def self.attribute_map { :'is_charge' => :'is_charge', :'amount' => :'amount', :'base_amount' => :'base_amount', :'percentage' => :'percentage', :'reason' => :'reason', :'reason_code' => :'reason_code', :'vat_category' => :'vat_category', :'vat_rate' => :'vat_rate' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/factpulse/models/allowance_charge.rb', line 236 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 101 102 103 104 105 106 |
# File 'lib/factpulse/models/allowance_charge.rb', line 97 def self.openapi_nullable Set.new([ :'base_amount', :'percentage', :'reason', :'reason_code', :'vat_category', :'vat_rate' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/factpulse/models/allowance_charge.rb', line 83 def self.openapi_types { :'is_charge' => :'Boolean', :'amount' => :'Amount1', :'base_amount' => :'BaseAmount', :'percentage' => :'Percentage', :'reason' => :'String', :'reason_code' => :'AllowanceChargeReasonCode', :'vat_category' => :'VATCategory', :'vat_rate' => :'VatRate' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/factpulse/models/allowance_charge.rb', line 208 def ==(o) return true if self.equal?(o) self.class == o.class && is_charge == o.is_charge && amount == o.amount && base_amount == o.base_amount && percentage == o.percentage && reason == o.reason && reason_code == o.reason_code && vat_category == o.vat_category && vat_rate == o.vat_rate end |
#eql?(o) ⇒ Boolean
223 224 225 |
# File 'lib/factpulse/models/allowance_charge.rb', line 223 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
229 230 231 |
# File 'lib/factpulse/models/allowance_charge.rb', line 229 def hash [is_charge, amount, base_amount, percentage, reason, reason_code, vat_category, vat_rate].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/factpulse/models/allowance_charge.rb', line 163 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @is_charge.nil? invalid_properties.push('invalid value for "is_charge", is_charge cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/factpulse/models/allowance_charge.rb', line 258 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 |
# File 'lib/factpulse/models/allowance_charge.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @is_charge.nil? return false if @amount.nil? true end |