Class: FactPulse::AllowanceCharge

Inherits:
ApiModelBase show all
Defined in:
lib/factpulse/models/allowance_charge.rb

Overview

Document-level or line-level allowance/charge. Represents BG-20 (Document level allowances), BG-21 (Document level charges), BG-27 (Invoice line allowances), or BG-28 (Invoice line charges).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AllowanceCharge

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/factpulse/models/allowance_charge.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::AllowanceCharge` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::AllowanceCharge`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'is_charge')
    self.is_charge = attributes[:'is_charge']
  else
    self.is_charge = nil
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'base_amount')
    self.base_amount = attributes[:'base_amount']
  end

  if attributes.key?(:'percentage')
    self.percentage = attributes[:'percentage']
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  end

  if attributes.key?(:'reason_code')
    self.reason_code = attributes[:'reason_code']
  end

  if attributes.key?(:'vat_category')
    self.vat_category = attributes[:'vat_category']
  end

  if attributes.key?(:'vat_rate')
    self.vat_rate = attributes[:'vat_rate']
  end
end

Instance Attribute Details

#amount ⇒ Object

Returns the value of attribute amount.



22
23
24
# File 'lib/factpulse/models/allowance_charge.rb', line 22

def amount
  @amount
end

#base_amount ⇒ Object

Returns the value of attribute base_amount.



24
25
26
# File 'lib/factpulse/models/allowance_charge.rb', line 24

def base_amount
  @base_amount
end

#is_charge ⇒ Object

True for charge, False for allowance (ChargeIndicator).



20
21
22
# File 'lib/factpulse/models/allowance_charge.rb', line 20

def is_charge
  @is_charge
end

#percentage ⇒ Object

Returns the value of attribute percentage.



26
27
28
# File 'lib/factpulse/models/allowance_charge.rb', line 26

def percentage
  @percentage
end

#reason ⇒ Object

Returns the value of attribute reason.



28
29
30
# File 'lib/factpulse/models/allowance_charge.rb', line 28

def reason
  @reason
end

#reason_code ⇒ Object

Returns the value of attribute reason_code.



30
31
32
# File 'lib/factpulse/models/allowance_charge.rb', line 30

def reason_code
  @reason_code
end

#vat_category ⇒ Object

Returns the value of attribute vat_category.



32
33
34
# File 'lib/factpulse/models/allowance_charge.rb', line 32

def vat_category
  @vat_category
end

#vat_rate ⇒ Object

Returns the value of attribute vat_rate.



34
35
36
# File 'lib/factpulse/models/allowance_charge.rb', line 34

def vat_rate
  @vat_rate
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



51
52
53
# File 'lib/factpulse/models/allowance_charge.rb', line 51

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



56
57
58
# File 'lib/factpulse/models/allowance_charge.rb', line 56

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/factpulse/models/allowance_charge.rb', line 37

def self.attribute_map
  {
    :'is_charge' => :'is_charge',
    :'amount' => :'amount',
    :'base_amount' => :'base_amount',
    :'percentage' => :'percentage',
    :'reason' => :'reason',
    :'reason_code' => :'reason_code',
    :'vat_category' => :'vat_category',
    :'vat_rate' => :'vat_rate'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/factpulse/models/allowance_charge.rb', line 214

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



75
76
77
78
79
80
81
82
83
84
# File 'lib/factpulse/models/allowance_charge.rb', line 75

def self.openapi_nullable
  Set.new([
    :'base_amount',
    :'percentage',
    :'reason',
    :'reason_code',
    :'vat_category',
    :'vat_rate'
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/factpulse/models/allowance_charge.rb', line 61

def self.openapi_types
  {
    :'is_charge' => :'Boolean',
    :'amount' => :'Amount',
    :'base_amount' => :'BaseAmount',
    :'percentage' => :'Percentage',
    :'reason' => :'String',
    :'reason_code' => :'String',
    :'vat_category' => :'String',
    :'vat_rate' => :'VatRate'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/factpulse/models/allowance_charge.rb', line 186

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      is_charge == o.is_charge &&
      amount == o.amount &&
      base_amount == o.base_amount &&
      percentage == o.percentage &&
      reason == o.reason &&
      reason_code == o.reason_code &&
      vat_category == o.vat_category &&
      vat_rate == o.vat_rate
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


201
202
203
# File 'lib/factpulse/models/allowance_charge.rb', line 201

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



207
208
209
# File 'lib/factpulse/models/allowance_charge.rb', line 207

def hash
  [is_charge, amount, base_amount, percentage, reason, reason_code, vat_category, vat_rate].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/factpulse/models/allowance_charge.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @is_charge.nil?
    invalid_properties.push('invalid value for "is_charge", is_charge cannot be nil.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/factpulse/models/allowance_charge.rb', line 236

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



157
158
159
160
161
162
# File 'lib/factpulse/models/allowance_charge.rb', line 157

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @is_charge.nil?
  return false if @amount.nil?
  true
end