Class: FactPulse::ConversionSuccessTaskResult
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::ConversionSuccessTaskResult
- Defined in:
- lib/factpulse/models/conversion_success_task_result.rb
Overview
Successful result from task_convert_document.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#content_b64 ⇒ Object
Returns the value of attribute content_b64.
-
#conversion_id ⇒ Object
Returns the value of attribute conversion_id.
-
#document_type_code ⇒ Object
Returns the value of attribute document_type_code.
-
#extraction ⇒ Object
Returns the value of attribute extraction.
-
#pdf_regenerated ⇒ Object
Returns the value of attribute pdf_regenerated.
-
#pdf_regenerated_reason ⇒ Object
Returns the value of attribute pdf_regenerated_reason.
-
#processing_time_ms ⇒ Object
Returns the value of attribute processing_time_ms.
-
#profile ⇒ Object
Returns the value of attribute profile.
-
#status ⇒ Object
Returns the value of attribute status.
-
#xml_content ⇒ Object
Returns the value of attribute xml_content.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConversionSuccessTaskResult
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ConversionSuccessTaskResult
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::ConversionSuccessTaskResult` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::ConversionSuccessTaskResult`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = 'SUCCESS' end if attributes.key?(:'conversion_id') self.conversion_id = attributes[:'conversion_id'] else self.conversion_id = nil end if attributes.key?(:'document_type_code') self.document_type_code = attributes[:'document_type_code'] else self.document_type_code = nil end if attributes.key?(:'profile') self.profile = attributes[:'profile'] else self.profile = nil end if attributes.key?(:'extraction') self.extraction = attributes[:'extraction'] else self.extraction = nil end if attributes.key?(:'processing_time_ms') self.processing_time_ms = attributes[:'processing_time_ms'] else self.processing_time_ms = nil end if attributes.key?(:'pdf_regenerated') self.pdf_regenerated = attributes[:'pdf_regenerated'] else self.pdf_regenerated = false end if attributes.key?(:'pdf_regenerated_reason') self.pdf_regenerated_reason = attributes[:'pdf_regenerated_reason'] end if attributes.key?(:'content_b64') self.content_b64 = attributes[:'content_b64'] end if attributes.key?(:'xml_content') self.xml_content = attributes[:'xml_content'] end end |
Instance Attribute Details
#content_b64 ⇒ Object
Returns the value of attribute content_b64.
35 36 37 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 35 def content_b64 @content_b64 end |
#conversion_id ⇒ Object
Returns the value of attribute conversion_id.
21 22 23 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 21 def conversion_id @conversion_id end |
#document_type_code ⇒ Object
Returns the value of attribute document_type_code.
23 24 25 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 23 def document_type_code @document_type_code end |
#extraction ⇒ Object
Returns the value of attribute extraction.
27 28 29 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 27 def extraction @extraction end |
#pdf_regenerated ⇒ Object
Returns the value of attribute pdf_regenerated.
31 32 33 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 31 def pdf_regenerated @pdf_regenerated end |
#pdf_regenerated_reason ⇒ Object
Returns the value of attribute pdf_regenerated_reason.
33 34 35 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 33 def pdf_regenerated_reason @pdf_regenerated_reason end |
#processing_time_ms ⇒ Object
Returns the value of attribute processing_time_ms.
29 30 31 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 29 def processing_time_ms @processing_time_ms end |
#profile ⇒ Object
Returns the value of attribute profile.
25 26 27 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 25 def profile @profile end |
#status ⇒ Object
Returns the value of attribute status.
19 20 21 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 19 def status @status end |
#xml_content ⇒ Object
Returns the value of attribute xml_content.
37 38 39 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 37 def xml_content @xml_content end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 62 def self.attribute_map { :'status' => :'status', :'conversion_id' => :'conversion_id', :'document_type_code' => :'document_type_code', :'profile' => :'profile', :'extraction' => :'extraction', :'processing_time_ms' => :'processing_time_ms', :'pdf_regenerated' => :'pdf_regenerated', :'pdf_regenerated_reason' => :'pdf_regenerated_reason', :'content_b64' => :'content_b64', :'xml_content' => :'xml_content' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 317 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
104 105 106 107 108 109 110 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 104 def self.openapi_nullable Set.new([ :'pdf_regenerated_reason', :'content_b64', :'xml_content' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 88 def self.openapi_types { :'status' => :'String', :'conversion_id' => :'String', :'document_type_code' => :'Integer', :'profile' => :'String', :'extraction' => :'ConversionExtractionInfo', :'processing_time_ms' => :'Integer', :'pdf_regenerated' => :'Boolean', :'pdf_regenerated_reason' => :'String', :'content_b64' => :'String', :'xml_content' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 287 def ==(o) return true if self.equal?(o) self.class == o.class && status == o.status && conversion_id == o.conversion_id && document_type_code == o.document_type_code && profile == o.profile && extraction == o.extraction && processing_time_ms == o.processing_time_ms && pdf_regenerated == o.pdf_regenerated && pdf_regenerated_reason == o.pdf_regenerated_reason && content_b64 == o.content_b64 && xml_content == o.xml_content end |
#eql?(o) ⇒ Boolean
304 305 306 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 304 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
310 311 312 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 310 def hash [status, conversion_id, document_type_code, profile, extraction, processing_time_ms, pdf_regenerated, pdf_regenerated_reason, content_b64, xml_content].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 185 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @conversion_id.nil? invalid_properties.push('invalid value for "conversion_id", conversion_id cannot be nil.') end if @document_type_code.nil? invalid_properties.push('invalid value for "document_type_code", document_type_code cannot be nil.') end if @profile.nil? invalid_properties.push('invalid value for "profile", profile cannot be nil.') end if @extraction.nil? invalid_properties.push('invalid value for "extraction", extraction cannot be nil.') end if @processing_time_ms.nil? invalid_properties.push('invalid value for "processing_time_ms", processing_time_ms cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 339 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/factpulse/models/conversion_success_task_result.rb', line 213 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["SUCCESS"]) return false unless status_validator.valid?(@status) return false if @conversion_id.nil? return false if @document_type_code.nil? return false if @profile.nil? return false if @extraction.nil? return false if @processing_time_ms.nil? true end |