Class: FactPulse::ConvertPendingInputResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::ConvertPendingInputResponse
- Defined in:
- lib/factpulse/models/convert_pending_input_response.rb
Overview
Reponse donnees manquantes.
Instance Attribute Summary collapse
-
#conversion_id ⇒ Object
Returns the value of attribute conversion_id.
-
#expires_at ⇒ Object
Returns the value of attribute expires_at.
-
#extracted_data ⇒ Object
Donnees extraites par OCR au format FacturXInvoice.
-
#extraction ⇒ Object
Returns the value of attribute extraction.
-
#message ⇒ Object
Returns the value of attribute message.
-
#missing_fields ⇒ Object
Returns the value of attribute missing_fields.
-
#resume_url ⇒ Object
Returns the value of attribute resume_url.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConvertPendingInputResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ConvertPendingInputResponse
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::ConvertPendingInputResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::ConvertPendingInputResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = 'pending_input' end if attributes.key?(:'conversion_id') self.conversion_id = attributes[:'conversion_id'] else self.conversion_id = nil end if attributes.key?(:'message') self. = attributes[:'message'] else self. = 'Donnees manquantes requises pour la conformite' end if attributes.key?(:'extraction') self.extraction = attributes[:'extraction'] else self.extraction = nil end if attributes.key?(:'extracted_data') if (value = attributes[:'extracted_data']).is_a?(Hash) self.extracted_data = value end else self.extracted_data = nil end if attributes.key?(:'missing_fields') if (value = attributes[:'missing_fields']).is_a?(Array) self.missing_fields = value end else self.missing_fields = nil end if attributes.key?(:'resume_url') self.resume_url = attributes[:'resume_url'] else self.resume_url = nil end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] else self.expires_at = nil end end |
Instance Attribute Details
#conversion_id ⇒ Object
Returns the value of attribute conversion_id.
21 22 23 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 21 def conversion_id @conversion_id end |
#expires_at ⇒ Object
Returns the value of attribute expires_at.
34 35 36 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 34 def expires_at @expires_at end |
#extracted_data ⇒ Object
Donnees extraites par OCR au format FacturXInvoice
28 29 30 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 28 def extracted_data @extracted_data end |
#extraction ⇒ Object
Returns the value of attribute extraction.
25 26 27 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 25 def extraction @extraction end |
#message ⇒ Object
Returns the value of attribute message.
23 24 25 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 23 def @message end |
#missing_fields ⇒ Object
Returns the value of attribute missing_fields.
30 31 32 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 30 def missing_fields @missing_fields end |
#resume_url ⇒ Object
Returns the value of attribute resume_url.
32 33 34 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 32 def resume_url @resume_url end |
#status ⇒ Object
Returns the value of attribute status.
19 20 21 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 19 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
51 52 53 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 51 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
56 57 58 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 56 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 37 def self.attribute_map { :'status' => :'status', :'conversion_id' => :'conversion_id', :'message' => :'message', :'extraction' => :'extraction', :'extracted_data' => :'extracted_data', :'missing_fields' => :'missing_fields', :'resume_url' => :'resume_url', :'expires_at' => :'expires_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 284 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 75 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 61 def self.openapi_types { :'status' => :'String', :'conversion_id' => :'String', :'message' => :'String', :'extraction' => :'ExtractionInfo', :'extracted_data' => :'Hash<String, Object>', :'missing_fields' => :'Array<MissingField>', :'resume_url' => :'String', :'expires_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 256 def ==(o) return true if self.equal?(o) self.class == o.class && status == o.status && conversion_id == o.conversion_id && == o. && extraction == o.extraction && extracted_data == o.extracted_data && missing_fields == o.missing_fields && resume_url == o.resume_url && expires_at == o.expires_at end |
#eql?(o) ⇒ Boolean
271 272 273 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 271 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
277 278 279 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 277 def hash [status, conversion_id, , extraction, extracted_data, missing_fields, resume_url, expires_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @conversion_id.nil? invalid_properties.push('invalid value for "conversion_id", conversion_id cannot be nil.') end if @extraction.nil? invalid_properties.push('invalid value for "extraction", extraction cannot be nil.') end if @extracted_data.nil? invalid_properties.push('invalid value for "extracted_data", extracted_data cannot be nil.') end if @missing_fields.nil? invalid_properties.push('invalid value for "missing_fields", missing_fields cannot be nil.') end if @resume_url.nil? invalid_properties.push('invalid value for "resume_url", resume_url cannot be nil.') end if @expires_at.nil? invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 306 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
183 184 185 186 187 188 189 190 191 192 |
# File 'lib/factpulse/models/convert_pending_input_response.rb', line 183 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @conversion_id.nil? return false if @extraction.nil? return false if @extracted_data.nil? return false if @missing_fields.nil? return false if @resume_url.nil? return false if @expires_at.nil? true end |