Class: FactPulse::ConvertSuccessResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::ConvertSuccessResponse
- Defined in:
- lib/factpulse/models/convert_success_response.rb
Overview
Reponse succes de conversion. Le champ invoice contient les donnees de la facture au format FacturXInvoice (cf. facture_electronique.models.FacturXInvoice). Ce modele est le meme que celui utilise pour la generation Factur-X, garantissant une coherence totale.
Instance Attribute Summary collapse
-
#conversion_id ⇒ Object
Identifiant unique de conversion.
-
#document_type ⇒ Object
Returns the value of attribute document_type.
-
#extraction ⇒ Object
Returns the value of attribute extraction.
-
#files ⇒ Object
Returns the value of attribute files.
-
#invoice ⇒ Object
Donnees facture au format FacturXInvoice (cf. models.py).
-
#pdf_regenerated ⇒ Object
True si le PDF a ete regenere (source non exploitable).
-
#pdf_regenerated_reason ⇒ Object
Returns the value of attribute pdf_regenerated_reason.
-
#processing_time_ms ⇒ Object
Temps de traitement en ms.
-
#status ⇒ Object
Statut de la conversion.
-
#validation ⇒ Object
Returns the value of attribute validation.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConvertSuccessResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ConvertSuccessResponse
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/factpulse/models/convert_success_response.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::ConvertSuccessResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::ConvertSuccessResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = 'success' end if attributes.key?(:'conversion_id') self.conversion_id = attributes[:'conversion_id'] else self.conversion_id = nil end if attributes.key?(:'document_type') self.document_type = attributes[:'document_type'] else self.document_type = nil end if attributes.key?(:'invoice') if (value = attributes[:'invoice']).is_a?(Hash) self.invoice = value end else self.invoice = nil end if attributes.key?(:'extraction') self.extraction = attributes[:'extraction'] else self.extraction = nil end if attributes.key?(:'validation') self.validation = attributes[:'validation'] else self.validation = nil end if attributes.key?(:'files') self.files = attributes[:'files'] else self.files = nil end if attributes.key?(:'processing_time_ms') self.processing_time_ms = attributes[:'processing_time_ms'] else self.processing_time_ms = nil end if attributes.key?(:'pdf_regenerated') self.pdf_regenerated = attributes[:'pdf_regenerated'] else self.pdf_regenerated = false end if attributes.key?(:'pdf_regenerated_reason') self.pdf_regenerated_reason = attributes[:'pdf_regenerated_reason'] end end |
Instance Attribute Details
#conversion_id ⇒ Object
Identifiant unique de conversion
23 24 25 |
# File 'lib/factpulse/models/convert_success_response.rb', line 23 def conversion_id @conversion_id end |
#document_type ⇒ Object
Returns the value of attribute document_type.
25 26 27 |
# File 'lib/factpulse/models/convert_success_response.rb', line 25 def document_type @document_type end |
#extraction ⇒ Object
Returns the value of attribute extraction.
30 31 32 |
# File 'lib/factpulse/models/convert_success_response.rb', line 30 def extraction @extraction end |
#files ⇒ Object
Returns the value of attribute files.
34 35 36 |
# File 'lib/factpulse/models/convert_success_response.rb', line 34 def files @files end |
#invoice ⇒ Object
Donnees facture au format FacturXInvoice (cf. models.py)
28 29 30 |
# File 'lib/factpulse/models/convert_success_response.rb', line 28 def invoice @invoice end |
#pdf_regenerated ⇒ Object
True si le PDF a ete regenere (source non exploitable)
40 41 42 |
# File 'lib/factpulse/models/convert_success_response.rb', line 40 def pdf_regenerated @pdf_regenerated end |
#pdf_regenerated_reason ⇒ Object
Returns the value of attribute pdf_regenerated_reason.
42 43 44 |
# File 'lib/factpulse/models/convert_success_response.rb', line 42 def pdf_regenerated_reason @pdf_regenerated_reason end |
#processing_time_ms ⇒ Object
Temps de traitement en ms
37 38 39 |
# File 'lib/factpulse/models/convert_success_response.rb', line 37 def processing_time_ms @processing_time_ms end |
#status ⇒ Object
Statut de la conversion
20 21 22 |
# File 'lib/factpulse/models/convert_success_response.rb', line 20 def status @status end |
#validation ⇒ Object
Returns the value of attribute validation.
32 33 34 |
# File 'lib/factpulse/models/convert_success_response.rb', line 32 def validation @validation end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/factpulse/models/convert_success_response.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/factpulse/models/convert_success_response.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/factpulse/models/convert_success_response.rb', line 45 def self.attribute_map { :'status' => :'status', :'conversion_id' => :'conversion_id', :'document_type' => :'document_type', :'invoice' => :'invoice', :'extraction' => :'extraction', :'validation' => :'validation', :'files' => :'files', :'processing_time_ms' => :'processing_time_ms', :'pdf_regenerated' => :'pdf_regenerated', :'pdf_regenerated_reason' => :'pdf_regenerated_reason' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/factpulse/models/convert_success_response.rb', line 322 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 91 |
# File 'lib/factpulse/models/convert_success_response.rb', line 87 def self.openapi_nullable Set.new([ :'pdf_regenerated_reason' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/factpulse/models/convert_success_response.rb', line 71 def self.openapi_types { :'status' => :'String', :'conversion_id' => :'String', :'document_type' => :'DocumentTypeInfo', :'invoice' => :'Hash<String, Object>', :'extraction' => :'ExtractionInfo', :'validation' => :'ValidationInfo', :'files' => :'FilesInfo', :'processing_time_ms' => :'Integer', :'pdf_regenerated' => :'Boolean', :'pdf_regenerated_reason' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/factpulse/models/convert_success_response.rb', line 292 def ==(o) return true if self.equal?(o) self.class == o.class && status == o.status && conversion_id == o.conversion_id && document_type == o.document_type && invoice == o.invoice && extraction == o.extraction && validation == o.validation && files == o.files && processing_time_ms == o.processing_time_ms && pdf_regenerated == o.pdf_regenerated && pdf_regenerated_reason == o.pdf_regenerated_reason end |
#eql?(o) ⇒ Boolean
309 310 311 |
# File 'lib/factpulse/models/convert_success_response.rb', line 309 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
315 316 317 |
# File 'lib/factpulse/models/convert_success_response.rb', line 315 def hash [status, conversion_id, document_type, invoice, extraction, validation, files, processing_time_ms, pdf_regenerated, pdf_regenerated_reason].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/factpulse/models/convert_success_response.rb', line 172 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @conversion_id.nil? invalid_properties.push('invalid value for "conversion_id", conversion_id cannot be nil.') end if @document_type.nil? invalid_properties.push('invalid value for "document_type", document_type cannot be nil.') end if @invoice.nil? invalid_properties.push('invalid value for "invoice", invoice cannot be nil.') end if @extraction.nil? invalid_properties.push('invalid value for "extraction", extraction cannot be nil.') end if @validation.nil? invalid_properties.push('invalid value for "validation", validation cannot be nil.') end if @files.nil? invalid_properties.push('invalid value for "files", files cannot be nil.') end if @processing_time_ms.nil? invalid_properties.push('invalid value for "processing_time_ms", processing_time_ms cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/factpulse/models/convert_success_response.rb', line 344 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/factpulse/models/convert_success_response.rb', line 208 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @conversion_id.nil? return false if @document_type.nil? return false if @invoice.nil? return false if @extraction.nil? return false if @validation.nil? return false if @files.nil? return false if @processing_time_ms.nil? true end |