Class: FactPulse::ConvertValidationFailedResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::ConvertValidationFailedResponse
- Defined in:
- lib/factpulse/models/convert_validation_failed_response.rb
Overview
Reponse echec de validation - inclut les donnees extraites pour correction.
Instance Attribute Summary collapse
-
#conversion_id ⇒ Object
Identifiant unique de conversion.
-
#expires_at ⇒ Object
Expiration de la conversion (1h).
-
#extracted_data ⇒ Object
Donnees extraites par OCR au format FacturXInvoice (a completer/corriger).
-
#extraction ⇒ Object
Informations sur l’extraction OCR.
-
#message ⇒ Object
Message explicatif.
-
#missing_fields ⇒ Object
Champs manquants pour conformite Factur-X.
-
#resume_url ⇒ Object
URL pour reprendre la conversion avec corrections.
-
#status ⇒ Object
Statut de la conversion.
-
#validation ⇒ Object
Resultat de la validation Factur-X.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConvertValidationFailedResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ConvertValidationFailedResponse
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::ConvertValidationFailedResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::ConvertValidationFailedResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = 'validation_failed' end if attributes.key?(:'conversion_id') self.conversion_id = attributes[:'conversion_id'] else self.conversion_id = nil end if attributes.key?(:'message') self. = attributes[:'message'] else self. = 'Donnees extraites avec erreurs de validation. Completez le formulaire et appelez /resume.' end if attributes.key?(:'extraction') self.extraction = attributes[:'extraction'] else self.extraction = nil end if attributes.key?(:'extracted_data') if (value = attributes[:'extracted_data']).is_a?(Hash) self.extracted_data = value end else self.extracted_data = nil end if attributes.key?(:'missing_fields') if (value = attributes[:'missing_fields']).is_a?(Array) self.missing_fields = value end end if attributes.key?(:'validation') self.validation = attributes[:'validation'] else self.validation = nil end if attributes.key?(:'resume_url') self.resume_url = attributes[:'resume_url'] else self.resume_url = nil end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] else self.expires_at = nil end end |
Instance Attribute Details
#conversion_id ⇒ Object
Identifiant unique de conversion
23 24 25 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 23 def conversion_id @conversion_id end |
#expires_at ⇒ Object
Expiration de la conversion (1h)
44 45 46 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 44 def expires_at @expires_at end |
#extracted_data ⇒ Object
Donnees extraites par OCR au format FacturXInvoice (a completer/corriger)
32 33 34 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 32 def extracted_data @extracted_data end |
#extraction ⇒ Object
Informations sur l’extraction OCR
29 30 31 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 29 def extraction @extraction end |
#message ⇒ Object
Message explicatif
26 27 28 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 26 def end |
#missing_fields ⇒ Object
Champs manquants pour conformite Factur-X
35 36 37 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 35 def missing_fields @missing_fields end |
#resume_url ⇒ Object
URL pour reprendre la conversion avec corrections
41 42 43 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 41 def resume_url @resume_url end |
#status ⇒ Object
Statut de la conversion
20 21 22 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 20 def status @status end |
#validation ⇒ Object
Resultat de la validation Factur-X
38 39 40 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 38 def validation @validation end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 47 def self.attribute_map { :'status' => :'status', :'conversion_id' => :'conversion_id', :'message' => :'message', :'extraction' => :'extraction', :'extracted_data' => :'extracted_data', :'missing_fields' => :'missing_fields', :'validation' => :'validation', :'resume_url' => :'resume_url', :'expires_at' => :'expires_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 301 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 72 def self.openapi_types { :'status' => :'String', :'conversion_id' => :'String', :'message' => :'String', :'extraction' => :'ExtractionInfo', :'extracted_data' => :'Hash<String, Object>', :'missing_fields' => :'Array<MissingField>', :'validation' => :'ValidationInfo', :'resume_url' => :'String', :'expires_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 272 def ==(o) return true if self.equal?(o) self.class == o.class && status == o.status && conversion_id == o.conversion_id && == o. && extraction == o.extraction && extracted_data == o.extracted_data && missing_fields == o.missing_fields && validation == o.validation && resume_url == o.resume_url && expires_at == o.expires_at end |
#eql?(o) ⇒ Boolean
288 289 290 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 288 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
294 295 296 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 294 def hash [status, conversion_id, , extraction, extracted_data, missing_fields, validation, resume_url, expires_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 167 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @conversion_id.nil? invalid_properties.push('invalid value for "conversion_id", conversion_id cannot be nil.') end if @extraction.nil? invalid_properties.push('invalid value for "extraction", extraction cannot be nil.') end if @extracted_data.nil? invalid_properties.push('invalid value for "extracted_data", extracted_data cannot be nil.') end if @validation.nil? invalid_properties.push('invalid value for "validation", validation cannot be nil.') end if @resume_url.nil? invalid_properties.push('invalid value for "resume_url", resume_url cannot be nil.') end if @expires_at.nil? invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 323 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
199 200 201 202 203 204 205 206 207 208 |
# File 'lib/factpulse/models/convert_validation_failed_response.rb', line 199 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @conversion_id.nil? return false if @extraction.nil? return false if @extracted_data.nil? return false if @validation.nil? return false if @resume_url.nil? return false if @expires_at.nil? true end |