Class: FactPulse::CreateAggregatedReportRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/factpulse/models/create_aggregated_report_request.rb

Overview

Request to create a PPF-compliant aggregated e-reporting submission. This schema allows creating a SINGLE report file containing multiple flux types, as expected by the PPF and PA platforms: - TransactionsReport: Contains both Invoice (10.1) and Transactions (10.3) - PaymentsReport: Contains both Invoice payments (10.2) and Transaction payments (10.4) Source: Specifications externes v3.1, XSD ereporting.xsd

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateAggregatedReportRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 116

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::CreateAggregatedReportRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::CreateAggregatedReportRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'report_id')
    self.report_id = attributes[:'report_id']
  else
    self.report_id = nil
  end

  if attributes.key?(:'report_name')
    self.report_name = attributes[:'report_name']
  end

  if attributes.key?(:'transmission_type')
    self.transmission_type = attributes[:'transmission_type']
  end

  if attributes.key?(:'sender')
    self.sender = attributes[:'sender']
  else
    self.sender = nil
  end

  if attributes.key?(:'period')
    self.period = attributes[:'period']
  else
    self.period = nil
  end

  if attributes.key?(:'invoices')
    if (value = attributes[:'invoices']).is_a?(Array)
      self.invoices = value
    end
  end

  if attributes.key?(:'transactions')
    if (value = attributes[:'transactions']).is_a?(Array)
      self.transactions = value
    end
  end

  if attributes.key?(:'invoice_payments')
    if (value = attributes[:'invoice_payments']).is_a?(Array)
      self.invoice_payments = value
    end
  end

  if attributes.key?(:'transaction_payments')
    if (value = attributes[:'transaction_payments']).is_a?(Array)
      self.transaction_payments = value
    end
  end
end

Instance Attribute Details

#invoice_payments ⇒ Object

Returns the value of attribute invoice_payments.



37
38
39
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 37

def invoice_payments
  @invoice_payments
end

#invoices ⇒ Object

Returns the value of attribute invoices.



33
34
35
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 33

def invoices
  @invoices
end

#period ⇒ Object

Reporting period



31
32
33
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 31

def period
  @period
end

#report_id ⇒ Object

Report identifier (generated by caller)



20
21
22
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 20

def report_id
  @report_id
end

#report_name ⇒ Object

Returns the value of attribute report_name.



22
23
24
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 22

def report_name
  @report_name
end

#sender ⇒ Object

Report sender/declarant



28
29
30
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 28

def sender
  @sender
end

#transaction_payments ⇒ Object

Returns the value of attribute transaction_payments.



39
40
41
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 39

def transaction_payments
  @transaction_payments
end

#transactions ⇒ Object

Returns the value of attribute transactions.



35
36
37
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 35

def transactions
  @transactions
end

#transmission_type ⇒ Object

Transmission type: IN=Initial, RE=Rectificative (TT-4)



25
26
27
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 25

def transmission_type
  @transmission_type
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



79
80
81
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 64

def self.attribute_map
  {
    :'report_id' => :'reportId',
    :'report_name' => :'reportName',
    :'transmission_type' => :'transmissionType',
    :'sender' => :'sender',
    :'period' => :'period',
    :'invoices' => :'invoices',
    :'transactions' => :'transactions',
    :'invoice_payments' => :'invoicePayments',
    :'transaction_payments' => :'transactionPayments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 272

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



104
105
106
107
108
109
110
111
112
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 104

def self.openapi_nullable
  Set.new([
    :'report_name',
    :'invoices',
    :'transactions',
    :'invoice_payments',
    :'transaction_payments'
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 89

def self.openapi_types
  {
    :'report_id' => :'String',
    :'report_name' => :'String',
    :'transmission_type' => :'TransmissionTypeCode',
    :'sender' => :'ReportSender',
    :'period' => :'ReportPeriod',
    :'invoices' => :'Array<InvoiceInput>',
    :'transactions' => :'Array<AggregatedTransactionInput>',
    :'invoice_payments' => :'Array<InvoicePaymentInput>',
    :'transaction_payments' => :'Array<AggregatedPaymentInput>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 243

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      report_id == o.report_id &&
      report_name == o.report_name &&
      transmission_type == o.transmission_type &&
      sender == o.sender &&
      period == o.period &&
      invoices == o.invoices &&
      transactions == o.transactions &&
      invoice_payments == o.invoice_payments &&
      transaction_payments == o.transaction_payments
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


259
260
261
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 259

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



265
266
267
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 265

def hash
  [report_id, report_name, transmission_type, sender, period, invoices, transactions, invoice_payments, transaction_payments].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 183

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @report_id.nil?
    invalid_properties.push('invalid value for "report_id", report_id cannot be nil.')
  end

  if @sender.nil?
    invalid_properties.push('invalid value for "sender", sender cannot be nil.')
  end

  if @period.nil?
    invalid_properties.push('invalid value for "period", period cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 294

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



203
204
205
206
207
208
209
# File 'lib/factpulse/models/create_aggregated_report_request.rb', line 203

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @report_id.nil?
  return false if @sender.nil?
  return false if @period.nil?
  true
end