Class: FactPulse::CreateEReportingRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::CreateEReportingRequest
- Defined in:
- lib/factpulse/models/create_e_reporting_request.rb
Overview
Request to create an e-reporting submission. Supports all four flux types: - 10.1: B2B international invoices (use invoices field) - 10.2: B2B international payments (use invoicePayments field) - 10.3: B2C aggregated transactions (use transactions field) - 10.4: B2C aggregated payments (use aggregatedPayments field)
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#aggregated_payments ⇒ Object
Returns the value of attribute aggregated_payments.
-
#flow_type ⇒ Object
E-Reporting flux type (for internal routing).
-
#invoice_payments ⇒ Object
Returns the value of attribute invoice_payments.
-
#invoices ⇒ Object
Returns the value of attribute invoices.
-
#issuer ⇒ Object
Returns the value of attribute issuer.
-
#period ⇒ Object
Reporting period.
-
#report_id ⇒ Object
Report identifier (generated by caller).
-
#report_name ⇒ Object
Returns the value of attribute report_name.
-
#sender ⇒ Object
Report sender (PA transmitting the report).
-
#transactions ⇒ Object
Returns the value of attribute transactions.
-
#transmission_type ⇒ Object
Transmission type (TT-4 TypeCode): IN=Initial, RE=Rectificative.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateEReportingRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateEReportingRequest
Initializes the object
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 126 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::CreateEReportingRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::CreateEReportingRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'report_id') self.report_id = attributes[:'report_id'] else self.report_id = nil end if attributes.key?(:'report_name') self.report_name = attributes[:'report_name'] end if attributes.key?(:'flow_type') self.flow_type = attributes[:'flow_type'] else self.flow_type = nil end if attributes.key?(:'transmission_type') self.transmission_type = attributes[:'transmission_type'] end if attributes.key?(:'sender') self.sender = attributes[:'sender'] else self.sender = nil end if attributes.key?(:'issuer') self.issuer = attributes[:'issuer'] end if attributes.key?(:'period') self.period = attributes[:'period'] else self.period = nil end if attributes.key?(:'invoices') if (value = attributes[:'invoices']).is_a?(Array) self.invoices = value end end if attributes.key?(:'transactions') if (value = attributes[:'transactions']).is_a?(Array) self.transactions = value end end if attributes.key?(:'invoice_payments') if (value = attributes[:'invoice_payments']).is_a?(Array) self.invoice_payments = value end end if attributes.key?(:'aggregated_payments') if (value = attributes[:'aggregated_payments']).is_a?(Array) self.aggregated_payments = value end end end |
Instance Attribute Details
#aggregated_payments ⇒ Object
Returns the value of attribute aggregated_payments.
44 45 46 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 44 def aggregated_payments @aggregated_payments end |
#flow_type ⇒ Object
E-Reporting flux type (for internal routing)
25 26 27 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 25 def flow_type @flow_type end |
#invoice_payments ⇒ Object
Returns the value of attribute invoice_payments.
42 43 44 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 42 def invoice_payments @invoice_payments end |
#invoices ⇒ Object
Returns the value of attribute invoices.
38 39 40 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 38 def invoices @invoices end |
#issuer ⇒ Object
Returns the value of attribute issuer.
33 34 35 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 33 def issuer @issuer end |
#period ⇒ Object
Reporting period
36 37 38 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 36 def period @period end |
#report_id ⇒ Object
Report identifier (generated by caller)
20 21 22 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 20 def report_id @report_id end |
#report_name ⇒ Object
Returns the value of attribute report_name.
22 23 24 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 22 def report_name @report_name end |
#sender ⇒ Object
Report sender (PA transmitting the report)
31 32 33 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 31 def sender @sender end |
#transactions ⇒ Object
Returns the value of attribute transactions.
40 41 42 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 40 def transactions @transactions end |
#transmission_type ⇒ Object
Transmission type (TT-4 TypeCode): IN=Initial, RE=Rectificative
28 29 30 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 28 def transmission_type @transmission_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
86 87 88 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 86 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
91 92 93 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 91 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 69 def self.attribute_map { :'report_id' => :'reportId', :'report_name' => :'reportName', :'flow_type' => :'flowType', :'transmission_type' => :'transmissionType', :'sender' => :'sender', :'issuer' => :'issuer', :'period' => :'period', :'invoices' => :'invoices', :'transactions' => :'transactions', :'invoice_payments' => :'invoicePayments', :'aggregated_payments' => :'aggregatedPayments' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 309 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
113 114 115 116 117 118 119 120 121 122 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 113 def self.openapi_nullable Set.new([ :'report_name', :'issuer', :'invoices', :'transactions', :'invoice_payments', :'aggregated_payments' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 96 def self.openapi_types { :'report_id' => :'String', :'report_name' => :'String', :'flow_type' => :'EReportingFlowType', :'transmission_type' => :'TransmissionTypeCode', :'sender' => :'ReportSender', :'issuer' => :'ReportIssuer', :'period' => :'ReportPeriod', :'invoices' => :'Array<InvoiceInput>', :'transactions' => :'Array<AggregatedTransactionInput>', :'invoice_payments' => :'Array<InvoicePaymentInput>', :'aggregated_payments' => :'Array<AggregatedPaymentInput>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 278 def ==(o) return true if self.equal?(o) self.class == o.class && report_id == o.report_id && report_name == o.report_name && flow_type == o.flow_type && transmission_type == o.transmission_type && sender == o.sender && issuer == o.issuer && period == o.period && invoices == o.invoices && transactions == o.transactions && invoice_payments == o.invoice_payments && aggregated_payments == o.aggregated_payments end |
#eql?(o) ⇒ Boolean
296 297 298 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 296 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
302 303 304 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 302 def hash [report_id, report_name, flow_type, transmission_type, sender, issuer, period, invoices, transactions, invoice_payments, aggregated_payments].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 203 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @report_id.nil? invalid_properties.push('invalid value for "report_id", report_id cannot be nil.') end if @flow_type.nil? invalid_properties.push('invalid value for "flow_type", flow_type cannot be nil.') end if @sender.nil? invalid_properties.push('invalid value for "sender", sender cannot be nil.') end if @period.nil? invalid_properties.push('invalid value for "period", period cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 331 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
227 228 229 230 231 232 233 234 |
# File 'lib/factpulse/models/create_e_reporting_request.rb', line 227 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @report_id.nil? return false if @flow_type.nil? return false if @sender.nil? return false if @period.nil? true end |