Class: FactPulse::InvoicingFramework
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::InvoicingFramework
- Defined in:
- lib/factpulse/models/invoicing_framework.rb
Overview
Defines the invoicing framework. - invoicing_framework_code: Chorus Pro code (A1, A2, A9, A12) - used for B2G - operation_nature: Operation nature (B1, S1, M1, etc.) - priority for Factur-X If operation_nature is provided, it will be used directly in Factur-X XML (BT-23). Otherwise, the code will be derived from invoicing_framework_code via automatic mapping. Example: >>> framework = InvoicingFramework( ... invoicing_framework_code=InvoicingFrameworkCode.A1_SUPPLIER_INVOICE, ... operation_nature=OperationNature.GOODS # Forces B1 instead of S1 ... )
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#approver_service_code ⇒ Object
Returns the value of attribute approver_service_code.
-
#approver_structure_code ⇒ Object
Returns the value of attribute approver_structure_code.
-
#invoicing_framework_code ⇒ Object
Chorus Pro framework code (A1, A2, A9, A12).
-
#operation_nature ⇒ Object
Returns the value of attribute operation_nature.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InvoicingFramework
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ InvoicingFramework
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/factpulse/models/invoicing_framework.rb', line 91 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::InvoicingFramework` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::InvoicingFramework`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'invoicing_framework_code') self.invoicing_framework_code = attributes[:'invoicing_framework_code'] else self.invoicing_framework_code = nil end if attributes.key?(:'operation_nature') self.operation_nature = attributes[:'operation_nature'] end if attributes.key?(:'approver_service_code') self.approver_service_code = attributes[:'approver_service_code'] end if attributes.key?(:'approver_structure_code') self.approver_structure_code = attributes[:'approver_structure_code'] end end |
Instance Attribute Details
#approver_service_code ⇒ Object
Returns the value of attribute approver_service_code.
24 25 26 |
# File 'lib/factpulse/models/invoicing_framework.rb', line 24 def approver_service_code @approver_service_code end |
#approver_structure_code ⇒ Object
Returns the value of attribute approver_structure_code.
26 27 28 |
# File 'lib/factpulse/models/invoicing_framework.rb', line 26 def approver_structure_code @approver_structure_code end |
#invoicing_framework_code ⇒ Object
Chorus Pro framework code (A1, A2, A9, A12)
20 21 22 |
# File 'lib/factpulse/models/invoicing_framework.rb', line 20 def invoicing_framework_code @invoicing_framework_code end |
#operation_nature ⇒ Object
Returns the value of attribute operation_nature.
22 23 24 |
# File 'lib/factpulse/models/invoicing_framework.rb', line 22 def operation_nature @operation_nature end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/factpulse/models/invoicing_framework.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/factpulse/models/invoicing_framework.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 |
# File 'lib/factpulse/models/invoicing_framework.rb', line 51 def self.attribute_map { :'invoicing_framework_code' => :'invoicing_framework_code', :'operation_nature' => :'operation_nature', :'approver_service_code' => :'approver_service_code', :'approver_structure_code' => :'approver_structure_code' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/factpulse/models/invoicing_framework.rb', line 180 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 85 86 87 |
# File 'lib/factpulse/models/invoicing_framework.rb', line 81 def self.openapi_nullable Set.new([ :'operation_nature', :'approver_service_code', :'approver_structure_code' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 |
# File 'lib/factpulse/models/invoicing_framework.rb', line 71 def self.openapi_types { :'invoicing_framework_code' => :'InvoicingFrameworkCode', :'operation_nature' => :'OperationNature', :'approver_service_code' => :'String', :'approver_structure_code' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
156 157 158 159 160 161 162 163 |
# File 'lib/factpulse/models/invoicing_framework.rb', line 156 def ==(o) return true if self.equal?(o) self.class == o.class && invoicing_framework_code == o.invoicing_framework_code && operation_nature == o.operation_nature && approver_service_code == o.approver_service_code && approver_structure_code == o.approver_structure_code end |
#eql?(o) ⇒ Boolean
167 168 169 |
# File 'lib/factpulse/models/invoicing_framework.rb', line 167 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
173 174 175 |
# File 'lib/factpulse/models/invoicing_framework.rb', line 173 def hash [invoicing_framework_code, operation_nature, approver_service_code, approver_structure_code].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
126 127 128 129 130 131 132 133 134 |
# File 'lib/factpulse/models/invoicing_framework.rb', line 126 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @invoicing_framework_code.nil? invalid_properties.push('invalid value for "invoicing_framework_code", invoicing_framework_code cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/factpulse/models/invoicing_framework.rb', line 202 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
138 139 140 141 142 |
# File 'lib/factpulse/models/invoicing_framework.rb', line 138 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @invoicing_framework_code.nil? true end |