Class: FactPulse::PDPConfigUpdateRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FactPulse::PDPConfigUpdateRequest
- Defined in:
- lib/factpulse/models/pdp_config_update_request.rb
Overview
PDP configuration update request. For encryption_mode=‘double’, the X-Encryption-Key header must also be provided containing a base64-encoded AES-256 key (32 bytes).
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#client_secret ⇒ Object
OAuth Client Secret (sent but never returned).
-
#encryption_mode ⇒ Object
Returns the value of attribute encryption_mode.
-
#flow_service_url ⇒ Object
PDP Flow Service URL.
-
#is_active ⇒ Object
Whether config is active.
-
#mode_sandbox ⇒ Object
Sandbox mode.
-
#oauth_client_id ⇒ Object
OAuth Client ID.
-
#token_url ⇒ Object
PDP OAuth token URL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PDPConfigUpdateRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PDPConfigUpdateRequest
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FactPulse::PDPConfigUpdateRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FactPulse::PDPConfigUpdateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] else self.is_active = true end if attributes.key?(:'mode_sandbox') self.mode_sandbox = attributes[:'mode_sandbox'] else self.mode_sandbox = false end if attributes.key?(:'flow_service_url') self.flow_service_url = attributes[:'flow_service_url'] else self.flow_service_url = nil end if attributes.key?(:'token_url') self.token_url = attributes[:'token_url'] else self.token_url = nil end if attributes.key?(:'oauth_client_id') self.oauth_client_id = attributes[:'oauth_client_id'] else self.oauth_client_id = nil end if attributes.key?(:'client_secret') self.client_secret = attributes[:'client_secret'] else self.client_secret = nil end if attributes.key?(:'encryption_mode') self.encryption_mode = attributes[:'encryption_mode'] end end |
Instance Attribute Details
#client_secret ⇒ Object
OAuth Client Secret (sent but never returned)
35 36 37 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 35 def client_secret @client_secret end |
#encryption_mode ⇒ Object
Returns the value of attribute encryption_mode.
37 38 39 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 37 def encryption_mode @encryption_mode end |
#flow_service_url ⇒ Object
PDP Flow Service URL
26 27 28 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 26 def flow_service_url @flow_service_url end |
#is_active ⇒ Object
Whether config is active
20 21 22 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 20 def is_active @is_active end |
#mode_sandbox ⇒ Object
Sandbox mode
23 24 25 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 23 def mode_sandbox @mode_sandbox end |
#oauth_client_id ⇒ Object
OAuth Client ID
32 33 34 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 32 def oauth_client_id @oauth_client_id end |
#token_url ⇒ Object
PDP OAuth token URL
29 30 31 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 29 def token_url @token_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 62 def self.attribute_map { :'is_active' => :'isActive', :'mode_sandbox' => :'modeSandbox', :'flow_service_url' => :'flowServiceUrl', :'token_url' => :'tokenUrl', :'oauth_client_id' => :'oauthClientId', :'client_secret' => :'clientSecret', :'encryption_mode' => :'encryptionMode' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 277 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 102 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 98 def self.openapi_nullable Set.new([ :'encryption_mode' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 85 def self.openapi_types { :'is_active' => :'Boolean', :'mode_sandbox' => :'Boolean', :'flow_service_url' => :'String', :'token_url' => :'String', :'oauth_client_id' => :'String', :'client_secret' => :'String', :'encryption_mode' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 250 def ==(o) return true if self.equal?(o) self.class == o.class && is_active == o.is_active && mode_sandbox == o.mode_sandbox && flow_service_url == o.flow_service_url && token_url == o.token_url && oauth_client_id == o.oauth_client_id && client_secret == o.client_secret && encryption_mode == o.encryption_mode end |
#eql?(o) ⇒ Boolean
264 265 266 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 264 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
270 271 272 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 270 def hash [is_active, mode_sandbox, flow_service_url, token_url, oauth_client_id, client_secret, encryption_mode].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 163 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @flow_service_url.nil? invalid_properties.push('invalid value for "flow_service_url", flow_service_url cannot be nil.') end if @token_url.nil? invalid_properties.push('invalid value for "token_url", token_url cannot be nil.') end if @oauth_client_id.nil? invalid_properties.push('invalid value for "oauth_client_id", oauth_client_id cannot be nil.') end if @client_secret.nil? invalid_properties.push('invalid value for "client_secret", client_secret cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 299 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/factpulse/models/pdp_config_update_request.rb', line 187 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @flow_service_url.nil? return false if @token_url.nil? return false if @oauth_client_id.nil? return false if @client_secret.nil? encryption_mode_validator = EnumAttributeValidator.new('String', ["fernet", "double"]) return false unless encryption_mode_validator.valid?(@encryption_mode) true end |